;;; latin-unity-tables.el --- initialize latin-unity-equivalences
;; Do not edit --- automatically generated.
;; Created: 2002 November 01
(provide 'latin-unity-tables)
(defconst latin-unity-equivalences
  (let ((table (make-char-table 'generic)))
    ;; default all non-Latin charsets
    (put-char-table t [0 nil nil nil nil nil nil nil nil nil nil nil nil] table)
    ;; Control 1 code points are spatial
    ;; Warning on these is beyond this library's scope.
    (put-char-table 'control-1 [2047 nil nil nil nil nil nil nil nil nil nil nil nil] table)
    (put-char-table (make-char 'ascii 0) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 0) nil #x0) table)
    (put-char-table (make-char 'ascii 1) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 1) nil #x1) table)
    (put-char-table (make-char 'ascii 2) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 2) nil #x2) table)
    (put-char-table (make-char 'ascii 3) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 3) nil #x3) table)
    (put-char-table (make-char 'ascii 4) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 4) nil #x4) table)
    (put-char-table (make-char 'ascii 5) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 5) nil #x5) table)
    (put-char-table (make-char 'ascii 6) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 6) nil #x6) table)
    (put-char-table (make-char 'ascii 7) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 7) nil #x7) table)
    (put-char-table (make-char 'ascii 8) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 8) nil #x8) table)
    (put-char-table (make-char 'ascii 9) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 9) nil #x9) table)
    (put-char-table (make-char 'ascii 10) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 10) nil #xA) table)
    (put-char-table (make-char 'ascii 11) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 11) nil #xB) table)
    (put-char-table (make-char 'ascii 12) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 12) nil #xC) table)
    (put-char-table (make-char 'ascii 13) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 13) nil #xD) table)
    (put-char-table (make-char 'ascii 14) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 14) nil #xE) table)
    (put-char-table (make-char 'ascii 15) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 15) nil #xF) table)
    (put-char-table (make-char 'ascii 16) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 16) nil #x10) table)
    (put-char-table (make-char 'ascii 17) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 17) nil #x11) table)
    (put-char-table (make-char 'ascii 18) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 18) nil #x12) table)
    (put-char-table (make-char 'ascii 19) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 19) nil #x13) table)
    (put-char-table (make-char 'ascii 20) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 20) nil #x14) table)
    (put-char-table (make-char 'ascii 21) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 21) nil #x15) table)
    (put-char-table (make-char 'ascii 22) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 22) nil #x16) table)
    (put-char-table (make-char 'ascii 23) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 23) nil #x17) table)
    (put-char-table (make-char 'ascii 24) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 24) nil #x18) table)
    (put-char-table (make-char 'ascii 25) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 25) nil #x19) table)
    (put-char-table (make-char 'ascii 26) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 26) nil #x1A) table)
    (put-char-table (make-char 'ascii 27) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 27) nil #x1B) table)
    (put-char-table (make-char 'ascii 28) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 28) nil #x1C) table)
    (put-char-table (make-char 'ascii 29) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 29) nil #x1D) table)
    (put-char-table (make-char 'ascii 30) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 30) nil #x1E) table)
    (put-char-table (make-char 'ascii 31) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 31) nil #x1F) table)
    (put-char-table (make-char 'ascii 32) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 32) nil #x20) table)
    (put-char-table (make-char 'ascii 33) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 33) (make-char 'latin-jisx0201 33) #x21) table)
    (put-char-table (make-char 'ascii 34) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 34) (make-char 'latin-jisx0201 34) #x22) table)
    (put-char-table (make-char 'ascii 35) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 35) (make-char 'latin-jisx0201 35) #x23) table)
    (put-char-table (make-char 'ascii 36) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 36) (make-char 'latin-jisx0201 36) #x24) table)
    (put-char-table (make-char 'ascii 37) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 37) (make-char 'latin-jisx0201 37) #x25) table)
    (put-char-table (make-char 'ascii 38) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 38) (make-char 'latin-jisx0201 38) #x26) table)
    (put-char-table (make-char 'ascii 39) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 39) (make-char 'latin-jisx0201 39) #x27) table)
    (put-char-table (make-char 'ascii 40) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 40) (make-char 'latin-jisx0201 40) #x28) table)
    (put-char-table (make-char 'ascii 41) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 41) (make-char 'latin-jisx0201 41) #x29) table)
    (put-char-table (make-char 'ascii 42) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 42) (make-char 'latin-jisx0201 42) #x2A) table)
    (put-char-table (make-char 'ascii 43) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 43) (make-char 'latin-jisx0201 43) #x2B) table)
    (put-char-table (make-char 'ascii 44) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 44) (make-char 'latin-jisx0201 44) #x2C) table)
    (put-char-table (make-char 'ascii 45) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 45) (make-char 'latin-jisx0201 45) #x2D) table)
    (put-char-table (make-char 'ascii 46) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 46) (make-char 'latin-jisx0201 46) #x2E) table)
    (put-char-table (make-char 'ascii 47) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 47) (make-char 'latin-jisx0201 47) #x2F) table)
    (put-char-table (make-char 'ascii 48) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 48) (make-char 'latin-jisx0201 48) #x30) table)
    (put-char-table (make-char 'ascii 49) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 49) (make-char 'latin-jisx0201 49) #x31) table)
    (put-char-table (make-char 'ascii 50) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 50) (make-char 'latin-jisx0201 50) #x32) table)
    (put-char-table (make-char 'ascii 51) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 51) (make-char 'latin-jisx0201 51) #x33) table)
    (put-char-table (make-char 'ascii 52) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 52) (make-char 'latin-jisx0201 52) #x34) table)
    (put-char-table (make-char 'ascii 53) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 53) (make-char 'latin-jisx0201 53) #x35) table)
    (put-char-table (make-char 'ascii 54) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 54) (make-char 'latin-jisx0201 54) #x36) table)
    (put-char-table (make-char 'ascii 55) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 55) (make-char 'latin-jisx0201 55) #x37) table)
    (put-char-table (make-char 'ascii 56) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 56) (make-char 'latin-jisx0201 56) #x38) table)
    (put-char-table (make-char 'ascii 57) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 57) (make-char 'latin-jisx0201 57) #x39) table)
    (put-char-table (make-char 'ascii 58) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 58) (make-char 'latin-jisx0201 58) #x3A) table)
    (put-char-table (make-char 'ascii 59) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 59) (make-char 'latin-jisx0201 59) #x3B) table)
    (put-char-table (make-char 'ascii 60) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 60) (make-char 'latin-jisx0201 60) #x3C) table)
    (put-char-table (make-char 'ascii 61) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 61) (make-char 'latin-jisx0201 61) #x3D) table)
    (put-char-table (make-char 'ascii 62) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 62) (make-char 'latin-jisx0201 62) #x3E) table)
    (put-char-table (make-char 'ascii 63) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 63) (make-char 'latin-jisx0201 63) #x3F) table)
    (put-char-table (make-char 'ascii 64) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 64) (make-char 'latin-jisx0201 64) #x40) table)
    (put-char-table (make-char 'ascii 65) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 65) (make-char 'latin-jisx0201 65) #x41) table)
    (put-char-table (make-char 'ascii 66) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 66) (make-char 'latin-jisx0201 66) #x42) table)
    (put-char-table (make-char 'ascii 67) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 67) (make-char 'latin-jisx0201 67) #x43) table)
    (put-char-table (make-char 'ascii 68) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 68) (make-char 'latin-jisx0201 68) #x44) table)
    (put-char-table (make-char 'ascii 69) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 69) (make-char 'latin-jisx0201 69) #x45) table)
    (put-char-table (make-char 'ascii 70) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 70) (make-char 'latin-jisx0201 70) #x46) table)
    (put-char-table (make-char 'ascii 71) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 71) (make-char 'latin-jisx0201 71) #x47) table)
    (put-char-table (make-char 'ascii 72) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 72) (make-char 'latin-jisx0201 72) #x48) table)
    (put-char-table (make-char 'ascii 73) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 73) (make-char 'latin-jisx0201 73) #x49) table)
    (put-char-table (make-char 'ascii 74) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 74) (make-char 'latin-jisx0201 74) #x4A) table)
    (put-char-table (make-char 'ascii 75) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 75) (make-char 'latin-jisx0201 75) #x4B) table)
    (put-char-table (make-char 'ascii 76) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 76) (make-char 'latin-jisx0201 76) #x4C) table)
    (put-char-table (make-char 'ascii 77) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 77) (make-char 'latin-jisx0201 77) #x4D) table)
    (put-char-table (make-char 'ascii 78) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 78) (make-char 'latin-jisx0201 78) #x4E) table)
    (put-char-table (make-char 'ascii 79) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 79) (make-char 'latin-jisx0201 79) #x4F) table)
    (put-char-table (make-char 'ascii 80) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 80) (make-char 'latin-jisx0201 80) #x50) table)
    (put-char-table (make-char 'ascii 81) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 81) (make-char 'latin-jisx0201 81) #x51) table)
    (put-char-table (make-char 'ascii 82) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 82) (make-char 'latin-jisx0201 82) #x52) table)
    (put-char-table (make-char 'ascii 83) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 83) (make-char 'latin-jisx0201 83) #x53) table)
    (put-char-table (make-char 'ascii 84) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 84) (make-char 'latin-jisx0201 84) #x54) table)
    (put-char-table (make-char 'ascii 85) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 85) (make-char 'latin-jisx0201 85) #x55) table)
    (put-char-table (make-char 'ascii 86) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 86) (make-char 'latin-jisx0201 86) #x56) table)
    (put-char-table (make-char 'ascii 87) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 87) (make-char 'latin-jisx0201 87) #x57) table)
    (put-char-table (make-char 'ascii 88) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 88) (make-char 'latin-jisx0201 88) #x58) table)
    (put-char-table (make-char 'ascii 89) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 89) (make-char 'latin-jisx0201 89) #x59) table)
    (put-char-table (make-char 'ascii 90) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 90) (make-char 'latin-jisx0201 90) #x5A) table)
    (put-char-table (make-char 'ascii 91) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 91) (make-char 'latin-jisx0201 91) #x5B) table)
    (put-char-table (make-char 'ascii 92) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 92) nil #x5C) table)
    (put-char-table (make-char 'ascii 93) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 93) (make-char 'latin-jisx0201 93) #x5D) table)
    (put-char-table (make-char 'ascii 94) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 94) (make-char 'latin-jisx0201 94) #x5E) table)
    (put-char-table (make-char 'ascii 95) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 95) (make-char 'latin-jisx0201 95) #x5F) table)
    (put-char-table (make-char 'ascii 96) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 96) (make-char 'latin-jisx0201 96) #x60) table)
    (put-char-table (make-char 'ascii 97) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 97) (make-char 'latin-jisx0201 97) #x61) table)
    (put-char-table (make-char 'ascii 98) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 98) (make-char 'latin-jisx0201 98) #x62) table)
    (put-char-table (make-char 'ascii 99) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 99) (make-char 'latin-jisx0201 99) #x63) table)
    (put-char-table (make-char 'ascii 100) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 100) (make-char 'latin-jisx0201 100) #x64) table)
    (put-char-table (make-char 'ascii 101) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 101) (make-char 'latin-jisx0201 101) #x65) table)
    (put-char-table (make-char 'ascii 102) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 102) (make-char 'latin-jisx0201 102) #x66) table)
    (put-char-table (make-char 'ascii 103) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 103) (make-char 'latin-jisx0201 103) #x67) table)
    (put-char-table (make-char 'ascii 104) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 104) (make-char 'latin-jisx0201 104) #x68) table)
    (put-char-table (make-char 'ascii 105) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 105) (make-char 'latin-jisx0201 105) #x69) table)
    (put-char-table (make-char 'ascii 106) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 106) (make-char 'latin-jisx0201 106) #x6A) table)
    (put-char-table (make-char 'ascii 107) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 107) (make-char 'latin-jisx0201 107) #x6B) table)
    (put-char-table (make-char 'ascii 108) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 108) (make-char 'latin-jisx0201 108) #x6C) table)
    (put-char-table (make-char 'ascii 109) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 109) (make-char 'latin-jisx0201 109) #x6D) table)
    (put-char-table (make-char 'ascii 110) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 110) (make-char 'latin-jisx0201 110) #x6E) table)
    (put-char-table (make-char 'ascii 111) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 111) (make-char 'latin-jisx0201 111) #x6F) table)
    (put-char-table (make-char 'ascii 112) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 112) (make-char 'latin-jisx0201 112) #x70) table)
    (put-char-table (make-char 'ascii 113) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 113) (make-char 'latin-jisx0201 113) #x71) table)
    (put-char-table (make-char 'ascii 114) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 114) (make-char 'latin-jisx0201 114) #x72) table)
    (put-char-table (make-char 'ascii 115) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 115) (make-char 'latin-jisx0201 115) #x73) table)
    (put-char-table (make-char 'ascii 116) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 116) (make-char 'latin-jisx0201 116) #x74) table)
    (put-char-table (make-char 'ascii 117) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 117) (make-char 'latin-jisx0201 117) #x75) table)
    (put-char-table (make-char 'ascii 118) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 118) (make-char 'latin-jisx0201 118) #x76) table)
    (put-char-table (make-char 'ascii 119) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 119) (make-char 'latin-jisx0201 119) #x77) table)
    (put-char-table (make-char 'ascii 120) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 120) (make-char 'latin-jisx0201 120) #x78) table)
    (put-char-table (make-char 'ascii 121) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 121) (make-char 'latin-jisx0201 121) #x79) table)
    (put-char-table (make-char 'ascii 122) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 122) (make-char 'latin-jisx0201 122) #x7A) table)
    (put-char-table (make-char 'ascii 123) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 123) (make-char 'latin-jisx0201 123) #x7B) table)
    (put-char-table (make-char 'ascii 124) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 124) (make-char 'latin-jisx0201 124) #x7C) table)
    (put-char-table (make-char 'ascii 125) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 125) (make-char 'latin-jisx0201 125) #x7D) table)
    (put-char-table (make-char 'ascii 126) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 126) nil #x7E) table)
    (put-char-table (make-char 'ascii 127) (vector #x200 nil nil nil nil nil nil nil nil nil (make-char 'ascii 127) nil #x7F) table)
    (put-char-table (make-char 'control-1 0) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 1) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 2) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 3) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 4) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 5) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 6) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 7) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 8) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 9) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 10) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 11) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 12) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 13) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 14) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 15) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 16) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 17) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 18) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 19) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 20) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 21) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 22) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 23) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 24) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 25) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 26) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 27) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 28) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 29) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 30) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'control-1 31) (vector #x7FF nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-1 32) (vector #x1FF (make-char 'latin-iso8859-1 32) (make-char 'latin-iso8859-2 32) (make-char 'latin-iso8859-3 32) (make-char 'latin-iso8859-4 32) (make-char 'latin-iso8859-9 32) (make-char 'latin-iso8859-13 32) (make-char 'latin-iso8859-14 32) (make-char 'latin-iso8859-15 32) (make-char 'latin-iso8859-16 32) nil nil #xA0) table)
    (put-char-table (make-char 'latin-iso8859-1 33) (vector #x91 (make-char 'latin-iso8859-1 33) nil nil nil (make-char 'latin-iso8859-9 33) nil nil (make-char 'latin-iso8859-15 33) nil nil nil #xA1) table)
    (put-char-table (make-char 'latin-iso8859-1 34) (vector #xB1 (make-char 'latin-iso8859-1 34) nil nil nil (make-char 'latin-iso8859-9 34) (make-char 'latin-iso8859-13 34) nil (make-char 'latin-iso8859-15 34) nil nil nil #xA2) table)
    (put-char-table (make-char 'latin-iso8859-1 35) (vector #xF5 (make-char 'latin-iso8859-1 35) nil (make-char 'latin-iso8859-3 35) nil (make-char 'latin-iso8859-9 35) (make-char 'latin-iso8859-13 35) (make-char 'latin-iso8859-14 35) (make-char 'latin-iso8859-15 35) nil nil nil #xA3) table)
    (put-char-table (make-char 'latin-iso8859-1 36) (vector #x3F (make-char 'latin-iso8859-1 36) (make-char 'latin-iso8859-2 36) (make-char 'latin-iso8859-3 36) (make-char 'latin-iso8859-4 36) (make-char 'latin-iso8859-9 36) (make-char 'latin-iso8859-13 36) nil nil nil nil nil #xA4) table)
    (put-char-table (make-char 'latin-iso8859-1 37) (vector #x491 (make-char 'latin-iso8859-1 37) nil nil nil (make-char 'latin-iso8859-9 37) nil nil (make-char 'latin-iso8859-15 37) nil nil (make-char 'latin-jisx0201 92) #xA5) table)
    (put-char-table (make-char 'latin-iso8859-1 38) (vector #x31 (make-char 'latin-iso8859-1 38) nil nil nil (make-char 'latin-iso8859-9 38) (make-char 'latin-iso8859-13 38) nil nil nil nil nil #xA6) table)
    (put-char-table (make-char 'latin-iso8859-1 39) (vector #x1FF (make-char 'latin-iso8859-1 39) (make-char 'latin-iso8859-2 39) (make-char 'latin-iso8859-3 39) (make-char 'latin-iso8859-4 39) (make-char 'latin-iso8859-9 39) (make-char 'latin-iso8859-13 39) (make-char 'latin-iso8859-14 39) (make-char 'latin-iso8859-15 39) (make-char 'latin-iso8859-16 39) nil nil #xA7) table)
    (put-char-table (make-char 'latin-iso8859-1 40) (vector #x1F (make-char 'latin-iso8859-1 40) (make-char 'latin-iso8859-2 40) (make-char 'latin-iso8859-3 40) (make-char 'latin-iso8859-4 40) (make-char 'latin-iso8859-9 40) nil nil nil nil nil nil #xA8) table)
    (put-char-table (make-char 'latin-iso8859-1 41) (vector #x1F1 (make-char 'latin-iso8859-1 41) nil nil nil (make-char 'latin-iso8859-9 41) (make-char 'latin-iso8859-13 41) (make-char 'latin-iso8859-14 41) (make-char 'latin-iso8859-15 41) (make-char 'latin-iso8859-16 41) nil nil #xA9) table)
    (put-char-table (make-char 'latin-iso8859-1 42) (vector #x91 (make-char 'latin-iso8859-1 42) nil nil nil (make-char 'latin-iso8859-9 42) nil nil (make-char 'latin-iso8859-15 42) nil nil nil #xAA) table)
    (put-char-table (make-char 'latin-iso8859-1 43) (vector #x1B1 (make-char 'latin-iso8859-1 43) nil nil nil (make-char 'latin-iso8859-9 43) (make-char 'latin-iso8859-13 43) nil (make-char 'latin-iso8859-15 43) (make-char 'latin-iso8859-16 43) nil nil #xAB) table)
    (put-char-table (make-char 'latin-iso8859-1 44) (vector #xB1 (make-char 'latin-iso8859-1 44) nil nil nil (make-char 'latin-iso8859-9 44) (make-char 'latin-iso8859-13 44) nil (make-char 'latin-iso8859-15 44) nil nil nil #xAC) table)
    (put-char-table (make-char 'latin-iso8859-1 45) (vector #x1FF (make-char 'latin-iso8859-1 45) (make-char 'latin-iso8859-2 45) (make-char 'latin-iso8859-3 45) (make-char 'latin-iso8859-4 45) (make-char 'latin-iso8859-9 45) (make-char 'latin-iso8859-13 45) (make-char 'latin-iso8859-14 45) (make-char 'latin-iso8859-15 45) (make-char 'latin-iso8859-16 45) nil nil #xAD) table)
    (put-char-table (make-char 'latin-iso8859-1 46) (vector #xF1 (make-char 'latin-iso8859-1 46) nil nil nil (make-char 'latin-iso8859-9 46) (make-char 'latin-iso8859-13 46) (make-char 'latin-iso8859-14 46) (make-char 'latin-iso8859-15 46) nil nil nil #xAE) table)
    (put-char-table (make-char 'latin-iso8859-1 47) (vector #x99 (make-char 'latin-iso8859-1 47) nil nil (make-char 'latin-iso8859-4 47) (make-char 'latin-iso8859-9 47) nil nil (make-char 'latin-iso8859-15 47) nil nil nil #xAF) table)
    (put-char-table (make-char 'latin-iso8859-1 48) (vector #x1BF (make-char 'latin-iso8859-1 48) (make-char 'latin-iso8859-2 48) (make-char 'latin-iso8859-3 48) (make-char 'latin-iso8859-4 48) (make-char 'latin-iso8859-9 48) (make-char 'latin-iso8859-13 48) nil (make-char 'latin-iso8859-15 48) (make-char 'latin-iso8859-16 48) nil nil #xB0) table)
    (put-char-table (make-char 'latin-iso8859-1 49) (vector #x1B1 (make-char 'latin-iso8859-1 49) nil nil nil (make-char 'latin-iso8859-9 49) (make-char 'latin-iso8859-13 49) nil (make-char 'latin-iso8859-15 49) (make-char 'latin-iso8859-16 49) nil nil #xB1) table)
    (put-char-table (make-char 'latin-iso8859-1 50) (vector #xB5 (make-char 'latin-iso8859-1 50) nil (make-char 'latin-iso8859-3 50) nil (make-char 'latin-iso8859-9 50) (make-char 'latin-iso8859-13 50) nil (make-char 'latin-iso8859-15 50) nil nil nil #xB2) table)
    (put-char-table (make-char 'latin-iso8859-1 51) (vector #xB5 (make-char 'latin-iso8859-1 51) nil (make-char 'latin-iso8859-3 51) nil (make-char 'latin-iso8859-9 51) (make-char 'latin-iso8859-13 51) nil (make-char 'latin-iso8859-15 51) nil nil nil #xB3) table)
    (put-char-table (make-char 'latin-iso8859-1 52) (vector #x1F (make-char 'latin-iso8859-1 52) (make-char 'latin-iso8859-2 52) (make-char 'latin-iso8859-3 52) (make-char 'latin-iso8859-4 52) (make-char 'latin-iso8859-9 52) nil nil nil nil nil nil #xB4) table)
    (put-char-table (make-char 'latin-iso8859-1 53) (vector #xB5 (make-char 'latin-iso8859-1 53) nil (make-char 'latin-iso8859-3 53) nil (make-char 'latin-iso8859-9 53) (make-char 'latin-iso8859-13 53) nil (make-char 'latin-iso8859-15 53) nil nil nil #xB5) table)
    (put-char-table (make-char 'latin-iso8859-1 54) (vector #x1F1 (make-char 'latin-iso8859-1 54) nil nil nil (make-char 'latin-iso8859-9 54) (make-char 'latin-iso8859-13 54) (make-char 'latin-iso8859-14 54) (make-char 'latin-iso8859-15 54) (make-char 'latin-iso8859-16 54) nil nil #xB6) table)
    (put-char-table (make-char 'latin-iso8859-1 55) (vector #x1B5 (make-char 'latin-iso8859-1 55) nil (make-char 'latin-iso8859-3 55) nil (make-char 'latin-iso8859-9 55) (make-char 'latin-iso8859-13 55) nil (make-char 'latin-iso8859-15 55) (make-char 'latin-iso8859-16 55) nil nil #xB7) table)
    (put-char-table (make-char 'latin-iso8859-1 56) (vector #x1F (make-char 'latin-iso8859-1 56) (make-char 'latin-iso8859-2 56) (make-char 'latin-iso8859-3 56) (make-char 'latin-iso8859-4 56) (make-char 'latin-iso8859-9 56) nil nil nil nil nil nil #xB8) table)
    (put-char-table (make-char 'latin-iso8859-1 57) (vector #xB1 (make-char 'latin-iso8859-1 57) nil nil nil (make-char 'latin-iso8859-9 57) (make-char 'latin-iso8859-13 57) nil (make-char 'latin-iso8859-15 57) nil nil nil #xB9) table)
    (put-char-table (make-char 'latin-iso8859-1 58) (vector #x91 (make-char 'latin-iso8859-1 58) nil nil nil (make-char 'latin-iso8859-9 58) nil nil (make-char 'latin-iso8859-15 58) nil nil nil #xBA) table)
    (put-char-table (make-char 'latin-iso8859-1 59) (vector #x1B1 (make-char 'latin-iso8859-1 59) nil nil nil (make-char 'latin-iso8859-9 59) (make-char 'latin-iso8859-13 59) nil (make-char 'latin-iso8859-15 59) (make-char 'latin-iso8859-16 59) nil nil #xBB) table)
    (put-char-table (make-char 'latin-iso8859-1 60) (vector #x31 (make-char 'latin-iso8859-1 60) nil nil nil (make-char 'latin-iso8859-9 60) (make-char 'latin-iso8859-13 60) nil nil nil nil nil #xBC) table)
    (put-char-table (make-char 'latin-iso8859-1 61) (vector #x35 (make-char 'latin-iso8859-1 61) nil (make-char 'latin-iso8859-3 61) nil (make-char 'latin-iso8859-9 61) (make-char 'latin-iso8859-13 61) nil nil nil nil nil #xBD) table)
    (put-char-table (make-char 'latin-iso8859-1 62) (vector #x31 (make-char 'latin-iso8859-1 62) nil nil nil (make-char 'latin-iso8859-9 62) (make-char 'latin-iso8859-13 62) nil nil nil nil nil #xBE) table)
    (put-char-table (make-char 'latin-iso8859-1 63) (vector #x91 (make-char 'latin-iso8859-1 63) nil nil nil (make-char 'latin-iso8859-9 63) nil nil (make-char 'latin-iso8859-15 63) nil nil nil #xBF) table)
    (put-char-table (make-char 'latin-iso8859-1 64) (vector #x1D5 (make-char 'latin-iso8859-1 64) nil (make-char 'latin-iso8859-3 64) nil (make-char 'latin-iso8859-9 64) nil (make-char 'latin-iso8859-14 64) (make-char 'latin-iso8859-15 64) (make-char 'latin-iso8859-16 64) nil nil #xC0) table)
    (put-char-table (make-char 'latin-iso8859-1 65) (vector #x1DF (make-char 'latin-iso8859-1 65) (make-char 'latin-iso8859-2 65) (make-char 'latin-iso8859-3 65) (make-char 'latin-iso8859-4 65) (make-char 'latin-iso8859-9 65) nil (make-char 'latin-iso8859-14 65) (make-char 'latin-iso8859-15 65) (make-char 'latin-iso8859-16 65) nil nil #xC1) table)
    (put-char-table (make-char 'latin-iso8859-1 66) (vector #x1DF (make-char 'latin-iso8859-1 66) (make-char 'latin-iso8859-2 66) (make-char 'latin-iso8859-3 66) (make-char 'latin-iso8859-4 66) (make-char 'latin-iso8859-9 66) nil (make-char 'latin-iso8859-14 66) (make-char 'latin-iso8859-15 66) (make-char 'latin-iso8859-16 66) nil nil #xC2) table)
    (put-char-table (make-char 'latin-iso8859-1 67) (vector #xD9 (make-char 'latin-iso8859-1 67) nil nil (make-char 'latin-iso8859-4 67) (make-char 'latin-iso8859-9 67) nil (make-char 'latin-iso8859-14 67) (make-char 'latin-iso8859-15 67) nil nil nil #xC3) table)
    (put-char-table (make-char 'latin-iso8859-1 68) (vector #x1FF (make-char 'latin-iso8859-1 68) (make-char 'latin-iso8859-2 68) (make-char 'latin-iso8859-3 68) (make-char 'latin-iso8859-4 68) (make-char 'latin-iso8859-9 68) (make-char 'latin-iso8859-13 68) (make-char 'latin-iso8859-14 68) (make-char 'latin-iso8859-15 68) (make-char 'latin-iso8859-16 68) nil nil #xC4) table)
    (put-char-table (make-char 'latin-iso8859-1 69) (vector #xF9 (make-char 'latin-iso8859-1 69) nil nil (make-char 'latin-iso8859-4 69) (make-char 'latin-iso8859-9 69) (make-char 'latin-iso8859-13 69) (make-char 'latin-iso8859-14 69) (make-char 'latin-iso8859-15 69) nil nil nil #xC5) table)
    (put-char-table (make-char 'latin-iso8859-1 70) (vector #x1F9 (make-char 'latin-iso8859-1 70) nil nil (make-char 'latin-iso8859-4 70) (make-char 'latin-iso8859-9 70) (make-char 'latin-iso8859-13 47) (make-char 'latin-iso8859-14 70) (make-char 'latin-iso8859-15 70) (make-char 'latin-iso8859-16 70) nil nil #xC6) table)
    (put-char-table (make-char 'latin-iso8859-1 71) (vector #x1D7 (make-char 'latin-iso8859-1 71) (make-char 'latin-iso8859-2 71) (make-char 'latin-iso8859-3 71) nil (make-char 'latin-iso8859-9 71) nil (make-char 'latin-iso8859-14 71) (make-char 'latin-iso8859-15 71) (make-char 'latin-iso8859-16 71) nil nil #xC7) table)
    (put-char-table (make-char 'latin-iso8859-1 72) (vector #x1D5 (make-char 'latin-iso8859-1 72) nil (make-char 'latin-iso8859-3 72) nil (make-char 'latin-iso8859-9 72) nil (make-char 'latin-iso8859-14 72) (make-char 'latin-iso8859-15 72) (make-char 'latin-iso8859-16 72) nil nil #xC8) table)
    (put-char-table (make-char 'latin-iso8859-1 73) (vector #x1FF (make-char 'latin-iso8859-1 73) (make-char 'latin-iso8859-2 73) (make-char 'latin-iso8859-3 73) (make-char 'latin-iso8859-4 73) (make-char 'latin-iso8859-9 73) (make-char 'latin-iso8859-13 73) (make-char 'latin-iso8859-14 73) (make-char 'latin-iso8859-15 73) (make-char 'latin-iso8859-16 73) nil nil #xC9) table)
    (put-char-table (make-char 'latin-iso8859-1 74) (vector #x1D5 (make-char 'latin-iso8859-1 74) nil (make-char 'latin-iso8859-3 74) nil (make-char 'latin-iso8859-9 74) nil (make-char 'latin-iso8859-14 74) (make-char 'latin-iso8859-15 74) (make-char 'latin-iso8859-16 74) nil nil #xCA) table)
    (put-char-table (make-char 'latin-iso8859-1 75) (vector #x1DF (make-char 'latin-iso8859-1 75) (make-char 'latin-iso8859-2 75) (make-char 'latin-iso8859-3 75) (make-char 'latin-iso8859-4 75) (make-char 'latin-iso8859-9 75) nil (make-char 'latin-iso8859-14 75) (make-char 'latin-iso8859-15 75) (make-char 'latin-iso8859-16 75) nil nil #xCB) table)
    (put-char-table (make-char 'latin-iso8859-1 76) (vector #x1D5 (make-char 'latin-iso8859-1 76) nil (make-char 'latin-iso8859-3 76) nil (make-char 'latin-iso8859-9 76) nil (make-char 'latin-iso8859-14 76) (make-char 'latin-iso8859-15 76) (make-char 'latin-iso8859-16 76) nil nil #xCC) table)
    (put-char-table (make-char 'latin-iso8859-1 77) (vector #x1DF (make-char 'latin-iso8859-1 77) (make-char 'latin-iso8859-2 77) (make-char 'latin-iso8859-3 77) (make-char 'latin-iso8859-4 77) (make-char 'latin-iso8859-9 77) nil (make-char 'latin-iso8859-14 77) (make-char 'latin-iso8859-15 77) (make-char 'latin-iso8859-16 77) nil nil #xCD) table)
    (put-char-table (make-char 'latin-iso8859-1 78) (vector #x1DF (make-char 'latin-iso8859-1 78) (make-char 'latin-iso8859-2 78) (make-char 'latin-iso8859-3 78) (make-char 'latin-iso8859-4 78) (make-char 'latin-iso8859-9 78) nil (make-char 'latin-iso8859-14 78) (make-char 'latin-iso8859-15 78) (make-char 'latin-iso8859-16 78) nil nil #xCE) table)
    (put-char-table (make-char 'latin-iso8859-1 79) (vector #x1D5 (make-char 'latin-iso8859-1 79) nil (make-char 'latin-iso8859-3 79) nil (make-char 'latin-iso8859-9 79) nil (make-char 'latin-iso8859-14 79) (make-char 'latin-iso8859-15 79) (make-char 'latin-iso8859-16 79) nil nil #xCF) table)
    (put-char-table (make-char 'latin-iso8859-1 80) (vector #x81 (make-char 'latin-iso8859-1 80) nil nil nil nil nil nil (make-char 'latin-iso8859-15 80) nil nil nil #xD0) table)
    (put-char-table (make-char 'latin-iso8859-1 81) (vector #xD5 (make-char 'latin-iso8859-1 81) nil (make-char 'latin-iso8859-3 81) nil (make-char 'latin-iso8859-9 81) nil (make-char 'latin-iso8859-14 81) (make-char 'latin-iso8859-15 81) nil nil nil #xD1) table)
    (put-char-table (make-char 'latin-iso8859-1 82) (vector #x1D5 (make-char 'latin-iso8859-1 82) nil (make-char 'latin-iso8859-3 82) nil (make-char 'latin-iso8859-9 82) nil (make-char 'latin-iso8859-14 82) (make-char 'latin-iso8859-15 82) (make-char 'latin-iso8859-16 82) nil nil #xD2) table)
    (put-char-table (make-char 'latin-iso8859-1 83) (vector #x1F7 (make-char 'latin-iso8859-1 83) (make-char 'latin-iso8859-2 83) (make-char 'latin-iso8859-3 83) nil (make-char 'latin-iso8859-9 83) (make-char 'latin-iso8859-13 83) (make-char 'latin-iso8859-14 83) (make-char 'latin-iso8859-15 83) (make-char 'latin-iso8859-16 83) nil nil #xD3) table)
    (put-char-table (make-char 'latin-iso8859-1 84) (vector #x1DF (make-char 'latin-iso8859-1 84) (make-char 'latin-iso8859-2 84) (make-char 'latin-iso8859-3 84) (make-char 'latin-iso8859-4 84) (make-char 'latin-iso8859-9 84) nil (make-char 'latin-iso8859-14 84) (make-char 'latin-iso8859-15 84) (make-char 'latin-iso8859-16 84) nil nil #xD4) table)
    (put-char-table (make-char 'latin-iso8859-1 85) (vector #xF9 (make-char 'latin-iso8859-1 85) nil nil (make-char 'latin-iso8859-4 85) (make-char 'latin-iso8859-9 85) (make-char 'latin-iso8859-13 85) (make-char 'latin-iso8859-14 85) (make-char 'latin-iso8859-15 85) nil nil nil #xD5) table)
    (put-char-table (make-char 'latin-iso8859-1 86) (vector #x1FF (make-char 'latin-iso8859-1 86) (make-char 'latin-iso8859-2 86) (make-char 'latin-iso8859-3 86) (make-char 'latin-iso8859-4 86) (make-char 'latin-iso8859-9 86) (make-char 'latin-iso8859-13 86) (make-char 'latin-iso8859-14 86) (make-char 'latin-iso8859-15 86) (make-char 'latin-iso8859-16 86) nil nil #xD6) table)
    (put-char-table (make-char 'latin-iso8859-1 87) (vector #xBF (make-char 'latin-iso8859-1 87) (make-char 'latin-iso8859-2 87) (make-char 'latin-iso8859-3 87) (make-char 'latin-iso8859-4 87) (make-char 'latin-iso8859-9 87) (make-char 'latin-iso8859-13 87) nil (make-char 'latin-iso8859-15 87) nil nil nil #xD7) table)
    (put-char-table (make-char 'latin-iso8859-1 88) (vector #xF9 (make-char 'latin-iso8859-1 88) nil nil (make-char 'latin-iso8859-4 88) (make-char 'latin-iso8859-9 88) (make-char 'latin-iso8859-13 40) (make-char 'latin-iso8859-14 88) (make-char 'latin-iso8859-15 88) nil nil nil #xD8) table)
    (put-char-table (make-char 'latin-iso8859-1 89) (vector #x1D5 (make-char 'latin-iso8859-1 89) nil (make-char 'latin-iso8859-3 89) nil (make-char 'latin-iso8859-9 89) nil (make-char 'latin-iso8859-14 89) (make-char 'latin-iso8859-15 89) (make-char 'latin-iso8859-16 89) nil nil #xD9) table)
    (put-char-table (make-char 'latin-iso8859-1 90) (vector #x1DF (make-char 'latin-iso8859-1 90) (make-char 'latin-iso8859-2 90) (make-char 'latin-iso8859-3 90) (make-char 'latin-iso8859-4 90) (make-char 'latin-iso8859-9 90) nil (make-char 'latin-iso8859-14 90) (make-char 'latin-iso8859-15 90) (make-char 'latin-iso8859-16 90) nil nil #xDA) table)
    (put-char-table (make-char 'latin-iso8859-1 91) (vector #x1DD (make-char 'latin-iso8859-1 91) nil (make-char 'latin-iso8859-3 91) (make-char 'latin-iso8859-4 91) (make-char 'latin-iso8859-9 91) nil (make-char 'latin-iso8859-14 91) (make-char 'latin-iso8859-15 91) (make-char 'latin-iso8859-16 91) nil nil #xDB) table)
    (put-char-table (make-char 'latin-iso8859-1 92) (vector #x1FF (make-char 'latin-iso8859-1 92) (make-char 'latin-iso8859-2 92) (make-char 'latin-iso8859-3 92) (make-char 'latin-iso8859-4 92) (make-char 'latin-iso8859-9 92) (make-char 'latin-iso8859-13 92) (make-char 'latin-iso8859-14 92) (make-char 'latin-iso8859-15 92) (make-char 'latin-iso8859-16 92) nil nil #xDC) table)
    (put-char-table (make-char 'latin-iso8859-1 93) (vector #xC3 (make-char 'latin-iso8859-1 93) (make-char 'latin-iso8859-2 93) nil nil nil nil (make-char 'latin-iso8859-14 93) (make-char 'latin-iso8859-15 93) nil nil nil #xDD) table)
    (put-char-table (make-char 'latin-iso8859-1 94) (vector #x81 (make-char 'latin-iso8859-1 94) nil nil nil nil nil nil (make-char 'latin-iso8859-15 94) nil nil nil #xDE) table)
    (put-char-table (make-char 'latin-iso8859-1 95) (vector #x1FF (make-char 'latin-iso8859-1 95) (make-char 'latin-iso8859-2 95) (make-char 'latin-iso8859-3 95) (make-char 'latin-iso8859-4 95) (make-char 'latin-iso8859-9 95) (make-char 'latin-iso8859-13 95) (make-char 'latin-iso8859-14 95) (make-char 'latin-iso8859-15 95) (make-char 'latin-iso8859-16 95) nil nil #xDF) table)
    (put-char-table (make-char 'latin-iso8859-1 96) (vector #x1D5 (make-char 'latin-iso8859-1 96) nil (make-char 'latin-iso8859-3 96) nil (make-char 'latin-iso8859-9 96) nil (make-char 'latin-iso8859-14 96) (make-char 'latin-iso8859-15 96) (make-char 'latin-iso8859-16 96) nil nil #xE0) table)
    (put-char-table (make-char 'latin-iso8859-1 97) (vector #x1DF (make-char 'latin-iso8859-1 97) (make-char 'latin-iso8859-2 97) (make-char 'latin-iso8859-3 97) (make-char 'latin-iso8859-4 97) (make-char 'latin-iso8859-9 97) nil (make-char 'latin-iso8859-14 97) (make-char 'latin-iso8859-15 97) (make-char 'latin-iso8859-16 97) nil nil #xE1) table)
    (put-char-table (make-char 'latin-iso8859-1 98) (vector #x1DF (make-char 'latin-iso8859-1 98) (make-char 'latin-iso8859-2 98) (make-char 'latin-iso8859-3 98) (make-char 'latin-iso8859-4 98) (make-char 'latin-iso8859-9 98) nil (make-char 'latin-iso8859-14 98) (make-char 'latin-iso8859-15 98) (make-char 'latin-iso8859-16 98) nil nil #xE2) table)
    (put-char-table (make-char 'latin-iso8859-1 99) (vector #xD9 (make-char 'latin-iso8859-1 99) nil nil (make-char 'latin-iso8859-4 99) (make-char 'latin-iso8859-9 99) nil (make-char 'latin-iso8859-14 99) (make-char 'latin-iso8859-15 99) nil nil nil #xE3) table)
    (put-char-table (make-char 'latin-iso8859-1 100) (vector #x1FF (make-char 'latin-iso8859-1 100) (make-char 'latin-iso8859-2 100) (make-char 'latin-iso8859-3 100) (make-char 'latin-iso8859-4 100) (make-char 'latin-iso8859-9 100) (make-char 'latin-iso8859-13 100) (make-char 'latin-iso8859-14 100) (make-char 'latin-iso8859-15 100) (make-char 'latin-iso8859-16 100) nil nil #xE4) table)
    (put-char-table (make-char 'latin-iso8859-1 101) (vector #xF9 (make-char 'latin-iso8859-1 101) nil nil (make-char 'latin-iso8859-4 101) (make-char 'latin-iso8859-9 101) (make-char 'latin-iso8859-13 101) (make-char 'latin-iso8859-14 101) (make-char 'latin-iso8859-15 101) nil nil nil #xE5) table)
    (put-char-table (make-char 'latin-iso8859-1 102) (vector #x1F9 (make-char 'latin-iso8859-1 102) nil nil (make-char 'latin-iso8859-4 102) (make-char 'latin-iso8859-9 102) (make-char 'latin-iso8859-13 63) (make-char 'latin-iso8859-14 102) (make-char 'latin-iso8859-15 102) (make-char 'latin-iso8859-16 102) nil nil #xE6) table)
    (put-char-table (make-char 'latin-iso8859-1 103) (vector #x1D7 (make-char 'latin-iso8859-1 103) (make-char 'latin-iso8859-2 103) (make-char 'latin-iso8859-3 103) nil (make-char 'latin-iso8859-9 103) nil (make-char 'latin-iso8859-14 103) (make-char 'latin-iso8859-15 103) (make-char 'latin-iso8859-16 103) nil nil #xE7) table)
    (put-char-table (make-char 'latin-iso8859-1 104) (vector #x1D5 (make-char 'latin-iso8859-1 104) nil (make-char 'latin-iso8859-3 104) nil (make-char 'latin-iso8859-9 104) nil (make-char 'latin-iso8859-14 104) (make-char 'latin-iso8859-15 104) (make-char 'latin-iso8859-16 104) nil nil #xE8) table)
    (put-char-table (make-char 'latin-iso8859-1 105) (vector #x1FF (make-char 'latin-iso8859-1 105) (make-char 'latin-iso8859-2 105) (make-char 'latin-iso8859-3 105) (make-char 'latin-iso8859-4 105) (make-char 'latin-iso8859-9 105) (make-char 'latin-iso8859-13 105) (make-char 'latin-iso8859-14 105) (make-char 'latin-iso8859-15 105) (make-char 'latin-iso8859-16 105) nil nil #xE9) table)
    (put-char-table (make-char 'latin-iso8859-1 106) (vector #x1D5 (make-char 'latin-iso8859-1 106) nil (make-char 'latin-iso8859-3 106) nil (make-char 'latin-iso8859-9 106) nil (make-char 'latin-iso8859-14 106) (make-char 'latin-iso8859-15 106) (make-char 'latin-iso8859-16 106) nil nil #xEA) table)
    (put-char-table (make-char 'latin-iso8859-1 107) (vector #x1DF (make-char 'latin-iso8859-1 107) (make-char 'latin-iso8859-2 107) (make-char 'latin-iso8859-3 107) (make-char 'latin-iso8859-4 107) (make-char 'latin-iso8859-9 107) nil (make-char 'latin-iso8859-14 107) (make-char 'latin-iso8859-15 107) (make-char 'latin-iso8859-16 107) nil nil #xEB) table)
    (put-char-table (make-char 'latin-iso8859-1 108) (vector #x1D5 (make-char 'latin-iso8859-1 108) nil (make-char 'latin-iso8859-3 108) nil (make-char 'latin-iso8859-9 108) nil (make-char 'latin-iso8859-14 108) (make-char 'latin-iso8859-15 108) (make-char 'latin-iso8859-16 108) nil nil #xEC) table)
    (put-char-table (make-char 'latin-iso8859-1 109) (vector #x1DF (make-char 'latin-iso8859-1 109) (make-char 'latin-iso8859-2 109) (make-char 'latin-iso8859-3 109) (make-char 'latin-iso8859-4 109) (make-char 'latin-iso8859-9 109) nil (make-char 'latin-iso8859-14 109) (make-char 'latin-iso8859-15 109) (make-char 'latin-iso8859-16 109) nil nil #xED) table)
    (put-char-table (make-char 'latin-iso8859-1 110) (vector #x1DF (make-char 'latin-iso8859-1 110) (make-char 'latin-iso8859-2 110) (make-char 'latin-iso8859-3 110) (make-char 'latin-iso8859-4 110) (make-char 'latin-iso8859-9 110) nil (make-char 'latin-iso8859-14 110) (make-char 'latin-iso8859-15 110) (make-char 'latin-iso8859-16 110) nil nil #xEE) table)
    (put-char-table (make-char 'latin-iso8859-1 111) (vector #x1D5 (make-char 'latin-iso8859-1 111) nil (make-char 'latin-iso8859-3 111) nil (make-char 'latin-iso8859-9 111) nil (make-char 'latin-iso8859-14 111) (make-char 'latin-iso8859-15 111) (make-char 'latin-iso8859-16 111) nil nil #xEF) table)
    (put-char-table (make-char 'latin-iso8859-1 112) (vector #x81 (make-char 'latin-iso8859-1 112) nil nil nil nil nil nil (make-char 'latin-iso8859-15 112) nil nil nil #xF0) table)
    (put-char-table (make-char 'latin-iso8859-1 113) (vector #xD5 (make-char 'latin-iso8859-1 113) nil (make-char 'latin-iso8859-3 113) nil (make-char 'latin-iso8859-9 113) nil (make-char 'latin-iso8859-14 113) (make-char 'latin-iso8859-15 113) nil nil nil #xF1) table)
    (put-char-table (make-char 'latin-iso8859-1 114) (vector #x1D5 (make-char 'latin-iso8859-1 114) nil (make-char 'latin-iso8859-3 114) nil (make-char 'latin-iso8859-9 114) nil (make-char 'latin-iso8859-14 114) (make-char 'latin-iso8859-15 114) (make-char 'latin-iso8859-16 114) nil nil #xF2) table)
    (put-char-table (make-char 'latin-iso8859-1 115) (vector #x1F7 (make-char 'latin-iso8859-1 115) (make-char 'latin-iso8859-2 115) (make-char 'latin-iso8859-3 115) nil (make-char 'latin-iso8859-9 115) (make-char 'latin-iso8859-13 115) (make-char 'latin-iso8859-14 115) (make-char 'latin-iso8859-15 115) (make-char 'latin-iso8859-16 115) nil nil #xF3) table)
    (put-char-table (make-char 'latin-iso8859-1 116) (vector #x1DF (make-char 'latin-iso8859-1 116) (make-char 'latin-iso8859-2 116) (make-char 'latin-iso8859-3 116) (make-char 'latin-iso8859-4 116) (make-char 'latin-iso8859-9 116) nil (make-char 'latin-iso8859-14 116) (make-char 'latin-iso8859-15 116) (make-char 'latin-iso8859-16 116) nil nil #xF4) table)
    (put-char-table (make-char 'latin-iso8859-1 117) (vector #xF9 (make-char 'latin-iso8859-1 117) nil nil (make-char 'latin-iso8859-4 117) (make-char 'latin-iso8859-9 117) (make-char 'latin-iso8859-13 117) (make-char 'latin-iso8859-14 117) (make-char 'latin-iso8859-15 117) nil nil nil #xF5) table)
    (put-char-table (make-char 'latin-iso8859-1 118) (vector #x1FF (make-char 'latin-iso8859-1 118) (make-char 'latin-iso8859-2 118) (make-char 'latin-iso8859-3 118) (make-char 'latin-iso8859-4 118) (make-char 'latin-iso8859-9 118) (make-char 'latin-iso8859-13 118) (make-char 'latin-iso8859-14 118) (make-char 'latin-iso8859-15 118) (make-char 'latin-iso8859-16 118) nil nil #xF6) table)
    (put-char-table (make-char 'latin-iso8859-1 119) (vector #xBF (make-char 'latin-iso8859-1 119) (make-char 'latin-iso8859-2 119) (make-char 'latin-iso8859-3 119) (make-char 'latin-iso8859-4 119) (make-char 'latin-iso8859-9 119) (make-char 'latin-iso8859-13 119) nil (make-char 'latin-iso8859-15 119) nil nil nil #xF7) table)
    (put-char-table (make-char 'latin-iso8859-1 120) (vector #xF9 (make-char 'latin-iso8859-1 120) nil nil (make-char 'latin-iso8859-4 120) (make-char 'latin-iso8859-9 120) (make-char 'latin-iso8859-13 56) (make-char 'latin-iso8859-14 120) (make-char 'latin-iso8859-15 120) nil nil nil #xF8) table)
    (put-char-table (make-char 'latin-iso8859-1 121) (vector #x1D5 (make-char 'latin-iso8859-1 121) nil (make-char 'latin-iso8859-3 121) nil (make-char 'latin-iso8859-9 121) nil (make-char 'latin-iso8859-14 121) (make-char 'latin-iso8859-15 121) (make-char 'latin-iso8859-16 121) nil nil #xF9) table)
    (put-char-table (make-char 'latin-iso8859-1 122) (vector #x1DF (make-char 'latin-iso8859-1 122) (make-char 'latin-iso8859-2 122) (make-char 'latin-iso8859-3 122) (make-char 'latin-iso8859-4 122) (make-char 'latin-iso8859-9 122) nil (make-char 'latin-iso8859-14 122) (make-char 'latin-iso8859-15 122) (make-char 'latin-iso8859-16 122) nil nil #xFA) table)
    (put-char-table (make-char 'latin-iso8859-1 123) (vector #x1DD (make-char 'latin-iso8859-1 123) nil (make-char 'latin-iso8859-3 123) (make-char 'latin-iso8859-4 123) (make-char 'latin-iso8859-9 123) nil (make-char 'latin-iso8859-14 123) (make-char 'latin-iso8859-15 123) (make-char 'latin-iso8859-16 123) nil nil #xFB) table)
    (put-char-table (make-char 'latin-iso8859-1 124) (vector #x1FF (make-char 'latin-iso8859-1 124) (make-char 'latin-iso8859-2 124) (make-char 'latin-iso8859-3 124) (make-char 'latin-iso8859-4 124) (make-char 'latin-iso8859-9 124) (make-char 'latin-iso8859-13 124) (make-char 'latin-iso8859-14 124) (make-char 'latin-iso8859-15 124) (make-char 'latin-iso8859-16 124) nil nil #xFC) table)
    (put-char-table (make-char 'latin-iso8859-1 125) (vector #xC3 (make-char 'latin-iso8859-1 125) (make-char 'latin-iso8859-2 125) nil nil nil nil (make-char 'latin-iso8859-14 125) (make-char 'latin-iso8859-15 125) nil nil nil #xFD) table)
    (put-char-table (make-char 'latin-iso8859-1 126) (vector #x81 (make-char 'latin-iso8859-1 126) nil nil nil nil nil nil (make-char 'latin-iso8859-15 126) nil nil nil #xFE) table)
    (put-char-table (make-char 'latin-iso8859-1 127) (vector #x1D1 (make-char 'latin-iso8859-1 127) nil nil nil (make-char 'latin-iso8859-9 127) nil (make-char 'latin-iso8859-14 127) (make-char 'latin-iso8859-15 127) (make-char 'latin-iso8859-16 127) nil nil #xFF) table)
    (put-char-table (make-char 'latin-iso8859-2 32) (vector #x1FF (make-char 'latin-iso8859-1 32) (make-char 'latin-iso8859-2 32) (make-char 'latin-iso8859-3 32) (make-char 'latin-iso8859-4 32) (make-char 'latin-iso8859-9 32) (make-char 'latin-iso8859-13 32) (make-char 'latin-iso8859-14 32) (make-char 'latin-iso8859-15 32) (make-char 'latin-iso8859-16 32) nil nil #xA0) table)
    (put-char-table (make-char 'latin-iso8859-2 33) (vector #x12A nil (make-char 'latin-iso8859-2 33) nil (make-char 'latin-iso8859-4 33) nil (make-char 'latin-iso8859-13 64) nil nil (make-char 'latin-iso8859-16 33) nil nil #x104) table)
    (put-char-table (make-char 'latin-iso8859-2 34) (vector #x6 nil (make-char 'latin-iso8859-2 34) (make-char 'latin-iso8859-3 34) nil nil nil nil nil nil nil nil #x2D8) table)
    (put-char-table (make-char 'latin-iso8859-2 35) (vector #x122 nil (make-char 'latin-iso8859-2 35) nil nil nil (make-char 'latin-iso8859-13 89) nil nil (make-char 'latin-iso8859-16 35) nil nil #x141) table)
    (put-char-table (make-char 'latin-iso8859-2 36) (vector #x3F (make-char 'latin-iso8859-1 36) (make-char 'latin-iso8859-2 36) (make-char 'latin-iso8859-3 36) (make-char 'latin-iso8859-4 36) (make-char 'latin-iso8859-9 36) (make-char 'latin-iso8859-13 36) nil nil nil nil nil #xA4) table)
    (put-char-table (make-char 'latin-iso8859-2 37) (vector #x2 nil (make-char 'latin-iso8859-2 37) nil nil nil nil nil nil nil nil nil #x13D) table)
    (put-char-table (make-char 'latin-iso8859-2 38) (vector #x122 nil (make-char 'latin-iso8859-2 38) nil nil nil (make-char 'latin-iso8859-13 90) nil nil (make-char 'latin-iso8859-16 87) nil nil #x15A) table)
    (put-char-table (make-char 'latin-iso8859-2 39) (vector #x1FF (make-char 'latin-iso8859-1 39) (make-char 'latin-iso8859-2 39) (make-char 'latin-iso8859-3 39) (make-char 'latin-iso8859-4 39) (make-char 'latin-iso8859-9 39) (make-char 'latin-iso8859-13 39) (make-char 'latin-iso8859-14 39) (make-char 'latin-iso8859-15 39) (make-char 'latin-iso8859-16 39) nil nil #xA7) table)
    (put-char-table (make-char 'latin-iso8859-2 40) (vector #x1F (make-char 'latin-iso8859-1 40) (make-char 'latin-iso8859-2 40) (make-char 'latin-iso8859-3 40) (make-char 'latin-iso8859-4 40) (make-char 'latin-iso8859-9 40) nil nil nil nil nil nil #xA8) table)
    (put-char-table (make-char 'latin-iso8859-2 41) (vector #x1AA nil (make-char 'latin-iso8859-2 41) nil (make-char 'latin-iso8859-4 41) nil (make-char 'latin-iso8859-13 80) nil (make-char 'latin-iso8859-15 38) (make-char 'latin-iso8859-16 38) nil nil #x160) table)
    (put-char-table (make-char 'latin-iso8859-2 42) (vector #x16 nil (make-char 'latin-iso8859-2 42) (make-char 'latin-iso8859-3 42) nil (make-char 'latin-iso8859-9 94) nil nil nil nil nil nil #x15E) table)
    (put-char-table (make-char 'latin-iso8859-2 43) (vector #x2 nil (make-char 'latin-iso8859-2 43) nil nil nil nil nil nil nil nil nil #x164) table)
    (put-char-table (make-char 'latin-iso8859-2 44) (vector #x122 nil (make-char 'latin-iso8859-2 44) nil nil nil (make-char 'latin-iso8859-13 74) nil nil (make-char 'latin-iso8859-16 44) nil nil #x179) table)
    (put-char-table (make-char 'latin-iso8859-2 45) (vector #x1FF (make-char 'latin-iso8859-1 45) (make-char 'latin-iso8859-2 45) (make-char 'latin-iso8859-3 45) (make-char 'latin-iso8859-4 45) (make-char 'latin-iso8859-9 45) (make-char 'latin-iso8859-13 45) (make-char 'latin-iso8859-14 45) (make-char 'latin-iso8859-15 45) (make-char 'latin-iso8859-16 45) nil nil #xAD) table)
    (put-char-table (make-char 'latin-iso8859-2 46) (vector #x1AA nil (make-char 'latin-iso8859-2 46) nil (make-char 'latin-iso8859-4 46) nil (make-char 'latin-iso8859-13 94) nil (make-char 'latin-iso8859-15 52) (make-char 'latin-iso8859-16 52) nil nil #x17D) table)
    (put-char-table (make-char 'latin-iso8859-2 47) (vector #x126 nil (make-char 'latin-iso8859-2 47) (make-char 'latin-iso8859-3 47) nil nil (make-char 'latin-iso8859-13 93) nil nil (make-char 'latin-iso8859-16 47) nil nil #x17B) table)
    (put-char-table (make-char 'latin-iso8859-2 48) (vector #x1BF (make-char 'latin-iso8859-1 48) (make-char 'latin-iso8859-2 48) (make-char 'latin-iso8859-3 48) (make-char 'latin-iso8859-4 48) (make-char 'latin-iso8859-9 48) (make-char 'latin-iso8859-13 48) nil (make-char 'latin-iso8859-15 48) (make-char 'latin-iso8859-16 48) nil nil #xB0) table)
    (put-char-table (make-char 'latin-iso8859-2 49) (vector #x12A nil (make-char 'latin-iso8859-2 49) nil (make-char 'latin-iso8859-4 49) nil (make-char 'latin-iso8859-13 96) nil nil (make-char 'latin-iso8859-16 34) nil nil #x105) table)
    (put-char-table (make-char 'latin-iso8859-2 50) (vector #xA nil (make-char 'latin-iso8859-2 50) nil (make-char 'latin-iso8859-4 50) nil nil nil nil nil nil nil #x2DB) table)
    (put-char-table (make-char 'latin-iso8859-2 51) (vector #x122 nil (make-char 'latin-iso8859-2 51) nil nil nil (make-char 'latin-iso8859-13 121) nil nil (make-char 'latin-iso8859-16 51) nil nil #x142) table)
    (put-char-table (make-char 'latin-iso8859-2 52) (vector #x1F (make-char 'latin-iso8859-1 52) (make-char 'latin-iso8859-2 52) (make-char 'latin-iso8859-3 52) (make-char 'latin-iso8859-4 52) (make-char 'latin-iso8859-9 52) nil nil nil nil nil nil #xB4) table)
    (put-char-table (make-char 'latin-iso8859-2 53) (vector #x2 nil (make-char 'latin-iso8859-2 53) nil nil nil nil nil nil nil nil nil #x13E) table)
    (put-char-table (make-char 'latin-iso8859-2 54) (vector #x122 nil (make-char 'latin-iso8859-2 54) nil nil nil (make-char 'latin-iso8859-13 122) nil nil (make-char 'latin-iso8859-16 119) nil nil #x15B) table)
    (put-char-table (make-char 'latin-iso8859-2 55) (vector #xA nil (make-char 'latin-iso8859-2 55) nil (make-char 'latin-iso8859-4 55) nil nil nil nil nil nil nil #x2C7) table)
    (put-char-table (make-char 'latin-iso8859-2 56) (vector #x1F (make-char 'latin-iso8859-1 56) (make-char 'latin-iso8859-2 56) (make-char 'latin-iso8859-3 56) (make-char 'latin-iso8859-4 56) (make-char 'latin-iso8859-9 56) nil nil nil nil nil nil #xB8) table)
    (put-char-table (make-char 'latin-iso8859-2 57) (vector #x1AA nil (make-char 'latin-iso8859-2 57) nil (make-char 'latin-iso8859-4 57) nil (make-char 'latin-iso8859-13 112) nil (make-char 'latin-iso8859-15 40) (make-char 'latin-iso8859-16 40) nil nil #x161) table)
    (put-char-table (make-char 'latin-iso8859-2 58) (vector #x16 nil (make-char 'latin-iso8859-2 58) (make-char 'latin-iso8859-3 58) nil (make-char 'latin-iso8859-9 126) nil nil nil nil nil nil #x15F) table)
    (put-char-table (make-char 'latin-iso8859-2 59) (vector #x2 nil (make-char 'latin-iso8859-2 59) nil nil nil nil nil nil nil nil nil #x165) table)
    (put-char-table (make-char 'latin-iso8859-2 60) (vector #x122 nil (make-char 'latin-iso8859-2 60) nil nil nil (make-char 'latin-iso8859-13 106) nil nil (make-char 'latin-iso8859-16 46) nil nil #x17A) table)
    (put-char-table (make-char 'latin-iso8859-2 61) (vector #x2 nil (make-char 'latin-iso8859-2 61) nil nil nil nil nil nil nil nil nil #x2DD) table)
    (put-char-table (make-char 'latin-iso8859-2 62) (vector #x1AA nil (make-char 'latin-iso8859-2 62) nil (make-char 'latin-iso8859-4 62) nil (make-char 'latin-iso8859-13 126) nil (make-char 'latin-iso8859-15 56) (make-char 'latin-iso8859-16 56) nil nil #x17E) table)
    (put-char-table (make-char 'latin-iso8859-2 63) (vector #x126 nil (make-char 'latin-iso8859-2 63) (make-char 'latin-iso8859-3 63) nil nil (make-char 'latin-iso8859-13 125) nil nil (make-char 'latin-iso8859-16 63) nil nil #x17C) table)
    (put-char-table (make-char 'latin-iso8859-2 64) (vector #x2 nil (make-char 'latin-iso8859-2 64) nil nil nil nil nil nil nil nil nil #x154) table)
    (put-char-table (make-char 'latin-iso8859-2 65) (vector #x1DF (make-char 'latin-iso8859-1 65) (make-char 'latin-iso8859-2 65) (make-char 'latin-iso8859-3 65) (make-char 'latin-iso8859-4 65) (make-char 'latin-iso8859-9 65) nil (make-char 'latin-iso8859-14 65) (make-char 'latin-iso8859-15 65) (make-char 'latin-iso8859-16 65) nil nil #xC1) table)
    (put-char-table (make-char 'latin-iso8859-2 66) (vector #x1DF (make-char 'latin-iso8859-1 66) (make-char 'latin-iso8859-2 66) (make-char 'latin-iso8859-3 66) (make-char 'latin-iso8859-4 66) (make-char 'latin-iso8859-9 66) nil (make-char 'latin-iso8859-14 66) (make-char 'latin-iso8859-15 66) (make-char 'latin-iso8859-16 66) nil nil #xC2) table)
    (put-char-table (make-char 'latin-iso8859-2 67) (vector #x102 nil (make-char 'latin-iso8859-2 67) nil nil nil nil nil nil (make-char 'latin-iso8859-16 67) nil nil #x102) table)
    (put-char-table (make-char 'latin-iso8859-2 68) (vector #x1FF (make-char 'latin-iso8859-1 68) (make-char 'latin-iso8859-2 68) (make-char 'latin-iso8859-3 68) (make-char 'latin-iso8859-4 68) (make-char 'latin-iso8859-9 68) (make-char 'latin-iso8859-13 68) (make-char 'latin-iso8859-14 68) (make-char 'latin-iso8859-15 68) (make-char 'latin-iso8859-16 68) nil nil #xC4) table)
    (put-char-table (make-char 'latin-iso8859-2 69) (vector #x2 nil (make-char 'latin-iso8859-2 69) nil nil nil nil nil nil nil nil nil #x139) table)
    (put-char-table (make-char 'latin-iso8859-2 70) (vector #x122 nil (make-char 'latin-iso8859-2 70) nil nil nil (make-char 'latin-iso8859-13 67) nil nil (make-char 'latin-iso8859-16 69) nil nil #x106) table)
    (put-char-table (make-char 'latin-iso8859-2 71) (vector #x1D7 (make-char 'latin-iso8859-1 71) (make-char 'latin-iso8859-2 71) (make-char 'latin-iso8859-3 71) nil (make-char 'latin-iso8859-9 71) nil (make-char 'latin-iso8859-14 71) (make-char 'latin-iso8859-15 71) (make-char 'latin-iso8859-16 71) nil nil #xC7) table)
    (put-char-table (make-char 'latin-iso8859-2 72) (vector #x12A nil (make-char 'latin-iso8859-2 72) nil (make-char 'latin-iso8859-4 72) nil (make-char 'latin-iso8859-13 72) nil nil (make-char 'latin-iso8859-16 50) nil nil #x10C) table)
    (put-char-table (make-char 'latin-iso8859-2 73) (vector #x1FF (make-char 'latin-iso8859-1 73) (make-char 'latin-iso8859-2 73) (make-char 'latin-iso8859-3 73) (make-char 'latin-iso8859-4 73) (make-char 'latin-iso8859-9 73) (make-char 'latin-iso8859-13 73) (make-char 'latin-iso8859-14 73) (make-char 'latin-iso8859-15 73) (make-char 'latin-iso8859-16 73) nil nil #xC9) table)
    (put-char-table (make-char 'latin-iso8859-2 74) (vector #x12A nil (make-char 'latin-iso8859-2 74) nil (make-char 'latin-iso8859-4 74) nil (make-char 'latin-iso8859-13 70) nil nil (make-char 'latin-iso8859-16 93) nil nil #x118) table)
    (put-char-table (make-char 'latin-iso8859-2 75) (vector #x1DF (make-char 'latin-iso8859-1 75) (make-char 'latin-iso8859-2 75) (make-char 'latin-iso8859-3 75) (make-char 'latin-iso8859-4 75) (make-char 'latin-iso8859-9 75) nil (make-char 'latin-iso8859-14 75) (make-char 'latin-iso8859-15 75) (make-char 'latin-iso8859-16 75) nil nil #xCB) table)
    (put-char-table (make-char 'latin-iso8859-2 76) (vector #x2 nil (make-char 'latin-iso8859-2 76) nil nil nil nil nil nil nil nil nil #x11A) table)
    (put-char-table (make-char 'latin-iso8859-2 77) (vector #x1DF (make-char 'latin-iso8859-1 77) (make-char 'latin-iso8859-2 77) (make-char 'latin-iso8859-3 77) (make-char 'latin-iso8859-4 77) (make-char 'latin-iso8859-9 77) nil (make-char 'latin-iso8859-14 77) (make-char 'latin-iso8859-15 77) (make-char 'latin-iso8859-16 77) nil nil #xCD) table)
    (put-char-table (make-char 'latin-iso8859-2 78) (vector #x1DF (make-char 'latin-iso8859-1 78) (make-char 'latin-iso8859-2 78) (make-char 'latin-iso8859-3 78) (make-char 'latin-iso8859-4 78) (make-char 'latin-iso8859-9 78) nil (make-char 'latin-iso8859-14 78) (make-char 'latin-iso8859-15 78) (make-char 'latin-iso8859-16 78) nil nil #xCE) table)
    (put-char-table (make-char 'latin-iso8859-2 79) (vector #x2 nil (make-char 'latin-iso8859-2 79) nil nil nil nil nil nil nil nil nil #x10E) table)
    (put-char-table (make-char 'latin-iso8859-2 80) (vector #x10A nil (make-char 'latin-iso8859-2 80) nil (make-char 'latin-iso8859-4 80) nil nil nil nil (make-char 'latin-iso8859-16 80) nil nil #x110) table)
    (put-char-table (make-char 'latin-iso8859-2 81) (vector #x122 nil (make-char 'latin-iso8859-2 81) nil nil nil (make-char 'latin-iso8859-13 81) nil nil (make-char 'latin-iso8859-16 81) nil nil #x143) table)
    (put-char-table (make-char 'latin-iso8859-2 82) (vector #x2 nil (make-char 'latin-iso8859-2 82) nil nil nil nil nil nil nil nil nil #x147) table)
    (put-char-table (make-char 'latin-iso8859-2 83) (vector #x1F7 (make-char 'latin-iso8859-1 83) (make-char 'latin-iso8859-2 83) (make-char 'latin-iso8859-3 83) nil (make-char 'latin-iso8859-9 83) (make-char 'latin-iso8859-13 83) (make-char 'latin-iso8859-14 83) (make-char 'latin-iso8859-15 83) (make-char 'latin-iso8859-16 83) nil nil #xD3) table)
    (put-char-table (make-char 'latin-iso8859-2 84) (vector #x1DF (make-char 'latin-iso8859-1 84) (make-char 'latin-iso8859-2 84) (make-char 'latin-iso8859-3 84) (make-char 'latin-iso8859-4 84) (make-char 'latin-iso8859-9 84) nil (make-char 'latin-iso8859-14 84) (make-char 'latin-iso8859-15 84) (make-char 'latin-iso8859-16 84) nil nil #xD4) table)
    (put-char-table (make-char 'latin-iso8859-2 85) (vector #x102 nil (make-char 'latin-iso8859-2 85) nil nil nil nil nil nil (make-char 'latin-iso8859-16 85) nil nil #x150) table)
    (put-char-table (make-char 'latin-iso8859-2 86) (vector #x1FF (make-char 'latin-iso8859-1 86) (make-char 'latin-iso8859-2 86) (make-char 'latin-iso8859-3 86) (make-char 'latin-iso8859-4 86) (make-char 'latin-iso8859-9 86) (make-char 'latin-iso8859-13 86) (make-char 'latin-iso8859-14 86) (make-char 'latin-iso8859-15 86) (make-char 'latin-iso8859-16 86) nil nil #xD6) table)
    (put-char-table (make-char 'latin-iso8859-2 87) (vector #xBF (make-char 'latin-iso8859-1 87) (make-char 'latin-iso8859-2 87) (make-char 'latin-iso8859-3 87) (make-char 'latin-iso8859-4 87) (make-char 'latin-iso8859-9 87) (make-char 'latin-iso8859-13 87) nil (make-char 'latin-iso8859-15 87) nil nil nil #xD7) table)
    (put-char-table (make-char 'latin-iso8859-2 88) (vector #x2 nil (make-char 'latin-iso8859-2 88) nil nil nil nil nil nil nil nil nil #x158) table)
    (put-char-table (make-char 'latin-iso8859-2 89) (vector #x2 nil (make-char 'latin-iso8859-2 89) nil nil nil nil nil nil nil nil nil #x16E) table)
    (put-char-table (make-char 'latin-iso8859-2 90) (vector #x1DF (make-char 'latin-iso8859-1 90) (make-char 'latin-iso8859-2 90) (make-char 'latin-iso8859-3 90) (make-char 'latin-iso8859-4 90) (make-char 'latin-iso8859-9 90) nil (make-char 'latin-iso8859-14 90) (make-char 'latin-iso8859-15 90) (make-char 'latin-iso8859-16 90) nil nil #xDA) table)
    (put-char-table (make-char 'latin-iso8859-2 91) (vector #x102 nil (make-char 'latin-iso8859-2 91) nil nil nil nil nil nil (make-char 'latin-iso8859-16 88) nil nil #x170) table)
    (put-char-table (make-char 'latin-iso8859-2 92) (vector #x1FF (make-char 'latin-iso8859-1 92) (make-char 'latin-iso8859-2 92) (make-char 'latin-iso8859-3 92) (make-char 'latin-iso8859-4 92) (make-char 'latin-iso8859-9 92) (make-char 'latin-iso8859-13 92) (make-char 'latin-iso8859-14 92) (make-char 'latin-iso8859-15 92) (make-char 'latin-iso8859-16 92) nil nil #xDC) table)
    (put-char-table (make-char 'latin-iso8859-2 93) (vector #xC3 (make-char 'latin-iso8859-1 93) (make-char 'latin-iso8859-2 93) nil nil nil nil (make-char 'latin-iso8859-14 93) (make-char 'latin-iso8859-15 93) nil nil nil #xDD) table)
    (put-char-table (make-char 'latin-iso8859-2 94) (vector #x2 nil (make-char 'latin-iso8859-2 94) nil nil nil nil nil nil nil nil nil #x162) table)
    (put-char-table (make-char 'latin-iso8859-2 95) (vector #x1FF (make-char 'latin-iso8859-1 95) (make-char 'latin-iso8859-2 95) (make-char 'latin-iso8859-3 95) (make-char 'latin-iso8859-4 95) (make-char 'latin-iso8859-9 95) (make-char 'latin-iso8859-13 95) (make-char 'latin-iso8859-14 95) (make-char 'latin-iso8859-15 95) (make-char 'latin-iso8859-16 95) nil nil #xDF) table)
    (put-char-table (make-char 'latin-iso8859-2 96) (vector #x2 nil (make-char 'latin-iso8859-2 96) nil nil nil nil nil nil nil nil nil #x155) table)
    (put-char-table (make-char 'latin-iso8859-2 97) (vector #x1DF (make-char 'latin-iso8859-1 97) (make-char 'latin-iso8859-2 97) (make-char 'latin-iso8859-3 97) (make-char 'latin-iso8859-4 97) (make-char 'latin-iso8859-9 97) nil (make-char 'latin-iso8859-14 97) (make-char 'latin-iso8859-15 97) (make-char 'latin-iso8859-16 97) nil nil #xE1) table)
    (put-char-table (make-char 'latin-iso8859-2 98) (vector #x1DF (make-char 'latin-iso8859-1 98) (make-char 'latin-iso8859-2 98) (make-char 'latin-iso8859-3 98) (make-char 'latin-iso8859-4 98) (make-char 'latin-iso8859-9 98) nil (make-char 'latin-iso8859-14 98) (make-char 'latin-iso8859-15 98) (make-char 'latin-iso8859-16 98) nil nil #xE2) table)
    (put-char-table (make-char 'latin-iso8859-2 99) (vector #x102 nil (make-char 'latin-iso8859-2 99) nil nil nil nil nil nil (make-char 'latin-iso8859-16 99) nil nil #x103) table)
    (put-char-table (make-char 'latin-iso8859-2 100) (vector #x1FF (make-char 'latin-iso8859-1 100) (make-char 'latin-iso8859-2 100) (make-char 'latin-iso8859-3 100) (make-char 'latin-iso8859-4 100) (make-char 'latin-iso8859-9 100) (make-char 'latin-iso8859-13 100) (make-char 'latin-iso8859-14 100) (make-char 'latin-iso8859-15 100) (make-char 'latin-iso8859-16 100) nil nil #xE4) table)
    (put-char-table (make-char 'latin-iso8859-2 101) (vector #x2 nil (make-char 'latin-iso8859-2 101) nil nil nil nil nil nil nil nil nil #x13A) table)
    (put-char-table (make-char 'latin-iso8859-2 102) (vector #x122 nil (make-char 'latin-iso8859-2 102) nil nil nil (make-char 'latin-iso8859-13 99) nil nil (make-char 'latin-iso8859-16 101) nil nil #x107) table)
    (put-char-table (make-char 'latin-iso8859-2 103) (vector #x1D7 (make-char 'latin-iso8859-1 103) (make-char 'latin-iso8859-2 103) (make-char 'latin-iso8859-3 103) nil (make-char 'latin-iso8859-9 103) nil (make-char 'latin-iso8859-14 103) (make-char 'latin-iso8859-15 103) (make-char 'latin-iso8859-16 103) nil nil #xE7) table)
    (put-char-table (make-char 'latin-iso8859-2 104) (vector #x12A nil (make-char 'latin-iso8859-2 104) nil (make-char 'latin-iso8859-4 104) nil (make-char 'latin-iso8859-13 104) nil nil (make-char 'latin-iso8859-16 57) nil nil #x10D) table)
    (put-char-table (make-char 'latin-iso8859-2 105) (vector #x1FF (make-char 'latin-iso8859-1 105) (make-char 'latin-iso8859-2 105) (make-char 'latin-iso8859-3 105) (make-char 'latin-iso8859-4 105) (make-char 'latin-iso8859-9 105) (make-char 'latin-iso8859-13 105) (make-char 'latin-iso8859-14 105) (make-char 'latin-iso8859-15 105) (make-char 'latin-iso8859-16 105) nil nil #xE9) table)
    (put-char-table (make-char 'latin-iso8859-2 106) (vector #x12A nil (make-char 'latin-iso8859-2 106) nil (make-char 'latin-iso8859-4 106) nil (make-char 'latin-iso8859-13 102) nil nil (make-char 'latin-iso8859-16 125) nil nil #x119) table)
    (put-char-table (make-char 'latin-iso8859-2 107) (vector #x1DF (make-char 'latin-iso8859-1 107) (make-char 'latin-iso8859-2 107) (make-char 'latin-iso8859-3 107) (make-char 'latin-iso8859-4 107) (make-char 'latin-iso8859-9 107) nil (make-char 'latin-iso8859-14 107) (make-char 'latin-iso8859-15 107) (make-char 'latin-iso8859-16 107) nil nil #xEB) table)
    (put-char-table (make-char 'latin-iso8859-2 108) (vector #x2 nil (make-char 'latin-iso8859-2 108) nil nil nil nil nil nil nil nil nil #x11B) table)
    (put-char-table (make-char 'latin-iso8859-2 109) (vector #x1DF (make-char 'latin-iso8859-1 109) (make-char 'latin-iso8859-2 109) (make-char 'latin-iso8859-3 109) (make-char 'latin-iso8859-4 109) (make-char 'latin-iso8859-9 109) nil (make-char 'latin-iso8859-14 109) (make-char 'latin-iso8859-15 109) (make-char 'latin-iso8859-16 109) nil nil #xED) table)
    (put-char-table (make-char 'latin-iso8859-2 110) (vector #x1DF (make-char 'latin-iso8859-1 110) (make-char 'latin-iso8859-2 110) (make-char 'latin-iso8859-3 110) (make-char 'latin-iso8859-4 110) (make-char 'latin-iso8859-9 110) nil (make-char 'latin-iso8859-14 110) (make-char 'latin-iso8859-15 110) (make-char 'latin-iso8859-16 110) nil nil #xEE) table)
    (put-char-table (make-char 'latin-iso8859-2 111) (vector #x2 nil (make-char 'latin-iso8859-2 111) nil nil nil nil nil nil nil nil nil #x10F) table)
    (put-char-table (make-char 'latin-iso8859-2 112) (vector #x10A nil (make-char 'latin-iso8859-2 112) nil (make-char 'latin-iso8859-4 112) nil nil nil nil (make-char 'latin-iso8859-16 112) nil nil #x111) table)
    (put-char-table (make-char 'latin-iso8859-2 113) (vector #x122 nil (make-char 'latin-iso8859-2 113) nil nil nil (make-char 'latin-iso8859-13 113) nil nil (make-char 'latin-iso8859-16 113) nil nil #x144) table)
    (put-char-table (make-char 'latin-iso8859-2 114) (vector #x2 nil (make-char 'latin-iso8859-2 114) nil nil nil nil nil nil nil nil nil #x148) table)
    (put-char-table (make-char 'latin-iso8859-2 115) (vector #x1F7 (make-char 'latin-iso8859-1 115) (make-char 'latin-iso8859-2 115) (make-char 'latin-iso8859-3 115) nil (make-char 'latin-iso8859-9 115) (make-char 'latin-iso8859-13 115) (make-char 'latin-iso8859-14 115) (make-char 'latin-iso8859-15 115) (make-char 'latin-iso8859-16 115) nil nil #xF3) table)
    (put-char-table (make-char 'latin-iso8859-2 116) (vector #x1DF (make-char 'latin-iso8859-1 116) (make-char 'latin-iso8859-2 116) (make-char 'latin-iso8859-3 116) (make-char 'latin-iso8859-4 116) (make-char 'latin-iso8859-9 116) nil (make-char 'latin-iso8859-14 116) (make-char 'latin-iso8859-15 116) (make-char 'latin-iso8859-16 116) nil nil #xF4) table)
    (put-char-table (make-char 'latin-iso8859-2 117) (vector #x102 nil (make-char 'latin-iso8859-2 117) nil nil nil nil nil nil (make-char 'latin-iso8859-16 117) nil nil #x151) table)
    (put-char-table (make-char 'latin-iso8859-2 118) (vector #x1FF (make-char 'latin-iso8859-1 118) (make-char 'latin-iso8859-2 118) (make-char 'latin-iso8859-3 118) (make-char 'latin-iso8859-4 118) (make-char 'latin-iso8859-9 118) (make-char 'latin-iso8859-13 118) (make-char 'latin-iso8859-14 118) (make-char 'latin-iso8859-15 118) (make-char 'latin-iso8859-16 118) nil nil #xF6) table)
    (put-char-table (make-char 'latin-iso8859-2 119) (vector #xBF (make-char 'latin-iso8859-1 119) (make-char 'latin-iso8859-2 119) (make-char 'latin-iso8859-3 119) (make-char 'latin-iso8859-4 119) (make-char 'latin-iso8859-9 119) (make-char 'latin-iso8859-13 119) nil (make-char 'latin-iso8859-15 119) nil nil nil #xF7) table)
    (put-char-table (make-char 'latin-iso8859-2 120) (vector #x2 nil (make-char 'latin-iso8859-2 120) nil nil nil nil nil nil nil nil nil #x159) table)
    (put-char-table (make-char 'latin-iso8859-2 121) (vector #x2 nil (make-char 'latin-iso8859-2 121) nil nil nil nil nil nil nil nil nil #x16F) table)
    (put-char-table (make-char 'latin-iso8859-2 122) (vector #x1DF (make-char 'latin-iso8859-1 122) (make-char 'latin-iso8859-2 122) (make-char 'latin-iso8859-3 122) (make-char 'latin-iso8859-4 122) (make-char 'latin-iso8859-9 122) nil (make-char 'latin-iso8859-14 122) (make-char 'latin-iso8859-15 122) (make-char 'latin-iso8859-16 122) nil nil #xFA) table)
    (put-char-table (make-char 'latin-iso8859-2 123) (vector #x102 nil (make-char 'latin-iso8859-2 123) nil nil nil nil nil nil (make-char 'latin-iso8859-16 120) nil nil #x171) table)
    (put-char-table (make-char 'latin-iso8859-2 124) (vector #x1FF (make-char 'latin-iso8859-1 124) (make-char 'latin-iso8859-2 124) (make-char 'latin-iso8859-3 124) (make-char 'latin-iso8859-4 124) (make-char 'latin-iso8859-9 124) (make-char 'latin-iso8859-13 124) (make-char 'latin-iso8859-14 124) (make-char 'latin-iso8859-15 124) (make-char 'latin-iso8859-16 124) nil nil #xFC) table)
    (put-char-table (make-char 'latin-iso8859-2 125) (vector #xC3 (make-char 'latin-iso8859-1 125) (make-char 'latin-iso8859-2 125) nil nil nil nil (make-char 'latin-iso8859-14 125) (make-char 'latin-iso8859-15 125) nil nil nil #xFD) table)
    (put-char-table (make-char 'latin-iso8859-2 126) (vector #x2 nil (make-char 'latin-iso8859-2 126) nil nil nil nil nil nil nil nil nil #x163) table)
    (put-char-table (make-char 'latin-iso8859-2 127) (vector #xE nil (make-char 'latin-iso8859-2 127) (make-char 'latin-iso8859-3 127) (make-char 'latin-iso8859-4 127) nil nil nil nil nil nil nil #x2D9) table)
    (put-char-table (make-char 'latin-iso8859-3 32) (vector #x1FF (make-char 'latin-iso8859-1 32) (make-char 'latin-iso8859-2 32) (make-char 'latin-iso8859-3 32) (make-char 'latin-iso8859-4 32) (make-char 'latin-iso8859-9 32) (make-char 'latin-iso8859-13 32) (make-char 'latin-iso8859-14 32) (make-char 'latin-iso8859-15 32) (make-char 'latin-iso8859-16 32) nil nil #xA0) table)
    (put-char-table (make-char 'latin-iso8859-3 33) (vector #x4 nil nil (make-char 'latin-iso8859-3 33) nil nil nil nil nil nil nil nil #x126) table)
    (put-char-table (make-char 'latin-iso8859-3 34) (vector #x6 nil (make-char 'latin-iso8859-2 34) (make-char 'latin-iso8859-3 34) nil nil nil nil nil nil nil nil #x2D8) table)
    (put-char-table (make-char 'latin-iso8859-3 35) (vector #xF5 (make-char 'latin-iso8859-1 35) nil (make-char 'latin-iso8859-3 35) nil (make-char 'latin-iso8859-9 35) (make-char 'latin-iso8859-13 35) (make-char 'latin-iso8859-14 35) (make-char 'latin-iso8859-15 35) nil nil nil #xA3) table)
    (put-char-table (make-char 'latin-iso8859-3 36) (vector #x3F (make-char 'latin-iso8859-1 36) (make-char 'latin-iso8859-2 36) (make-char 'latin-iso8859-3 36) (make-char 'latin-iso8859-4 36) (make-char 'latin-iso8859-9 36) (make-char 'latin-iso8859-13 36) nil nil nil nil nil #xA4) table)
    (put-char-table (make-char 'latin-iso8859-3 37) (vector #x0 nil nil nil nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-3 38) (vector #x4 nil nil (make-char 'latin-iso8859-3 38) nil nil nil nil nil nil nil nil #x124) table)
    (put-char-table (make-char 'latin-iso8859-3 39) (vector #x1FF (make-char 'latin-iso8859-1 39) (make-char 'latin-iso8859-2 39) (make-char 'latin-iso8859-3 39) (make-char 'latin-iso8859-4 39) (make-char 'latin-iso8859-9 39) (make-char 'latin-iso8859-13 39) (make-char 'latin-iso8859-14 39) (make-char 'latin-iso8859-15 39) (make-char 'latin-iso8859-16 39) nil nil #xA7) table)
    (put-char-table (make-char 'latin-iso8859-3 40) (vector #x1F (make-char 'latin-iso8859-1 40) (make-char 'latin-iso8859-2 40) (make-char 'latin-iso8859-3 40) (make-char 'latin-iso8859-4 40) (make-char 'latin-iso8859-9 40) nil nil nil nil nil nil #xA8) table)
    (put-char-table (make-char 'latin-iso8859-3 41) (vector #x14 nil nil (make-char 'latin-iso8859-3 41) nil (make-char 'latin-iso8859-9 93) nil nil nil nil nil nil #x130) table)
    (put-char-table (make-char 'latin-iso8859-3 42) (vector #x16 nil (make-char 'latin-iso8859-2 42) (make-char 'latin-iso8859-3 42) nil (make-char 'latin-iso8859-9 94) nil nil nil nil nil nil #x15E) table)
    (put-char-table (make-char 'latin-iso8859-3 43) (vector #x14 nil nil (make-char 'latin-iso8859-3 43) nil (make-char 'latin-iso8859-9 80) nil nil nil nil nil nil #x11E) table)
    (put-char-table (make-char 'latin-iso8859-3 44) (vector #x4 nil nil (make-char 'latin-iso8859-3 44) nil nil nil nil nil nil nil nil #x134) table)
    (put-char-table (make-char 'latin-iso8859-3 45) (vector #x1FF (make-char 'latin-iso8859-1 45) (make-char 'latin-iso8859-2 45) (make-char 'latin-iso8859-3 45) (make-char 'latin-iso8859-4 45) (make-char 'latin-iso8859-9 45) (make-char 'latin-iso8859-13 45) (make-char 'latin-iso8859-14 45) (make-char 'latin-iso8859-15 45) (make-char 'latin-iso8859-16 45) nil nil #xAD) table)
    (put-char-table (make-char 'latin-iso8859-3 46) (vector #x0 nil nil nil nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-3 47) (vector #x126 nil (make-char 'latin-iso8859-2 47) (make-char 'latin-iso8859-3 47) nil nil (make-char 'latin-iso8859-13 93) nil nil (make-char 'latin-iso8859-16 47) nil nil #x17B) table)
    (put-char-table (make-char 'latin-iso8859-3 48) (vector #x1BF (make-char 'latin-iso8859-1 48) (make-char 'latin-iso8859-2 48) (make-char 'latin-iso8859-3 48) (make-char 'latin-iso8859-4 48) (make-char 'latin-iso8859-9 48) (make-char 'latin-iso8859-13 48) nil (make-char 'latin-iso8859-15 48) (make-char 'latin-iso8859-16 48) nil nil #xB0) table)
    (put-char-table (make-char 'latin-iso8859-3 49) (vector #x4 nil nil (make-char 'latin-iso8859-3 49) nil nil nil nil nil nil nil nil #x127) table)
    (put-char-table (make-char 'latin-iso8859-3 50) (vector #xB5 (make-char 'latin-iso8859-1 50) nil (make-char 'latin-iso8859-3 50) nil (make-char 'latin-iso8859-9 50) (make-char 'latin-iso8859-13 50) nil (make-char 'latin-iso8859-15 50) nil nil nil #xB2) table)
    (put-char-table (make-char 'latin-iso8859-3 51) (vector #xB5 (make-char 'latin-iso8859-1 51) nil (make-char 'latin-iso8859-3 51) nil (make-char 'latin-iso8859-9 51) (make-char 'latin-iso8859-13 51) nil (make-char 'latin-iso8859-15 51) nil nil nil #xB3) table)
    (put-char-table (make-char 'latin-iso8859-3 52) (vector #x1F (make-char 'latin-iso8859-1 52) (make-char 'latin-iso8859-2 52) (make-char 'latin-iso8859-3 52) (make-char 'latin-iso8859-4 52) (make-char 'latin-iso8859-9 52) nil nil nil nil nil nil #xB4) table)
    (put-char-table (make-char 'latin-iso8859-3 53) (vector #xB5 (make-char 'latin-iso8859-1 53) nil (make-char 'latin-iso8859-3 53) nil (make-char 'latin-iso8859-9 53) (make-char 'latin-iso8859-13 53) nil (make-char 'latin-iso8859-15 53) nil nil nil #xB5) table)
    (put-char-table (make-char 'latin-iso8859-3 54) (vector #x4 nil nil (make-char 'latin-iso8859-3 54) nil nil nil nil nil nil nil nil #x125) table)
    (put-char-table (make-char 'latin-iso8859-3 55) (vector #x1B5 (make-char 'latin-iso8859-1 55) nil (make-char 'latin-iso8859-3 55) nil (make-char 'latin-iso8859-9 55) (make-char 'latin-iso8859-13 55) nil (make-char 'latin-iso8859-15 55) (make-char 'latin-iso8859-16 55) nil nil #xB7) table)
    (put-char-table (make-char 'latin-iso8859-3 56) (vector #x1F (make-char 'latin-iso8859-1 56) (make-char 'latin-iso8859-2 56) (make-char 'latin-iso8859-3 56) (make-char 'latin-iso8859-4 56) (make-char 'latin-iso8859-9 56) nil nil nil nil nil nil #xB8) table)
    (put-char-table (make-char 'latin-iso8859-3 57) (vector #x14 nil nil (make-char 'latin-iso8859-3 57) nil (make-char 'latin-iso8859-9 125) nil nil nil nil nil nil #x131) table)
    (put-char-table (make-char 'latin-iso8859-3 58) (vector #x16 nil (make-char 'latin-iso8859-2 58) (make-char 'latin-iso8859-3 58) nil (make-char 'latin-iso8859-9 126) nil nil nil nil nil nil #x15F) table)
    (put-char-table (make-char 'latin-iso8859-3 59) (vector #x14 nil nil (make-char 'latin-iso8859-3 59) nil (make-char 'latin-iso8859-9 112) nil nil nil nil nil nil #x11F) table)
    (put-char-table (make-char 'latin-iso8859-3 60) (vector #x4 nil nil (make-char 'latin-iso8859-3 60) nil nil nil nil nil nil nil nil #x135) table)
    (put-char-table (make-char 'latin-iso8859-3 61) (vector #x35 (make-char 'latin-iso8859-1 61) nil (make-char 'latin-iso8859-3 61) nil (make-char 'latin-iso8859-9 61) (make-char 'latin-iso8859-13 61) nil nil nil nil nil #xBD) table)
    (put-char-table (make-char 'latin-iso8859-3 62) (vector #x0 nil nil nil nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-3 63) (vector #x126 nil (make-char 'latin-iso8859-2 63) (make-char 'latin-iso8859-3 63) nil nil (make-char 'latin-iso8859-13 125) nil nil (make-char 'latin-iso8859-16 63) nil nil #x17C) table)
    (put-char-table (make-char 'latin-iso8859-3 64) (vector #x1D5 (make-char 'latin-iso8859-1 64) nil (make-char 'latin-iso8859-3 64) nil (make-char 'latin-iso8859-9 64) nil (make-char 'latin-iso8859-14 64) (make-char 'latin-iso8859-15 64) (make-char 'latin-iso8859-16 64) nil nil #xC0) table)
    (put-char-table (make-char 'latin-iso8859-3 65) (vector #x1DF (make-char 'latin-iso8859-1 65) (make-char 'latin-iso8859-2 65) (make-char 'latin-iso8859-3 65) (make-char 'latin-iso8859-4 65) (make-char 'latin-iso8859-9 65) nil (make-char 'latin-iso8859-14 65) (make-char 'latin-iso8859-15 65) (make-char 'latin-iso8859-16 65) nil nil #xC1) table)
    (put-char-table (make-char 'latin-iso8859-3 66) (vector #x1DF (make-char 'latin-iso8859-1 66) (make-char 'latin-iso8859-2 66) (make-char 'latin-iso8859-3 66) (make-char 'latin-iso8859-4 66) (make-char 'latin-iso8859-9 66) nil (make-char 'latin-iso8859-14 66) (make-char 'latin-iso8859-15 66) (make-char 'latin-iso8859-16 66) nil nil #xC2) table)
    (put-char-table (make-char 'latin-iso8859-3 67) (vector #x0 nil nil nil nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-3 68) (vector #x1FF (make-char 'latin-iso8859-1 68) (make-char 'latin-iso8859-2 68) (make-char 'latin-iso8859-3 68) (make-char 'latin-iso8859-4 68) (make-char 'latin-iso8859-9 68) (make-char 'latin-iso8859-13 68) (make-char 'latin-iso8859-14 68) (make-char 'latin-iso8859-15 68) (make-char 'latin-iso8859-16 68) nil nil #xC4) table)
    (put-char-table (make-char 'latin-iso8859-3 69) (vector #x44 nil nil (make-char 'latin-iso8859-3 69) nil nil nil (make-char 'latin-iso8859-14 36) nil nil nil nil #x10A) table)
    (put-char-table (make-char 'latin-iso8859-3 70) (vector #x4 nil nil (make-char 'latin-iso8859-3 70) nil nil nil nil nil nil nil nil #x108) table)
    (put-char-table (make-char 'latin-iso8859-3 71) (vector #x1D7 (make-char 'latin-iso8859-1 71) (make-char 'latin-iso8859-2 71) (make-char 'latin-iso8859-3 71) nil (make-char 'latin-iso8859-9 71) nil (make-char 'latin-iso8859-14 71) (make-char 'latin-iso8859-15 71) (make-char 'latin-iso8859-16 71) nil nil #xC7) table)
    (put-char-table (make-char 'latin-iso8859-3 72) (vector #x1D5 (make-char 'latin-iso8859-1 72) nil (make-char 'latin-iso8859-3 72) nil (make-char 'latin-iso8859-9 72) nil (make-char 'latin-iso8859-14 72) (make-char 'latin-iso8859-15 72) (make-char 'latin-iso8859-16 72) nil nil #xC8) table)
    (put-char-table (make-char 'latin-iso8859-3 73) (vector #x1FF (make-char 'latin-iso8859-1 73) (make-char 'latin-iso8859-2 73) (make-char 'latin-iso8859-3 73) (make-char 'latin-iso8859-4 73) (make-char 'latin-iso8859-9 73) (make-char 'latin-iso8859-13 73) (make-char 'latin-iso8859-14 73) (make-char 'latin-iso8859-15 73) (make-char 'latin-iso8859-16 73) nil nil #xC9) table)
    (put-char-table (make-char 'latin-iso8859-3 74) (vector #x1D5 (make-char 'latin-iso8859-1 74) nil (make-char 'latin-iso8859-3 74) nil (make-char 'latin-iso8859-9 74) nil (make-char 'latin-iso8859-14 74) (make-char 'latin-iso8859-15 74) (make-char 'latin-iso8859-16 74) nil nil #xCA) table)
    (put-char-table (make-char 'latin-iso8859-3 75) (vector #x1DF (make-char 'latin-iso8859-1 75) (make-char 'latin-iso8859-2 75) (make-char 'latin-iso8859-3 75) (make-char 'latin-iso8859-4 75) (make-char 'latin-iso8859-9 75) nil (make-char 'latin-iso8859-14 75) (make-char 'latin-iso8859-15 75) (make-char 'latin-iso8859-16 75) nil nil #xCB) table)
    (put-char-table (make-char 'latin-iso8859-3 76) (vector #x1D5 (make-char 'latin-iso8859-1 76) nil (make-char 'latin-iso8859-3 76) nil (make-char 'latin-iso8859-9 76) nil (make-char 'latin-iso8859-14 76) (make-char 'latin-iso8859-15 76) (make-char 'latin-iso8859-16 76) nil nil #xCC) table)
    (put-char-table (make-char 'latin-iso8859-3 77) (vector #x1DF (make-char 'latin-iso8859-1 77) (make-char 'latin-iso8859-2 77) (make-char 'latin-iso8859-3 77) (make-char 'latin-iso8859-4 77) (make-char 'latin-iso8859-9 77) nil (make-char 'latin-iso8859-14 77) (make-char 'latin-iso8859-15 77) (make-char 'latin-iso8859-16 77) nil nil #xCD) table)
    (put-char-table (make-char 'latin-iso8859-3 78) (vector #x1DF (make-char 'latin-iso8859-1 78) (make-char 'latin-iso8859-2 78) (make-char 'latin-iso8859-3 78) (make-char 'latin-iso8859-4 78) (make-char 'latin-iso8859-9 78) nil (make-char 'latin-iso8859-14 78) (make-char 'latin-iso8859-15 78) (make-char 'latin-iso8859-16 78) nil nil #xCE) table)
    (put-char-table (make-char 'latin-iso8859-3 79) (vector #x1D5 (make-char 'latin-iso8859-1 79) nil (make-char 'latin-iso8859-3 79) nil (make-char 'latin-iso8859-9 79) nil (make-char 'latin-iso8859-14 79) (make-char 'latin-iso8859-15 79) (make-char 'latin-iso8859-16 79) nil nil #xCF) table)
    (put-char-table (make-char 'latin-iso8859-3 80) (vector #x0 nil nil nil nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-3 81) (vector #xD5 (make-char 'latin-iso8859-1 81) nil (make-char 'latin-iso8859-3 81) nil (make-char 'latin-iso8859-9 81) nil (make-char 'latin-iso8859-14 81) (make-char 'latin-iso8859-15 81) nil nil nil #xD1) table)
    (put-char-table (make-char 'latin-iso8859-3 82) (vector #x1D5 (make-char 'latin-iso8859-1 82) nil (make-char 'latin-iso8859-3 82) nil (make-char 'latin-iso8859-9 82) nil (make-char 'latin-iso8859-14 82) (make-char 'latin-iso8859-15 82) (make-char 'latin-iso8859-16 82) nil nil #xD2) table)
    (put-char-table (make-char 'latin-iso8859-3 83) (vector #x1F7 (make-char 'latin-iso8859-1 83) (make-char 'latin-iso8859-2 83) (make-char 'latin-iso8859-3 83) nil (make-char 'latin-iso8859-9 83) (make-char 'latin-iso8859-13 83) (make-char 'latin-iso8859-14 83) (make-char 'latin-iso8859-15 83) (make-char 'latin-iso8859-16 83) nil nil #xD3) table)
    (put-char-table (make-char 'latin-iso8859-3 84) (vector #x1DF (make-char 'latin-iso8859-1 84) (make-char 'latin-iso8859-2 84) (make-char 'latin-iso8859-3 84) (make-char 'latin-iso8859-4 84) (make-char 'latin-iso8859-9 84) nil (make-char 'latin-iso8859-14 84) (make-char 'latin-iso8859-15 84) (make-char 'latin-iso8859-16 84) nil nil #xD4) table)
    (put-char-table (make-char 'latin-iso8859-3 85) (vector #x44 nil nil (make-char 'latin-iso8859-3 85) nil nil nil (make-char 'latin-iso8859-14 50) nil nil nil nil #x120) table)
    (put-char-table (make-char 'latin-iso8859-3 86) (vector #x1FF (make-char 'latin-iso8859-1 86) (make-char 'latin-iso8859-2 86) (make-char 'latin-iso8859-3 86) (make-char 'latin-iso8859-4 86) (make-char 'latin-iso8859-9 86) (make-char 'latin-iso8859-13 86) (make-char 'latin-iso8859-14 86) (make-char 'latin-iso8859-15 86) (make-char 'latin-iso8859-16 86) nil nil #xD6) table)
    (put-char-table (make-char 'latin-iso8859-3 87) (vector #xBF (make-char 'latin-iso8859-1 87) (make-char 'latin-iso8859-2 87) (make-char 'latin-iso8859-3 87) (make-char 'latin-iso8859-4 87) (make-char 'latin-iso8859-9 87) (make-char 'latin-iso8859-13 87) nil (make-char 'latin-iso8859-15 87) nil nil nil #xD7) table)
    (put-char-table (make-char 'latin-iso8859-3 88) (vector #x4 nil nil (make-char 'latin-iso8859-3 88) nil nil nil nil nil nil nil nil #x11C) table)
    (put-char-table (make-char 'latin-iso8859-3 89) (vector #x1D5 (make-char 'latin-iso8859-1 89) nil (make-char 'latin-iso8859-3 89) nil (make-char 'latin-iso8859-9 89) nil (make-char 'latin-iso8859-14 89) (make-char 'latin-iso8859-15 89) (make-char 'latin-iso8859-16 89) nil nil #xD9) table)
    (put-char-table (make-char 'latin-iso8859-3 90) (vector #x1DF (make-char 'latin-iso8859-1 90) (make-char 'latin-iso8859-2 90) (make-char 'latin-iso8859-3 90) (make-char 'latin-iso8859-4 90) (make-char 'latin-iso8859-9 90) nil (make-char 'latin-iso8859-14 90) (make-char 'latin-iso8859-15 90) (make-char 'latin-iso8859-16 90) nil nil #xDA) table)
    (put-char-table (make-char 'latin-iso8859-3 91) (vector #x1DD (make-char 'latin-iso8859-1 91) nil (make-char 'latin-iso8859-3 91) (make-char 'latin-iso8859-4 91) (make-char 'latin-iso8859-9 91) nil (make-char 'latin-iso8859-14 91) (make-char 'latin-iso8859-15 91) (make-char 'latin-iso8859-16 91) nil nil #xDB) table)
    (put-char-table (make-char 'latin-iso8859-3 92) (vector #x1FF (make-char 'latin-iso8859-1 92) (make-char 'latin-iso8859-2 92) (make-char 'latin-iso8859-3 92) (make-char 'latin-iso8859-4 92) (make-char 'latin-iso8859-9 92) (make-char 'latin-iso8859-13 92) (make-char 'latin-iso8859-14 92) (make-char 'latin-iso8859-15 92) (make-char 'latin-iso8859-16 92) nil nil #xDC) table)
    (put-char-table (make-char 'latin-iso8859-3 93) (vector #x4 nil nil (make-char 'latin-iso8859-3 93) nil nil nil nil nil nil nil nil #x16C) table)
    (put-char-table (make-char 'latin-iso8859-3 94) (vector #x4 nil nil (make-char 'latin-iso8859-3 94) nil nil nil nil nil nil nil nil #x15C) table)
    (put-char-table (make-char 'latin-iso8859-3 95) (vector #x1FF (make-char 'latin-iso8859-1 95) (make-char 'latin-iso8859-2 95) (make-char 'latin-iso8859-3 95) (make-char 'latin-iso8859-4 95) (make-char 'latin-iso8859-9 95) (make-char 'latin-iso8859-13 95) (make-char 'latin-iso8859-14 95) (make-char 'latin-iso8859-15 95) (make-char 'latin-iso8859-16 95) nil nil #xDF) table)
    (put-char-table (make-char 'latin-iso8859-3 96) (vector #x1D5 (make-char 'latin-iso8859-1 96) nil (make-char 'latin-iso8859-3 96) nil (make-char 'latin-iso8859-9 96) nil (make-char 'latin-iso8859-14 96) (make-char 'latin-iso8859-15 96) (make-char 'latin-iso8859-16 96) nil nil #xE0) table)
    (put-char-table (make-char 'latin-iso8859-3 97) (vector #x1DF (make-char 'latin-iso8859-1 97) (make-char 'latin-iso8859-2 97) (make-char 'latin-iso8859-3 97) (make-char 'latin-iso8859-4 97) (make-char 'latin-iso8859-9 97) nil (make-char 'latin-iso8859-14 97) (make-char 'latin-iso8859-15 97) (make-char 'latin-iso8859-16 97) nil nil #xE1) table)
    (put-char-table (make-char 'latin-iso8859-3 98) (vector #x1DF (make-char 'latin-iso8859-1 98) (make-char 'latin-iso8859-2 98) (make-char 'latin-iso8859-3 98) (make-char 'latin-iso8859-4 98) (make-char 'latin-iso8859-9 98) nil (make-char 'latin-iso8859-14 98) (make-char 'latin-iso8859-15 98) (make-char 'latin-iso8859-16 98) nil nil #xE2) table)
    (put-char-table (make-char 'latin-iso8859-3 99) (vector #x0 nil nil nil nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-3 100) (vector #x1FF (make-char 'latin-iso8859-1 100) (make-char 'latin-iso8859-2 100) (make-char 'latin-iso8859-3 100) (make-char 'latin-iso8859-4 100) (make-char 'latin-iso8859-9 100) (make-char 'latin-iso8859-13 100) (make-char 'latin-iso8859-14 100) (make-char 'latin-iso8859-15 100) (make-char 'latin-iso8859-16 100) nil nil #xE4) table)
    (put-char-table (make-char 'latin-iso8859-3 101) (vector #x44 nil nil (make-char 'latin-iso8859-3 101) nil nil nil (make-char 'latin-iso8859-14 37) nil nil nil nil #x10B) table)
    (put-char-table (make-char 'latin-iso8859-3 102) (vector #x4 nil nil (make-char 'latin-iso8859-3 102) nil nil nil nil nil nil nil nil #x109) table)
    (put-char-table (make-char 'latin-iso8859-3 103) (vector #x1D7 (make-char 'latin-iso8859-1 103) (make-char 'latin-iso8859-2 103) (make-char 'latin-iso8859-3 103) nil (make-char 'latin-iso8859-9 103) nil (make-char 'latin-iso8859-14 103) (make-char 'latin-iso8859-15 103) (make-char 'latin-iso8859-16 103) nil nil #xE7) table)
    (put-char-table (make-char 'latin-iso8859-3 104) (vector #x1D5 (make-char 'latin-iso8859-1 104) nil (make-char 'latin-iso8859-3 104) nil (make-char 'latin-iso8859-9 104) nil (make-char 'latin-iso8859-14 104) (make-char 'latin-iso8859-15 104) (make-char 'latin-iso8859-16 104) nil nil #xE8) table)
    (put-char-table (make-char 'latin-iso8859-3 105) (vector #x1FF (make-char 'latin-iso8859-1 105) (make-char 'latin-iso8859-2 105) (make-char 'latin-iso8859-3 105) (make-char 'latin-iso8859-4 105) (make-char 'latin-iso8859-9 105) (make-char 'latin-iso8859-13 105) (make-char 'latin-iso8859-14 105) (make-char 'latin-iso8859-15 105) (make-char 'latin-iso8859-16 105) nil nil #xE9) table)
    (put-char-table (make-char 'latin-iso8859-3 106) (vector #x1D5 (make-char 'latin-iso8859-1 106) nil (make-char 'latin-iso8859-3 106) nil (make-char 'latin-iso8859-9 106) nil (make-char 'latin-iso8859-14 106) (make-char 'latin-iso8859-15 106) (make-char 'latin-iso8859-16 106) nil nil #xEA) table)
    (put-char-table (make-char 'latin-iso8859-3 107) (vector #x1DF (make-char 'latin-iso8859-1 107) (make-char 'latin-iso8859-2 107) (make-char 'latin-iso8859-3 107) (make-char 'latin-iso8859-4 107) (make-char 'latin-iso8859-9 107) nil (make-char 'latin-iso8859-14 107) (make-char 'latin-iso8859-15 107) (make-char 'latin-iso8859-16 107) nil nil #xEB) table)
    (put-char-table (make-char 'latin-iso8859-3 108) (vector #x1D5 (make-char 'latin-iso8859-1 108) nil (make-char 'latin-iso8859-3 108) nil (make-char 'latin-iso8859-9 108) nil (make-char 'latin-iso8859-14 108) (make-char 'latin-iso8859-15 108) (make-char 'latin-iso8859-16 108) nil nil #xEC) table)
    (put-char-table (make-char 'latin-iso8859-3 109) (vector #x1DF (make-char 'latin-iso8859-1 109) (make-char 'latin-iso8859-2 109) (make-char 'latin-iso8859-3 109) (make-char 'latin-iso8859-4 109) (make-char 'latin-iso8859-9 109) nil (make-char 'latin-iso8859-14 109) (make-char 'latin-iso8859-15 109) (make-char 'latin-iso8859-16 109) nil nil #xED) table)
    (put-char-table (make-char 'latin-iso8859-3 110) (vector #x1DF (make-char 'latin-iso8859-1 110) (make-char 'latin-iso8859-2 110) (make-char 'latin-iso8859-3 110) (make-char 'latin-iso8859-4 110) (make-char 'latin-iso8859-9 110) nil (make-char 'latin-iso8859-14 110) (make-char 'latin-iso8859-15 110) (make-char 'latin-iso8859-16 110) nil nil #xEE) table)
    (put-char-table (make-char 'latin-iso8859-3 111) (vector #x1D5 (make-char 'latin-iso8859-1 111) nil (make-char 'latin-iso8859-3 111) nil (make-char 'latin-iso8859-9 111) nil (make-char 'latin-iso8859-14 111) (make-char 'latin-iso8859-15 111) (make-char 'latin-iso8859-16 111) nil nil #xEF) table)
    (put-char-table (make-char 'latin-iso8859-3 112) (vector #x0 nil nil nil nil nil nil nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-3 113) (vector #xD5 (make-char 'latin-iso8859-1 113) nil (make-char 'latin-iso8859-3 113) nil (make-char 'latin-iso8859-9 113) nil (make-char 'latin-iso8859-14 113) (make-char 'latin-iso8859-15 113) nil nil nil #xF1) table)
    (put-char-table (make-char 'latin-iso8859-3 114) (vector #x1D5 (make-char 'latin-iso8859-1 114) nil (make-char 'latin-iso8859-3 114) nil (make-char 'latin-iso8859-9 114) nil (make-char 'latin-iso8859-14 114) (make-char 'latin-iso8859-15 114) (make-char 'latin-iso8859-16 114) nil nil #xF2) table)
    (put-char-table (make-char 'latin-iso8859-3 115) (vector #x1F7 (make-char 'latin-iso8859-1 115) (make-char 'latin-iso8859-2 115) (make-char 'latin-iso8859-3 115) nil (make-char 'latin-iso8859-9 115) (make-char 'latin-iso8859-13 115) (make-char 'latin-iso8859-14 115) (make-char 'latin-iso8859-15 115) (make-char 'latin-iso8859-16 115) nil nil #xF3) table)
    (put-char-table (make-char 'latin-iso8859-3 116) (vector #x1DF (make-char 'latin-iso8859-1 116) (make-char 'latin-iso8859-2 116) (make-char 'latin-iso8859-3 116) (make-char 'latin-iso8859-4 116) (make-char 'latin-iso8859-9 116) nil (make-char 'latin-iso8859-14 116) (make-char 'latin-iso8859-15 116) (make-char 'latin-iso8859-16 116) nil nil #xF4) table)
    (put-char-table (make-char 'latin-iso8859-3 117) (vector #x44 nil nil (make-char 'latin-iso8859-3 117) nil nil nil (make-char 'latin-iso8859-14 51) nil nil nil nil #x121) table)
    (put-char-table (make-char 'latin-iso8859-3 118) (vector #x1FF (make-char 'latin-iso8859-1 118) (make-char 'latin-iso8859-2 118) (make-char 'latin-iso8859-3 118) (make-char 'latin-iso8859-4 118) (make-char 'latin-iso8859-9 118) (make-char 'latin-iso8859-13 118) (make-char 'latin-iso8859-14 118) (make-char 'latin-iso8859-15 118) (make-char 'latin-iso8859-16 118) nil nil #xF6) table)
    (put-char-table (make-char 'latin-iso8859-3 119) (vector #xBF (make-char 'latin-iso8859-1 119) (make-char 'latin-iso8859-2 119) (make-char 'latin-iso8859-3 119) (make-char 'latin-iso8859-4 119) (make-char 'latin-iso8859-9 119) (make-char 'latin-iso8859-13 119) nil (make-char 'latin-iso8859-15 119) nil nil nil #xF7) table)
    (put-char-table (make-char 'latin-iso8859-3 120) (vector #x4 nil nil (make-char 'latin-iso8859-3 120) nil nil nil nil nil nil nil nil #x11D) table)
    (put-char-table (make-char 'latin-iso8859-3 121) (vector #x1D5 (make-char 'latin-iso8859-1 121) nil (make-char 'latin-iso8859-3 121) nil (make-char 'latin-iso8859-9 121) nil (make-char 'latin-iso8859-14 121) (make-char 'latin-iso8859-15 121) (make-char 'latin-iso8859-16 121) nil nil #xF9) table)
    (put-char-table (make-char 'latin-iso8859-3 122) (vector #x1DF (make-char 'latin-iso8859-1 122) (make-char 'latin-iso8859-2 122) (make-char 'latin-iso8859-3 122) (make-char 'latin-iso8859-4 122) (make-char 'latin-iso8859-9 122) nil (make-char 'latin-iso8859-14 122) (make-char 'latin-iso8859-15 122) (make-char 'latin-iso8859-16 122) nil nil #xFA) table)
    (put-char-table (make-char 'latin-iso8859-3 123) (vector #x1DD (make-char 'latin-iso8859-1 123) nil (make-char 'latin-iso8859-3 123) (make-char 'latin-iso8859-4 123) (make-char 'latin-iso8859-9 123) nil (make-char 'latin-iso8859-14 123) (make-char 'latin-iso8859-15 123) (make-char 'latin-iso8859-16 123) nil nil #xFB) table)
    (put-char-table (make-char 'latin-iso8859-3 124) (vector #x1FF (make-char 'latin-iso8859-1 124) (make-char 'latin-iso8859-2 124) (make-char 'latin-iso8859-3 124) (make-char 'latin-iso8859-4 124) (make-char 'latin-iso8859-9 124) (make-char 'latin-iso8859-13 124) (make-char 'latin-iso8859-14 124) (make-char 'latin-iso8859-15 124) (make-char 'latin-iso8859-16 124) nil nil #xFC) table)
    (put-char-table (make-char 'latin-iso8859-3 125) (vector #x4 nil nil (make-char 'latin-iso8859-3 125) nil nil nil nil nil nil nil nil #x16D) table)
    (put-char-table (make-char 'latin-iso8859-3 126) (vector #x4 nil nil (make-char 'latin-iso8859-3 126) nil nil nil nil nil nil nil nil #x15D) table)
    (put-char-table (make-char 'latin-iso8859-3 127) (vector #xE nil (make-char 'latin-iso8859-2 127) (make-char 'latin-iso8859-3 127) (make-char 'latin-iso8859-4 127) nil nil nil nil nil nil nil #x2D9) table)
    (put-char-table (make-char 'latin-iso8859-4 32) (vector #x1FF (make-char 'latin-iso8859-1 32) (make-char 'latin-iso8859-2 32) (make-char 'latin-iso8859-3 32) (make-char 'latin-iso8859-4 32) (make-char 'latin-iso8859-9 32) (make-char 'latin-iso8859-13 32) (make-char 'latin-iso8859-14 32) (make-char 'latin-iso8859-15 32) (make-char 'latin-iso8859-16 32) nil nil #xA0) table)
    (put-char-table (make-char 'latin-iso8859-4 33) (vector #x12A nil (make-char 'latin-iso8859-2 33) nil (make-char 'latin-iso8859-4 33) nil (make-char 'latin-iso8859-13 64) nil nil (make-char 'latin-iso8859-16 33) nil nil #x104) table)
    (put-char-table (make-char 'latin-iso8859-4 34) (vector #x8 nil nil nil (make-char 'latin-iso8859-4 34) nil nil nil nil nil nil nil #x138) table)
    (put-char-table (make-char 'latin-iso8859-4 35) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 35) nil (make-char 'latin-iso8859-13 42) nil nil nil nil nil #x156) table)
    (put-char-table (make-char 'latin-iso8859-4 36) (vector #x3F (make-char 'latin-iso8859-1 36) (make-char 'latin-iso8859-2 36) (make-char 'latin-iso8859-3 36) (make-char 'latin-iso8859-4 36) (make-char 'latin-iso8859-9 36) (make-char 'latin-iso8859-13 36) nil nil nil nil nil #xA4) table)
    (put-char-table (make-char 'latin-iso8859-4 37) (vector #x8 nil nil nil (make-char 'latin-iso8859-4 37) nil nil nil nil nil nil nil #x128) table)
    (put-char-table (make-char 'latin-iso8859-4 38) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 38) nil (make-char 'latin-iso8859-13 79) nil nil nil nil nil #x13B) table)
    (put-char-table (make-char 'latin-iso8859-4 39) (vector #x1FF (make-char 'latin-iso8859-1 39) (make-char 'latin-iso8859-2 39) (make-char 'latin-iso8859-3 39) (make-char 'latin-iso8859-4 39) (make-char 'latin-iso8859-9 39) (make-char 'latin-iso8859-13 39) (make-char 'latin-iso8859-14 39) (make-char 'latin-iso8859-15 39) (make-char 'latin-iso8859-16 39) nil nil #xA7) table)
    (put-char-table (make-char 'latin-iso8859-4 40) (vector #x1F (make-char 'latin-iso8859-1 40) (make-char 'latin-iso8859-2 40) (make-char 'latin-iso8859-3 40) (make-char 'latin-iso8859-4 40) (make-char 'latin-iso8859-9 40) nil nil nil nil nil nil #xA8) table)
    (put-char-table (make-char 'latin-iso8859-4 41) (vector #x1AA nil (make-char 'latin-iso8859-2 41) nil (make-char 'latin-iso8859-4 41) nil (make-char 'latin-iso8859-13 80) nil (make-char 'latin-iso8859-15 38) (make-char 'latin-iso8859-16 38) nil nil #x160) table)
    (put-char-table (make-char 'latin-iso8859-4 42) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 42) nil (make-char 'latin-iso8859-13 71) nil nil nil nil nil #x112) table)
    (put-char-table (make-char 'latin-iso8859-4 43) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 43) nil (make-char 'latin-iso8859-13 76) nil nil nil nil nil #x122) table)
    (put-char-table (make-char 'latin-iso8859-4 44) (vector #x8 nil nil nil (make-char 'latin-iso8859-4 44) nil nil nil nil nil nil nil #x166) table)
    (put-char-table (make-char 'latin-iso8859-4 45) (vector #x1FF (make-char 'latin-iso8859-1 45) (make-char 'latin-iso8859-2 45) (make-char 'latin-iso8859-3 45) (make-char 'latin-iso8859-4 45) (make-char 'latin-iso8859-9 45) (make-char 'latin-iso8859-13 45) (make-char 'latin-iso8859-14 45) (make-char 'latin-iso8859-15 45) (make-char 'latin-iso8859-16 45) nil nil #xAD) table)
    (put-char-table (make-char 'latin-iso8859-4 46) (vector #x1AA nil (make-char 'latin-iso8859-2 46) nil (make-char 'latin-iso8859-4 46) nil (make-char 'latin-iso8859-13 94) nil (make-char 'latin-iso8859-15 52) (make-char 'latin-iso8859-16 52) nil nil #x17D) table)
    (put-char-table (make-char 'latin-iso8859-4 47) (vector #x99 (make-char 'latin-iso8859-1 47) nil nil (make-char 'latin-iso8859-4 47) (make-char 'latin-iso8859-9 47) nil nil (make-char 'latin-iso8859-15 47) nil nil nil #xAF) table)
    (put-char-table (make-char 'latin-iso8859-4 48) (vector #x1BF (make-char 'latin-iso8859-1 48) (make-char 'latin-iso8859-2 48) (make-char 'latin-iso8859-3 48) (make-char 'latin-iso8859-4 48) (make-char 'latin-iso8859-9 48) (make-char 'latin-iso8859-13 48) nil (make-char 'latin-iso8859-15 48) (make-char 'latin-iso8859-16 48) nil nil #xB0) table)
    (put-char-table (make-char 'latin-iso8859-4 49) (vector #x12A nil (make-char 'latin-iso8859-2 49) nil (make-char 'latin-iso8859-4 49) nil (make-char 'latin-iso8859-13 96) nil nil (make-char 'latin-iso8859-16 34) nil nil #x105) table)
    (put-char-table (make-char 'latin-iso8859-4 50) (vector #xA nil (make-char 'latin-iso8859-2 50) nil (make-char 'latin-iso8859-4 50) nil nil nil nil nil nil nil #x2DB) table)
    (put-char-table (make-char 'latin-iso8859-4 51) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 51) nil (make-char 'latin-iso8859-13 58) nil nil nil nil nil #x157) table)
    (put-char-table (make-char 'latin-iso8859-4 52) (vector #x1F (make-char 'latin-iso8859-1 52) (make-char 'latin-iso8859-2 52) (make-char 'latin-iso8859-3 52) (make-char 'latin-iso8859-4 52) (make-char 'latin-iso8859-9 52) nil nil nil nil nil nil #xB4) table)
    (put-char-table (make-char 'latin-iso8859-4 53) (vector #x8 nil nil nil (make-char 'latin-iso8859-4 53) nil nil nil nil nil nil nil #x129) table)
    (put-char-table (make-char 'latin-iso8859-4 54) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 54) nil (make-char 'latin-iso8859-13 111) nil nil nil nil nil #x13C) table)
    (put-char-table (make-char 'latin-iso8859-4 55) (vector #xA nil (make-char 'latin-iso8859-2 55) nil (make-char 'latin-iso8859-4 55) nil nil nil nil nil nil nil #x2C7) table)
    (put-char-table (make-char 'latin-iso8859-4 56) (vector #x1F (make-char 'latin-iso8859-1 56) (make-char 'latin-iso8859-2 56) (make-char 'latin-iso8859-3 56) (make-char 'latin-iso8859-4 56) (make-char 'latin-iso8859-9 56) nil nil nil nil nil nil #xB8) table)
    (put-char-table (make-char 'latin-iso8859-4 57) (vector #x1AA nil (make-char 'latin-iso8859-2 57) nil (make-char 'latin-iso8859-4 57) nil (make-char 'latin-iso8859-13 112) nil (make-char 'latin-iso8859-15 40) (make-char 'latin-iso8859-16 40) nil nil #x161) table)
    (put-char-table (make-char 'latin-iso8859-4 58) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 58) nil (make-char 'latin-iso8859-13 103) nil nil nil nil nil #x113) table)
    (put-char-table (make-char 'latin-iso8859-4 59) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 59) nil (make-char 'latin-iso8859-13 108) nil nil nil nil nil #x123) table)
    (put-char-table (make-char 'latin-iso8859-4 60) (vector #x8 nil nil nil (make-char 'latin-iso8859-4 60) nil nil nil nil nil nil nil #x167) table)
    (put-char-table (make-char 'latin-iso8859-4 61) (vector #x8 nil nil nil (make-char 'latin-iso8859-4 61) nil nil nil nil nil nil nil #x14A) table)
    (put-char-table (make-char 'latin-iso8859-4 62) (vector #x1AA nil (make-char 'latin-iso8859-2 62) nil (make-char 'latin-iso8859-4 62) nil (make-char 'latin-iso8859-13 126) nil (make-char 'latin-iso8859-15 56) (make-char 'latin-iso8859-16 56) nil nil #x17E) table)
    (put-char-table (make-char 'latin-iso8859-4 63) (vector #x8 nil nil nil (make-char 'latin-iso8859-4 63) nil nil nil nil nil nil nil #x14B) table)
    (put-char-table (make-char 'latin-iso8859-4 64) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 64) nil (make-char 'latin-iso8859-13 66) nil nil nil nil nil #x100) table)
    (put-char-table (make-char 'latin-iso8859-4 65) (vector #x1DF (make-char 'latin-iso8859-1 65) (make-char 'latin-iso8859-2 65) (make-char 'latin-iso8859-3 65) (make-char 'latin-iso8859-4 65) (make-char 'latin-iso8859-9 65) nil (make-char 'latin-iso8859-14 65) (make-char 'latin-iso8859-15 65) (make-char 'latin-iso8859-16 65) nil nil #xC1) table)
    (put-char-table (make-char 'latin-iso8859-4 66) (vector #x1DF (make-char 'latin-iso8859-1 66) (make-char 'latin-iso8859-2 66) (make-char 'latin-iso8859-3 66) (make-char 'latin-iso8859-4 66) (make-char 'latin-iso8859-9 66) nil (make-char 'latin-iso8859-14 66) (make-char 'latin-iso8859-15 66) (make-char 'latin-iso8859-16 66) nil nil #xC2) table)
    (put-char-table (make-char 'latin-iso8859-4 67) (vector #xD9 (make-char 'latin-iso8859-1 67) nil nil (make-char 'latin-iso8859-4 67) (make-char 'latin-iso8859-9 67) nil (make-char 'latin-iso8859-14 67) (make-char 'latin-iso8859-15 67) nil nil nil #xC3) table)
    (put-char-table (make-char 'latin-iso8859-4 68) (vector #x1FF (make-char 'latin-iso8859-1 68) (make-char 'latin-iso8859-2 68) (make-char 'latin-iso8859-3 68) (make-char 'latin-iso8859-4 68) (make-char 'latin-iso8859-9 68) (make-char 'latin-iso8859-13 68) (make-char 'latin-iso8859-14 68) (make-char 'latin-iso8859-15 68) (make-char 'latin-iso8859-16 68) nil nil #xC4) table)
    (put-char-table (make-char 'latin-iso8859-4 69) (vector #xF9 (make-char 'latin-iso8859-1 69) nil nil (make-char 'latin-iso8859-4 69) (make-char 'latin-iso8859-9 69) (make-char 'latin-iso8859-13 69) (make-char 'latin-iso8859-14 69) (make-char 'latin-iso8859-15 69) nil nil nil #xC5) table)
    (put-char-table (make-char 'latin-iso8859-4 70) (vector #x1F9 (make-char 'latin-iso8859-1 70) nil nil (make-char 'latin-iso8859-4 70) (make-char 'latin-iso8859-9 70) (make-char 'latin-iso8859-13 47) (make-char 'latin-iso8859-14 70) (make-char 'latin-iso8859-15 70) (make-char 'latin-iso8859-16 70) nil nil #xC6) table)
    (put-char-table (make-char 'latin-iso8859-4 71) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 71) nil (make-char 'latin-iso8859-13 65) nil nil nil nil nil #x12E) table)
    (put-char-table (make-char 'latin-iso8859-4 72) (vector #x12A nil (make-char 'latin-iso8859-2 72) nil (make-char 'latin-iso8859-4 72) nil (make-char 'latin-iso8859-13 72) nil nil (make-char 'latin-iso8859-16 50) nil nil #x10C) table)
    (put-char-table (make-char 'latin-iso8859-4 73) (vector #x1FF (make-char 'latin-iso8859-1 73) (make-char 'latin-iso8859-2 73) (make-char 'latin-iso8859-3 73) (make-char 'latin-iso8859-4 73) (make-char 'latin-iso8859-9 73) (make-char 'latin-iso8859-13 73) (make-char 'latin-iso8859-14 73) (make-char 'latin-iso8859-15 73) (make-char 'latin-iso8859-16 73) nil nil #xC9) table)
    (put-char-table (make-char 'latin-iso8859-4 74) (vector #x12A nil (make-char 'latin-iso8859-2 74) nil (make-char 'latin-iso8859-4 74) nil (make-char 'latin-iso8859-13 70) nil nil (make-char 'latin-iso8859-16 93) nil nil #x118) table)
    (put-char-table (make-char 'latin-iso8859-4 75) (vector #x1DF (make-char 'latin-iso8859-1 75) (make-char 'latin-iso8859-2 75) (make-char 'latin-iso8859-3 75) (make-char 'latin-iso8859-4 75) (make-char 'latin-iso8859-9 75) nil (make-char 'latin-iso8859-14 75) (make-char 'latin-iso8859-15 75) (make-char 'latin-iso8859-16 75) nil nil #xCB) table)
    (put-char-table (make-char 'latin-iso8859-4 76) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 76) nil (make-char 'latin-iso8859-13 75) nil nil nil nil nil #x116) table)
    (put-char-table (make-char 'latin-iso8859-4 77) (vector #x1DF (make-char 'latin-iso8859-1 77) (make-char 'latin-iso8859-2 77) (make-char 'latin-iso8859-3 77) (make-char 'latin-iso8859-4 77) (make-char 'latin-iso8859-9 77) nil (make-char 'latin-iso8859-14 77) (make-char 'latin-iso8859-15 77) (make-char 'latin-iso8859-16 77) nil nil #xCD) table)
    (put-char-table (make-char 'latin-iso8859-4 78) (vector #x1DF (make-char 'latin-iso8859-1 78) (make-char 'latin-iso8859-2 78) (make-char 'latin-iso8859-3 78) (make-char 'latin-iso8859-4 78) (make-char 'latin-iso8859-9 78) nil (make-char 'latin-iso8859-14 78) (make-char 'latin-iso8859-15 78) (make-char 'latin-iso8859-16 78) nil nil #xCE) table)
    (put-char-table (make-char 'latin-iso8859-4 79) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 79) nil (make-char 'latin-iso8859-13 78) nil nil nil nil nil #x12A) table)
    (put-char-table (make-char 'latin-iso8859-4 80) (vector #x10A nil (make-char 'latin-iso8859-2 80) nil (make-char 'latin-iso8859-4 80) nil nil nil nil (make-char 'latin-iso8859-16 80) nil nil #x110) table)
    (put-char-table (make-char 'latin-iso8859-4 81) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 81) nil (make-char 'latin-iso8859-13 82) nil nil nil nil nil #x145) table)
    (put-char-table (make-char 'latin-iso8859-4 82) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 82) nil (make-char 'latin-iso8859-13 84) nil nil nil nil nil #x14C) table)
    (put-char-table (make-char 'latin-iso8859-4 83) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 83) nil (make-char 'latin-iso8859-13 77) nil nil nil nil nil #x136) table)
    (put-char-table (make-char 'latin-iso8859-4 84) (vector #x1DF (make-char 'latin-iso8859-1 84) (make-char 'latin-iso8859-2 84) (make-char 'latin-iso8859-3 84) (make-char 'latin-iso8859-4 84) (make-char 'latin-iso8859-9 84) nil (make-char 'latin-iso8859-14 84) (make-char 'latin-iso8859-15 84) (make-char 'latin-iso8859-16 84) nil nil #xD4) table)
    (put-char-table (make-char 'latin-iso8859-4 85) (vector #xF9 (make-char 'latin-iso8859-1 85) nil nil (make-char 'latin-iso8859-4 85) (make-char 'latin-iso8859-9 85) (make-char 'latin-iso8859-13 85) (make-char 'latin-iso8859-14 85) (make-char 'latin-iso8859-15 85) nil nil nil #xD5) table)
    (put-char-table (make-char 'latin-iso8859-4 86) (vector #x1FF (make-char 'latin-iso8859-1 86) (make-char 'latin-iso8859-2 86) (make-char 'latin-iso8859-3 86) (make-char 'latin-iso8859-4 86) (make-char 'latin-iso8859-9 86) (make-char 'latin-iso8859-13 86) (make-char 'latin-iso8859-14 86) (make-char 'latin-iso8859-15 86) (make-char 'latin-iso8859-16 86) nil nil #xD6) table)
    (put-char-table (make-char 'latin-iso8859-4 87) (vector #xBF (make-char 'latin-iso8859-1 87) (make-char 'latin-iso8859-2 87) (make-char 'latin-iso8859-3 87) (make-char 'latin-iso8859-4 87) (make-char 'latin-iso8859-9 87) (make-char 'latin-iso8859-13 87) nil (make-char 'latin-iso8859-15 87) nil nil nil #xD7) table)
    (put-char-table (make-char 'latin-iso8859-4 88) (vector #xF9 (make-char 'latin-iso8859-1 88) nil nil (make-char 'latin-iso8859-4 88) (make-char 'latin-iso8859-9 88) (make-char 'latin-iso8859-13 40) (make-char 'latin-iso8859-14 88) (make-char 'latin-iso8859-15 88) nil nil nil #xD8) table)
    (put-char-table (make-char 'latin-iso8859-4 89) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 89) nil (make-char 'latin-iso8859-13 88) nil nil nil nil nil #x172) table)
    (put-char-table (make-char 'latin-iso8859-4 90) (vector #x1DF (make-char 'latin-iso8859-1 90) (make-char 'latin-iso8859-2 90) (make-char 'latin-iso8859-3 90) (make-char 'latin-iso8859-4 90) (make-char 'latin-iso8859-9 90) nil (make-char 'latin-iso8859-14 90) (make-char 'latin-iso8859-15 90) (make-char 'latin-iso8859-16 90) nil nil #xDA) table)
    (put-char-table (make-char 'latin-iso8859-4 91) (vector #x1DD (make-char 'latin-iso8859-1 91) nil (make-char 'latin-iso8859-3 91) (make-char 'latin-iso8859-4 91) (make-char 'latin-iso8859-9 91) nil (make-char 'latin-iso8859-14 91) (make-char 'latin-iso8859-15 91) (make-char 'latin-iso8859-16 91) nil nil #xDB) table)
    (put-char-table (make-char 'latin-iso8859-4 92) (vector #x1FF (make-char 'latin-iso8859-1 92) (make-char 'latin-iso8859-2 92) (make-char 'latin-iso8859-3 92) (make-char 'latin-iso8859-4 92) (make-char 'latin-iso8859-9 92) (make-char 'latin-iso8859-13 92) (make-char 'latin-iso8859-14 92) (make-char 'latin-iso8859-15 92) (make-char 'latin-iso8859-16 92) nil nil #xDC) table)
    (put-char-table (make-char 'latin-iso8859-4 93) (vector #x8 nil nil nil (make-char 'latin-iso8859-4 93) nil nil nil nil nil nil nil #x168) table)
    (put-char-table (make-char 'latin-iso8859-4 94) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 94) nil (make-char 'latin-iso8859-13 91) nil nil nil nil nil #x16A) table)
    (put-char-table (make-char 'latin-iso8859-4 95) (vector #x1FF (make-char 'latin-iso8859-1 95) (make-char 'latin-iso8859-2 95) (make-char 'latin-iso8859-3 95) (make-char 'latin-iso8859-4 95) (make-char 'latin-iso8859-9 95) (make-char 'latin-iso8859-13 95) (make-char 'latin-iso8859-14 95) (make-char 'latin-iso8859-15 95) (make-char 'latin-iso8859-16 95) nil nil #xDF) table)
    (put-char-table (make-char 'latin-iso8859-4 96) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 96) nil (make-char 'latin-iso8859-13 98) nil nil nil nil nil #x101) table)
    (put-char-table (make-char 'latin-iso8859-4 97) (vector #x1DF (make-char 'latin-iso8859-1 97) (make-char 'latin-iso8859-2 97) (make-char 'latin-iso8859-3 97) (make-char 'latin-iso8859-4 97) (make-char 'latin-iso8859-9 97) nil (make-char 'latin-iso8859-14 97) (make-char 'latin-iso8859-15 97) (make-char 'latin-iso8859-16 97) nil nil #xE1) table)
    (put-char-table (make-char 'latin-iso8859-4 98) (vector #x1DF (make-char 'latin-iso8859-1 98) (make-char 'latin-iso8859-2 98) (make-char 'latin-iso8859-3 98) (make-char 'latin-iso8859-4 98) (make-char 'latin-iso8859-9 98) nil (make-char 'latin-iso8859-14 98) (make-char 'latin-iso8859-15 98) (make-char 'latin-iso8859-16 98) nil nil #xE2) table)
    (put-char-table (make-char 'latin-iso8859-4 99) (vector #xD9 (make-char 'latin-iso8859-1 99) nil nil (make-char 'latin-iso8859-4 99) (make-char 'latin-iso8859-9 99) nil (make-char 'latin-iso8859-14 99) (make-char 'latin-iso8859-15 99) nil nil nil #xE3) table)
    (put-char-table (make-char 'latin-iso8859-4 100) (vector #x1FF (make-char 'latin-iso8859-1 100) (make-char 'latin-iso8859-2 100) (make-char 'latin-iso8859-3 100) (make-char 'latin-iso8859-4 100) (make-char 'latin-iso8859-9 100) (make-char 'latin-iso8859-13 100) (make-char 'latin-iso8859-14 100) (make-char 'latin-iso8859-15 100) (make-char 'latin-iso8859-16 100) nil nil #xE4) table)
    (put-char-table (make-char 'latin-iso8859-4 101) (vector #xF9 (make-char 'latin-iso8859-1 101) nil nil (make-char 'latin-iso8859-4 101) (make-char 'latin-iso8859-9 101) (make-char 'latin-iso8859-13 101) (make-char 'latin-iso8859-14 101) (make-char 'latin-iso8859-15 101) nil nil nil #xE5) table)
    (put-char-table (make-char 'latin-iso8859-4 102) (vector #x1F9 (make-char 'latin-iso8859-1 102) nil nil (make-char 'latin-iso8859-4 102) (make-char 'latin-iso8859-9 102) (make-char 'latin-iso8859-13 63) (make-char 'latin-iso8859-14 102) (make-char 'latin-iso8859-15 102) (make-char 'latin-iso8859-16 102) nil nil #xE6) table)
    (put-char-table (make-char 'latin-iso8859-4 103) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 103) nil (make-char 'latin-iso8859-13 97) nil nil nil nil nil #x12F) table)
    (put-char-table (make-char 'latin-iso8859-4 104) (vector #x12A nil (make-char 'latin-iso8859-2 104) nil (make-char 'latin-iso8859-4 104) nil (make-char 'latin-iso8859-13 104) nil nil (make-char 'latin-iso8859-16 57) nil nil #x10D) table)
    (put-char-table (make-char 'latin-iso8859-4 105) (vector #x1FF (make-char 'latin-iso8859-1 105) (make-char 'latin-iso8859-2 105) (make-char 'latin-iso8859-3 105) (make-char 'latin-iso8859-4 105) (make-char 'latin-iso8859-9 105) (make-char 'latin-iso8859-13 105) (make-char 'latin-iso8859-14 105) (make-char 'latin-iso8859-15 105) (make-char 'latin-iso8859-16 105) nil nil #xE9) table)
    (put-char-table (make-char 'latin-iso8859-4 106) (vector #x12A nil (make-char 'latin-iso8859-2 106) nil (make-char 'latin-iso8859-4 106) nil (make-char 'latin-iso8859-13 102) nil nil (make-char 'latin-iso8859-16 125) nil nil #x119) table)
    (put-char-table (make-char 'latin-iso8859-4 107) (vector #x1DF (make-char 'latin-iso8859-1 107) (make-char 'latin-iso8859-2 107) (make-char 'latin-iso8859-3 107) (make-char 'latin-iso8859-4 107) (make-char 'latin-iso8859-9 107) nil (make-char 'latin-iso8859-14 107) (make-char 'latin-iso8859-15 107) (make-char 'latin-iso8859-16 107) nil nil #xEB) table)
    (put-char-table (make-char 'latin-iso8859-4 108) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 108) nil (make-char 'latin-iso8859-13 107) nil nil nil nil nil #x117) table)
    (put-char-table (make-char 'latin-iso8859-4 109) (vector #x1DF (make-char 'latin-iso8859-1 109) (make-char 'latin-iso8859-2 109) (make-char 'latin-iso8859-3 109) (make-char 'latin-iso8859-4 109) (make-char 'latin-iso8859-9 109) nil (make-char 'latin-iso8859-14 109) (make-char 'latin-iso8859-15 109) (make-char 'latin-iso8859-16 109) nil nil #xED) table)
    (put-char-table (make-char 'latin-iso8859-4 110) (vector #x1DF (make-char 'latin-iso8859-1 110) (make-char 'latin-iso8859-2 110) (make-char 'latin-iso8859-3 110) (make-char 'latin-iso8859-4 110) (make-char 'latin-iso8859-9 110) nil (make-char 'latin-iso8859-14 110) (make-char 'latin-iso8859-15 110) (make-char 'latin-iso8859-16 110) nil nil #xEE) table)
    (put-char-table (make-char 'latin-iso8859-4 111) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 111) nil (make-char 'latin-iso8859-13 110) nil nil nil nil nil #x12B) table)
    (put-char-table (make-char 'latin-iso8859-4 112) (vector #x10A nil (make-char 'latin-iso8859-2 112) nil (make-char 'latin-iso8859-4 112) nil nil nil nil (make-char 'latin-iso8859-16 112) nil nil #x111) table)
    (put-char-table (make-char 'latin-iso8859-4 113) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 113) nil (make-char 'latin-iso8859-13 114) nil nil nil nil nil #x146) table)
    (put-char-table (make-char 'latin-iso8859-4 114) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 114) nil (make-char 'latin-iso8859-13 116) nil nil nil nil nil #x14D) table)
    (put-char-table (make-char 'latin-iso8859-4 115) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 115) nil (make-char 'latin-iso8859-13 109) nil nil nil nil nil #x137) table)
    (put-char-table (make-char 'latin-iso8859-4 116) (vector #x1DF (make-char 'latin-iso8859-1 116) (make-char 'latin-iso8859-2 116) (make-char 'latin-iso8859-3 116) (make-char 'latin-iso8859-4 116) (make-char 'latin-iso8859-9 116) nil (make-char 'latin-iso8859-14 116) (make-char 'latin-iso8859-15 116) (make-char 'latin-iso8859-16 116) nil nil #xF4) table)
    (put-char-table (make-char 'latin-iso8859-4 117) (vector #xF9 (make-char 'latin-iso8859-1 117) nil nil (make-char 'latin-iso8859-4 117) (make-char 'latin-iso8859-9 117) (make-char 'latin-iso8859-13 117) (make-char 'latin-iso8859-14 117) (make-char 'latin-iso8859-15 117) nil nil nil #xF5) table)
    (put-char-table (make-char 'latin-iso8859-4 118) (vector #x1FF (make-char 'latin-iso8859-1 118) (make-char 'latin-iso8859-2 118) (make-char 'latin-iso8859-3 118) (make-char 'latin-iso8859-4 118) (make-char 'latin-iso8859-9 118) (make-char 'latin-iso8859-13 118) (make-char 'latin-iso8859-14 118) (make-char 'latin-iso8859-15 118) (make-char 'latin-iso8859-16 118) nil nil #xF6) table)
    (put-char-table (make-char 'latin-iso8859-4 119) (vector #xBF (make-char 'latin-iso8859-1 119) (make-char 'latin-iso8859-2 119) (make-char 'latin-iso8859-3 119) (make-char 'latin-iso8859-4 119) (make-char 'latin-iso8859-9 119) (make-char 'latin-iso8859-13 119) nil (make-char 'latin-iso8859-15 119) nil nil nil #xF7) table)
    (put-char-table (make-char 'latin-iso8859-4 120) (vector #xF9 (make-char 'latin-iso8859-1 120) nil nil (make-char 'latin-iso8859-4 120) (make-char 'latin-iso8859-9 120) (make-char 'latin-iso8859-13 56) (make-char 'latin-iso8859-14 120) (make-char 'latin-iso8859-15 120) nil nil nil #xF8) table)
    (put-char-table (make-char 'latin-iso8859-4 121) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 121) nil (make-char 'latin-iso8859-13 120) nil nil nil nil nil #x173) table)
    (put-char-table (make-char 'latin-iso8859-4 122) (vector #x1DF (make-char 'latin-iso8859-1 122) (make-char 'latin-iso8859-2 122) (make-char 'latin-iso8859-3 122) (make-char 'latin-iso8859-4 122) (make-char 'latin-iso8859-9 122) nil (make-char 'latin-iso8859-14 122) (make-char 'latin-iso8859-15 122) (make-char 'latin-iso8859-16 122) nil nil #xFA) table)
    (put-char-table (make-char 'latin-iso8859-4 123) (vector #x1DD (make-char 'latin-iso8859-1 123) nil (make-char 'latin-iso8859-3 123) (make-char 'latin-iso8859-4 123) (make-char 'latin-iso8859-9 123) nil (make-char 'latin-iso8859-14 123) (make-char 'latin-iso8859-15 123) (make-char 'latin-iso8859-16 123) nil nil #xFB) table)
    (put-char-table (make-char 'latin-iso8859-4 124) (vector #x1FF (make-char 'latin-iso8859-1 124) (make-char 'latin-iso8859-2 124) (make-char 'latin-iso8859-3 124) (make-char 'latin-iso8859-4 124) (make-char 'latin-iso8859-9 124) (make-char 'latin-iso8859-13 124) (make-char 'latin-iso8859-14 124) (make-char 'latin-iso8859-15 124) (make-char 'latin-iso8859-16 124) nil nil #xFC) table)
    (put-char-table (make-char 'latin-iso8859-4 125) (vector #x8 nil nil nil (make-char 'latin-iso8859-4 125) nil nil nil nil nil nil nil #x169) table)
    (put-char-table (make-char 'latin-iso8859-4 126) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 126) nil (make-char 'latin-iso8859-13 123) nil nil nil nil nil #x16B) table)
    (put-char-table (make-char 'latin-iso8859-4 127) (vector #xE nil (make-char 'latin-iso8859-2 127) (make-char 'latin-iso8859-3 127) (make-char 'latin-iso8859-4 127) nil nil nil nil nil nil nil #x2D9) table)
    (put-char-table (make-char 'latin-jisx0201 33) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 33) (make-char 'latin-jisx0201 33) #x21) table)
    (put-char-table (make-char 'latin-jisx0201 34) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 34) (make-char 'latin-jisx0201 34) #x22) table)
    (put-char-table (make-char 'latin-jisx0201 35) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 35) (make-char 'latin-jisx0201 35) #x23) table)
    (put-char-table (make-char 'latin-jisx0201 36) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 36) (make-char 'latin-jisx0201 36) #x24) table)
    (put-char-table (make-char 'latin-jisx0201 37) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 37) (make-char 'latin-jisx0201 37) #x25) table)
    (put-char-table (make-char 'latin-jisx0201 38) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 38) (make-char 'latin-jisx0201 38) #x26) table)
    (put-char-table (make-char 'latin-jisx0201 39) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 39) (make-char 'latin-jisx0201 39) #x27) table)
    (put-char-table (make-char 'latin-jisx0201 40) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 40) (make-char 'latin-jisx0201 40) #x28) table)
    (put-char-table (make-char 'latin-jisx0201 41) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 41) (make-char 'latin-jisx0201 41) #x29) table)
    (put-char-table (make-char 'latin-jisx0201 42) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 42) (make-char 'latin-jisx0201 42) #x2A) table)
    (put-char-table (make-char 'latin-jisx0201 43) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 43) (make-char 'latin-jisx0201 43) #x2B) table)
    (put-char-table (make-char 'latin-jisx0201 44) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 44) (make-char 'latin-jisx0201 44) #x2C) table)
    (put-char-table (make-char 'latin-jisx0201 45) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 45) (make-char 'latin-jisx0201 45) #x2D) table)
    (put-char-table (make-char 'latin-jisx0201 46) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 46) (make-char 'latin-jisx0201 46) #x2E) table)
    (put-char-table (make-char 'latin-jisx0201 47) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 47) (make-char 'latin-jisx0201 47) #x2F) table)
    (put-char-table (make-char 'latin-jisx0201 48) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 48) (make-char 'latin-jisx0201 48) #x30) table)
    (put-char-table (make-char 'latin-jisx0201 49) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 49) (make-char 'latin-jisx0201 49) #x31) table)
    (put-char-table (make-char 'latin-jisx0201 50) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 50) (make-char 'latin-jisx0201 50) #x32) table)
    (put-char-table (make-char 'latin-jisx0201 51) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 51) (make-char 'latin-jisx0201 51) #x33) table)
    (put-char-table (make-char 'latin-jisx0201 52) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 52) (make-char 'latin-jisx0201 52) #x34) table)
    (put-char-table (make-char 'latin-jisx0201 53) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 53) (make-char 'latin-jisx0201 53) #x35) table)
    (put-char-table (make-char 'latin-jisx0201 54) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 54) (make-char 'latin-jisx0201 54) #x36) table)
    (put-char-table (make-char 'latin-jisx0201 55) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 55) (make-char 'latin-jisx0201 55) #x37) table)
    (put-char-table (make-char 'latin-jisx0201 56) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 56) (make-char 'latin-jisx0201 56) #x38) table)
    (put-char-table (make-char 'latin-jisx0201 57) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 57) (make-char 'latin-jisx0201 57) #x39) table)
    (put-char-table (make-char 'latin-jisx0201 58) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 58) (make-char 'latin-jisx0201 58) #x3A) table)
    (put-char-table (make-char 'latin-jisx0201 59) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 59) (make-char 'latin-jisx0201 59) #x3B) table)
    (put-char-table (make-char 'latin-jisx0201 60) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 60) (make-char 'latin-jisx0201 60) #x3C) table)
    (put-char-table (make-char 'latin-jisx0201 61) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 61) (make-char 'latin-jisx0201 61) #x3D) table)
    (put-char-table (make-char 'latin-jisx0201 62) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 62) (make-char 'latin-jisx0201 62) #x3E) table)
    (put-char-table (make-char 'latin-jisx0201 63) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 63) (make-char 'latin-jisx0201 63) #x3F) table)
    (put-char-table (make-char 'latin-jisx0201 64) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 64) (make-char 'latin-jisx0201 64) #x40) table)
    (put-char-table (make-char 'latin-jisx0201 65) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 65) (make-char 'latin-jisx0201 65) #x41) table)
    (put-char-table (make-char 'latin-jisx0201 66) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 66) (make-char 'latin-jisx0201 66) #x42) table)
    (put-char-table (make-char 'latin-jisx0201 67) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 67) (make-char 'latin-jisx0201 67) #x43) table)
    (put-char-table (make-char 'latin-jisx0201 68) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 68) (make-char 'latin-jisx0201 68) #x44) table)
    (put-char-table (make-char 'latin-jisx0201 69) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 69) (make-char 'latin-jisx0201 69) #x45) table)
    (put-char-table (make-char 'latin-jisx0201 70) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 70) (make-char 'latin-jisx0201 70) #x46) table)
    (put-char-table (make-char 'latin-jisx0201 71) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 71) (make-char 'latin-jisx0201 71) #x47) table)
    (put-char-table (make-char 'latin-jisx0201 72) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 72) (make-char 'latin-jisx0201 72) #x48) table)
    (put-char-table (make-char 'latin-jisx0201 73) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 73) (make-char 'latin-jisx0201 73) #x49) table)
    (put-char-table (make-char 'latin-jisx0201 74) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 74) (make-char 'latin-jisx0201 74) #x4A) table)
    (put-char-table (make-char 'latin-jisx0201 75) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 75) (make-char 'latin-jisx0201 75) #x4B) table)
    (put-char-table (make-char 'latin-jisx0201 76) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 76) (make-char 'latin-jisx0201 76) #x4C) table)
    (put-char-table (make-char 'latin-jisx0201 77) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 77) (make-char 'latin-jisx0201 77) #x4D) table)
    (put-char-table (make-char 'latin-jisx0201 78) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 78) (make-char 'latin-jisx0201 78) #x4E) table)
    (put-char-table (make-char 'latin-jisx0201 79) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 79) (make-char 'latin-jisx0201 79) #x4F) table)
    (put-char-table (make-char 'latin-jisx0201 80) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 80) (make-char 'latin-jisx0201 80) #x50) table)
    (put-char-table (make-char 'latin-jisx0201 81) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 81) (make-char 'latin-jisx0201 81) #x51) table)
    (put-char-table (make-char 'latin-jisx0201 82) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 82) (make-char 'latin-jisx0201 82) #x52) table)
    (put-char-table (make-char 'latin-jisx0201 83) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 83) (make-char 'latin-jisx0201 83) #x53) table)
    (put-char-table (make-char 'latin-jisx0201 84) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 84) (make-char 'latin-jisx0201 84) #x54) table)
    (put-char-table (make-char 'latin-jisx0201 85) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 85) (make-char 'latin-jisx0201 85) #x55) table)
    (put-char-table (make-char 'latin-jisx0201 86) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 86) (make-char 'latin-jisx0201 86) #x56) table)
    (put-char-table (make-char 'latin-jisx0201 87) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 87) (make-char 'latin-jisx0201 87) #x57) table)
    (put-char-table (make-char 'latin-jisx0201 88) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 88) (make-char 'latin-jisx0201 88) #x58) table)
    (put-char-table (make-char 'latin-jisx0201 89) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 89) (make-char 'latin-jisx0201 89) #x59) table)
    (put-char-table (make-char 'latin-jisx0201 90) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 90) (make-char 'latin-jisx0201 90) #x5A) table)
    (put-char-table (make-char 'latin-jisx0201 91) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 91) (make-char 'latin-jisx0201 91) #x5B) table)
    (put-char-table (make-char 'latin-jisx0201 92) (vector #x491 (make-char 'latin-iso8859-1 37) nil nil nil (make-char 'latin-iso8859-9 37) nil nil (make-char 'latin-iso8859-15 37) nil nil (make-char 'latin-jisx0201 92) #xA5) table)
    (put-char-table (make-char 'latin-jisx0201 93) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 93) (make-char 'latin-jisx0201 93) #x5D) table)
    (put-char-table (make-char 'latin-jisx0201 94) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 94) (make-char 'latin-jisx0201 94) #x5E) table)
    (put-char-table (make-char 'latin-jisx0201 95) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 95) (make-char 'latin-jisx0201 95) #x5F) table)
    (put-char-table (make-char 'latin-jisx0201 96) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 96) (make-char 'latin-jisx0201 96) #x60) table)
    (put-char-table (make-char 'latin-jisx0201 97) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 97) (make-char 'latin-jisx0201 97) #x61) table)
    (put-char-table (make-char 'latin-jisx0201 98) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 98) (make-char 'latin-jisx0201 98) #x62) table)
    (put-char-table (make-char 'latin-jisx0201 99) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 99) (make-char 'latin-jisx0201 99) #x63) table)
    (put-char-table (make-char 'latin-jisx0201 100) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 100) (make-char 'latin-jisx0201 100) #x64) table)
    (put-char-table (make-char 'latin-jisx0201 101) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 101) (make-char 'latin-jisx0201 101) #x65) table)
    (put-char-table (make-char 'latin-jisx0201 102) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 102) (make-char 'latin-jisx0201 102) #x66) table)
    (put-char-table (make-char 'latin-jisx0201 103) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 103) (make-char 'latin-jisx0201 103) #x67) table)
    (put-char-table (make-char 'latin-jisx0201 104) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 104) (make-char 'latin-jisx0201 104) #x68) table)
    (put-char-table (make-char 'latin-jisx0201 105) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 105) (make-char 'latin-jisx0201 105) #x69) table)
    (put-char-table (make-char 'latin-jisx0201 106) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 106) (make-char 'latin-jisx0201 106) #x6A) table)
    (put-char-table (make-char 'latin-jisx0201 107) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 107) (make-char 'latin-jisx0201 107) #x6B) table)
    (put-char-table (make-char 'latin-jisx0201 108) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 108) (make-char 'latin-jisx0201 108) #x6C) table)
    (put-char-table (make-char 'latin-jisx0201 109) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 109) (make-char 'latin-jisx0201 109) #x6D) table)
    (put-char-table (make-char 'latin-jisx0201 110) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 110) (make-char 'latin-jisx0201 110) #x6E) table)
    (put-char-table (make-char 'latin-jisx0201 111) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 111) (make-char 'latin-jisx0201 111) #x6F) table)
    (put-char-table (make-char 'latin-jisx0201 112) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 112) (make-char 'latin-jisx0201 112) #x70) table)
    (put-char-table (make-char 'latin-jisx0201 113) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 113) (make-char 'latin-jisx0201 113) #x71) table)
    (put-char-table (make-char 'latin-jisx0201 114) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 114) (make-char 'latin-jisx0201 114) #x72) table)
    (put-char-table (make-char 'latin-jisx0201 115) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 115) (make-char 'latin-jisx0201 115) #x73) table)
    (put-char-table (make-char 'latin-jisx0201 116) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 116) (make-char 'latin-jisx0201 116) #x74) table)
    (put-char-table (make-char 'latin-jisx0201 117) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 117) (make-char 'latin-jisx0201 117) #x75) table)
    (put-char-table (make-char 'latin-jisx0201 118) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 118) (make-char 'latin-jisx0201 118) #x76) table)
    (put-char-table (make-char 'latin-jisx0201 119) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 119) (make-char 'latin-jisx0201 119) #x77) table)
    (put-char-table (make-char 'latin-jisx0201 120) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 120) (make-char 'latin-jisx0201 120) #x78) table)
    (put-char-table (make-char 'latin-jisx0201 121) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 121) (make-char 'latin-jisx0201 121) #x79) table)
    (put-char-table (make-char 'latin-jisx0201 122) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 122) (make-char 'latin-jisx0201 122) #x7A) table)
    (put-char-table (make-char 'latin-jisx0201 123) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 123) (make-char 'latin-jisx0201 123) #x7B) table)
    (put-char-table (make-char 'latin-jisx0201 124) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 124) (make-char 'latin-jisx0201 124) #x7C) table)
    (put-char-table (make-char 'latin-jisx0201 125) (vector #x600 nil nil nil nil nil nil nil nil nil (make-char 'ascii 125) (make-char 'latin-jisx0201 125) #x7D) table)
    (put-char-table (make-char 'latin-jisx0201 126) (vector #x400 nil nil nil nil nil nil nil nil nil nil (make-char 'latin-jisx0201 126) #x203E) table)
    (put-char-table (make-char 'latin-iso8859-9 32) (vector #x1FF (make-char 'latin-iso8859-1 32) (make-char 'latin-iso8859-2 32) (make-char 'latin-iso8859-3 32) (make-char 'latin-iso8859-4 32) (make-char 'latin-iso8859-9 32) (make-char 'latin-iso8859-13 32) (make-char 'latin-iso8859-14 32) (make-char 'latin-iso8859-15 32) (make-char 'latin-iso8859-16 32) nil nil #xA0) table)
    (put-char-table (make-char 'latin-iso8859-9 33) (vector #x91 (make-char 'latin-iso8859-1 33) nil nil nil (make-char 'latin-iso8859-9 33) nil nil (make-char 'latin-iso8859-15 33) nil nil nil #xA1) table)
    (put-char-table (make-char 'latin-iso8859-9 34) (vector #xB1 (make-char 'latin-iso8859-1 34) nil nil nil (make-char 'latin-iso8859-9 34) (make-char 'latin-iso8859-13 34) nil (make-char 'latin-iso8859-15 34) nil nil nil #xA2) table)
    (put-char-table (make-char 'latin-iso8859-9 35) (vector #xF5 (make-char 'latin-iso8859-1 35) nil (make-char 'latin-iso8859-3 35) nil (make-char 'latin-iso8859-9 35) (make-char 'latin-iso8859-13 35) (make-char 'latin-iso8859-14 35) (make-char 'latin-iso8859-15 35) nil nil nil #xA3) table)
    (put-char-table (make-char 'latin-iso8859-9 36) (vector #x3F (make-char 'latin-iso8859-1 36) (make-char 'latin-iso8859-2 36) (make-char 'latin-iso8859-3 36) (make-char 'latin-iso8859-4 36) (make-char 'latin-iso8859-9 36) (make-char 'latin-iso8859-13 36) nil nil nil nil nil #xA4) table)
    (put-char-table (make-char 'latin-iso8859-9 37) (vector #x491 (make-char 'latin-iso8859-1 37) nil nil nil (make-char 'latin-iso8859-9 37) nil nil (make-char 'latin-iso8859-15 37) nil nil (make-char 'latin-jisx0201 92) #xA5) table)
    (put-char-table (make-char 'latin-iso8859-9 38) (vector #x31 (make-char 'latin-iso8859-1 38) nil nil nil (make-char 'latin-iso8859-9 38) (make-char 'latin-iso8859-13 38) nil nil nil nil nil #xA6) table)
    (put-char-table (make-char 'latin-iso8859-9 39) (vector #x1FF (make-char 'latin-iso8859-1 39) (make-char 'latin-iso8859-2 39) (make-char 'latin-iso8859-3 39) (make-char 'latin-iso8859-4 39) (make-char 'latin-iso8859-9 39) (make-char 'latin-iso8859-13 39) (make-char 'latin-iso8859-14 39) (make-char 'latin-iso8859-15 39) (make-char 'latin-iso8859-16 39) nil nil #xA7) table)
    (put-char-table (make-char 'latin-iso8859-9 40) (vector #x1F (make-char 'latin-iso8859-1 40) (make-char 'latin-iso8859-2 40) (make-char 'latin-iso8859-3 40) (make-char 'latin-iso8859-4 40) (make-char 'latin-iso8859-9 40) nil nil nil nil nil nil #xA8) table)
    (put-char-table (make-char 'latin-iso8859-9 41) (vector #x1F1 (make-char 'latin-iso8859-1 41) nil nil nil (make-char 'latin-iso8859-9 41) (make-char 'latin-iso8859-13 41) (make-char 'latin-iso8859-14 41) (make-char 'latin-iso8859-15 41) (make-char 'latin-iso8859-16 41) nil nil #xA9) table)
    (put-char-table (make-char 'latin-iso8859-9 42) (vector #x91 (make-char 'latin-iso8859-1 42) nil nil nil (make-char 'latin-iso8859-9 42) nil nil (make-char 'latin-iso8859-15 42) nil nil nil #xAA) table)
    (put-char-table (make-char 'latin-iso8859-9 43) (vector #x1B1 (make-char 'latin-iso8859-1 43) nil nil nil (make-char 'latin-iso8859-9 43) (make-char 'latin-iso8859-13 43) nil (make-char 'latin-iso8859-15 43) (make-char 'latin-iso8859-16 43) nil nil #xAB) table)
    (put-char-table (make-char 'latin-iso8859-9 44) (vector #xB1 (make-char 'latin-iso8859-1 44) nil nil nil (make-char 'latin-iso8859-9 44) (make-char 'latin-iso8859-13 44) nil (make-char 'latin-iso8859-15 44) nil nil nil #xAC) table)
    (put-char-table (make-char 'latin-iso8859-9 45) (vector #x1FF (make-char 'latin-iso8859-1 45) (make-char 'latin-iso8859-2 45) (make-char 'latin-iso8859-3 45) (make-char 'latin-iso8859-4 45) (make-char 'latin-iso8859-9 45) (make-char 'latin-iso8859-13 45) (make-char 'latin-iso8859-14 45) (make-char 'latin-iso8859-15 45) (make-char 'latin-iso8859-16 45) nil nil #xAD) table)
    (put-char-table (make-char 'latin-iso8859-9 46) (vector #xF1 (make-char 'latin-iso8859-1 46) nil nil nil (make-char 'latin-iso8859-9 46) (make-char 'latin-iso8859-13 46) (make-char 'latin-iso8859-14 46) (make-char 'latin-iso8859-15 46) nil nil nil #xAE) table)
    (put-char-table (make-char 'latin-iso8859-9 47) (vector #x99 (make-char 'latin-iso8859-1 47) nil nil (make-char 'latin-iso8859-4 47) (make-char 'latin-iso8859-9 47) nil nil (make-char 'latin-iso8859-15 47) nil nil nil #xAF) table)
    (put-char-table (make-char 'latin-iso8859-9 48) (vector #x1BF (make-char 'latin-iso8859-1 48) (make-char 'latin-iso8859-2 48) (make-char 'latin-iso8859-3 48) (make-char 'latin-iso8859-4 48) (make-char 'latin-iso8859-9 48) (make-char 'latin-iso8859-13 48) nil (make-char 'latin-iso8859-15 48) (make-char 'latin-iso8859-16 48) nil nil #xB0) table)
    (put-char-table (make-char 'latin-iso8859-9 49) (vector #x1B1 (make-char 'latin-iso8859-1 49) nil nil nil (make-char 'latin-iso8859-9 49) (make-char 'latin-iso8859-13 49) nil (make-char 'latin-iso8859-15 49) (make-char 'latin-iso8859-16 49) nil nil #xB1) table)
    (put-char-table (make-char 'latin-iso8859-9 50) (vector #xB5 (make-char 'latin-iso8859-1 50) nil (make-char 'latin-iso8859-3 50) nil (make-char 'latin-iso8859-9 50) (make-char 'latin-iso8859-13 50) nil (make-char 'latin-iso8859-15 50) nil nil nil #xB2) table)
    (put-char-table (make-char 'latin-iso8859-9 51) (vector #xB5 (make-char 'latin-iso8859-1 51) nil (make-char 'latin-iso8859-3 51) nil (make-char 'latin-iso8859-9 51) (make-char 'latin-iso8859-13 51) nil (make-char 'latin-iso8859-15 51) nil nil nil #xB3) table)
    (put-char-table (make-char 'latin-iso8859-9 52) (vector #x1F (make-char 'latin-iso8859-1 52) (make-char 'latin-iso8859-2 52) (make-char 'latin-iso8859-3 52) (make-char 'latin-iso8859-4 52) (make-char 'latin-iso8859-9 52) nil nil nil nil nil nil #xB4) table)
    (put-char-table (make-char 'latin-iso8859-9 53) (vector #xB5 (make-char 'latin-iso8859-1 53) nil (make-char 'latin-iso8859-3 53) nil (make-char 'latin-iso8859-9 53) (make-char 'latin-iso8859-13 53) nil (make-char 'latin-iso8859-15 53) nil nil nil #xB5) table)
    (put-char-table (make-char 'latin-iso8859-9 54) (vector #x1F1 (make-char 'latin-iso8859-1 54) nil nil nil (make-char 'latin-iso8859-9 54) (make-char 'latin-iso8859-13 54) (make-char 'latin-iso8859-14 54) (make-char 'latin-iso8859-15 54) (make-char 'latin-iso8859-16 54) nil nil #xB6) table)
    (put-char-table (make-char 'latin-iso8859-9 55) (vector #x1B5 (make-char 'latin-iso8859-1 55) nil (make-char 'latin-iso8859-3 55) nil (make-char 'latin-iso8859-9 55) (make-char 'latin-iso8859-13 55) nil (make-char 'latin-iso8859-15 55) (make-char 'latin-iso8859-16 55) nil nil #xB7) table)
    (put-char-table (make-char 'latin-iso8859-9 56) (vector #x1F (make-char 'latin-iso8859-1 56) (make-char 'latin-iso8859-2 56) (make-char 'latin-iso8859-3 56) (make-char 'latin-iso8859-4 56) (make-char 'latin-iso8859-9 56) nil nil nil nil nil nil #xB8) table)
    (put-char-table (make-char 'latin-iso8859-9 57) (vector #xB1 (make-char 'latin-iso8859-1 57) nil nil nil (make-char 'latin-iso8859-9 57) (make-char 'latin-iso8859-13 57) nil (make-char 'latin-iso8859-15 57) nil nil nil #xB9) table)
    (put-char-table (make-char 'latin-iso8859-9 58) (vector #x91 (make-char 'latin-iso8859-1 58) nil nil nil (make-char 'latin-iso8859-9 58) nil nil (make-char 'latin-iso8859-15 58) nil nil nil #xBA) table)
    (put-char-table (make-char 'latin-iso8859-9 59) (vector #x1B1 (make-char 'latin-iso8859-1 59) nil nil nil (make-char 'latin-iso8859-9 59) (make-char 'latin-iso8859-13 59) nil (make-char 'latin-iso8859-15 59) (make-char 'latin-iso8859-16 59) nil nil #xBB) table)
    (put-char-table (make-char 'latin-iso8859-9 60) (vector #x31 (make-char 'latin-iso8859-1 60) nil nil nil (make-char 'latin-iso8859-9 60) (make-char 'latin-iso8859-13 60) nil nil nil nil nil #xBC) table)
    (put-char-table (make-char 'latin-iso8859-9 61) (vector #x35 (make-char 'latin-iso8859-1 61) nil (make-char 'latin-iso8859-3 61) nil (make-char 'latin-iso8859-9 61) (make-char 'latin-iso8859-13 61) nil nil nil nil nil #xBD) table)
    (put-char-table (make-char 'latin-iso8859-9 62) (vector #x31 (make-char 'latin-iso8859-1 62) nil nil nil (make-char 'latin-iso8859-9 62) (make-char 'latin-iso8859-13 62) nil nil nil nil nil #xBE) table)
    (put-char-table (make-char 'latin-iso8859-9 63) (vector #x91 (make-char 'latin-iso8859-1 63) nil nil nil (make-char 'latin-iso8859-9 63) nil nil (make-char 'latin-iso8859-15 63) nil nil nil #xBF) table)
    (put-char-table (make-char 'latin-iso8859-9 64) (vector #x1D5 (make-char 'latin-iso8859-1 64) nil (make-char 'latin-iso8859-3 64) nil (make-char 'latin-iso8859-9 64) nil (make-char 'latin-iso8859-14 64) (make-char 'latin-iso8859-15 64) (make-char 'latin-iso8859-16 64) nil nil #xC0) table)
    (put-char-table (make-char 'latin-iso8859-9 65) (vector #x1DF (make-char 'latin-iso8859-1 65) (make-char 'latin-iso8859-2 65) (make-char 'latin-iso8859-3 65) (make-char 'latin-iso8859-4 65) (make-char 'latin-iso8859-9 65) nil (make-char 'latin-iso8859-14 65) (make-char 'latin-iso8859-15 65) (make-char 'latin-iso8859-16 65) nil nil #xC1) table)
    (put-char-table (make-char 'latin-iso8859-9 66) (vector #x1DF (make-char 'latin-iso8859-1 66) (make-char 'latin-iso8859-2 66) (make-char 'latin-iso8859-3 66) (make-char 'latin-iso8859-4 66) (make-char 'latin-iso8859-9 66) nil (make-char 'latin-iso8859-14 66) (make-char 'latin-iso8859-15 66) (make-char 'latin-iso8859-16 66) nil nil #xC2) table)
    (put-char-table (make-char 'latin-iso8859-9 67) (vector #xD9 (make-char 'latin-iso8859-1 67) nil nil (make-char 'latin-iso8859-4 67) (make-char 'latin-iso8859-9 67) nil (make-char 'latin-iso8859-14 67) (make-char 'latin-iso8859-15 67) nil nil nil #xC3) table)
    (put-char-table (make-char 'latin-iso8859-9 68) (vector #x1FF (make-char 'latin-iso8859-1 68) (make-char 'latin-iso8859-2 68) (make-char 'latin-iso8859-3 68) (make-char 'latin-iso8859-4 68) (make-char 'latin-iso8859-9 68) (make-char 'latin-iso8859-13 68) (make-char 'latin-iso8859-14 68) (make-char 'latin-iso8859-15 68) (make-char 'latin-iso8859-16 68) nil nil #xC4) table)
    (put-char-table (make-char 'latin-iso8859-9 69) (vector #xF9 (make-char 'latin-iso8859-1 69) nil nil (make-char 'latin-iso8859-4 69) (make-char 'latin-iso8859-9 69) (make-char 'latin-iso8859-13 69) (make-char 'latin-iso8859-14 69) (make-char 'latin-iso8859-15 69) nil nil nil #xC5) table)
    (put-char-table (make-char 'latin-iso8859-9 70) (vector #x1F9 (make-char 'latin-iso8859-1 70) nil nil (make-char 'latin-iso8859-4 70) (make-char 'latin-iso8859-9 70) (make-char 'latin-iso8859-13 47) (make-char 'latin-iso8859-14 70) (make-char 'latin-iso8859-15 70) (make-char 'latin-iso8859-16 70) nil nil #xC6) table)
    (put-char-table (make-char 'latin-iso8859-9 71) (vector #x1D7 (make-char 'latin-iso8859-1 71) (make-char 'latin-iso8859-2 71) (make-char 'latin-iso8859-3 71) nil (make-char 'latin-iso8859-9 71) nil (make-char 'latin-iso8859-14 71) (make-char 'latin-iso8859-15 71) (make-char 'latin-iso8859-16 71) nil nil #xC7) table)
    (put-char-table (make-char 'latin-iso8859-9 72) (vector #x1D5 (make-char 'latin-iso8859-1 72) nil (make-char 'latin-iso8859-3 72) nil (make-char 'latin-iso8859-9 72) nil (make-char 'latin-iso8859-14 72) (make-char 'latin-iso8859-15 72) (make-char 'latin-iso8859-16 72) nil nil #xC8) table)
    (put-char-table (make-char 'latin-iso8859-9 73) (vector #x1FF (make-char 'latin-iso8859-1 73) (make-char 'latin-iso8859-2 73) (make-char 'latin-iso8859-3 73) (make-char 'latin-iso8859-4 73) (make-char 'latin-iso8859-9 73) (make-char 'latin-iso8859-13 73) (make-char 'latin-iso8859-14 73) (make-char 'latin-iso8859-15 73) (make-char 'latin-iso8859-16 73) nil nil #xC9) table)
    (put-char-table (make-char 'latin-iso8859-9 74) (vector #x1D5 (make-char 'latin-iso8859-1 74) nil (make-char 'latin-iso8859-3 74) nil (make-char 'latin-iso8859-9 74) nil (make-char 'latin-iso8859-14 74) (make-char 'latin-iso8859-15 74) (make-char 'latin-iso8859-16 74) nil nil #xCA) table)
    (put-char-table (make-char 'latin-iso8859-9 75) (vector #x1DF (make-char 'latin-iso8859-1 75) (make-char 'latin-iso8859-2 75) (make-char 'latin-iso8859-3 75) (make-char 'latin-iso8859-4 75) (make-char 'latin-iso8859-9 75) nil (make-char 'latin-iso8859-14 75) (make-char 'latin-iso8859-15 75) (make-char 'latin-iso8859-16 75) nil nil #xCB) table)
    (put-char-table (make-char 'latin-iso8859-9 76) (vector #x1D5 (make-char 'latin-iso8859-1 76) nil (make-char 'latin-iso8859-3 76) nil (make-char 'latin-iso8859-9 76) nil (make-char 'latin-iso8859-14 76) (make-char 'latin-iso8859-15 76) (make-char 'latin-iso8859-16 76) nil nil #xCC) table)
    (put-char-table (make-char 'latin-iso8859-9 77) (vector #x1DF (make-char 'latin-iso8859-1 77) (make-char 'latin-iso8859-2 77) (make-char 'latin-iso8859-3 77) (make-char 'latin-iso8859-4 77) (make-char 'latin-iso8859-9 77) nil (make-char 'latin-iso8859-14 77) (make-char 'latin-iso8859-15 77) (make-char 'latin-iso8859-16 77) nil nil #xCD) table)
    (put-char-table (make-char 'latin-iso8859-9 78) (vector #x1DF (make-char 'latin-iso8859-1 78) (make-char 'latin-iso8859-2 78) (make-char 'latin-iso8859-3 78) (make-char 'latin-iso8859-4 78) (make-char 'latin-iso8859-9 78) nil (make-char 'latin-iso8859-14 78) (make-char 'latin-iso8859-15 78) (make-char 'latin-iso8859-16 78) nil nil #xCE) table)
    (put-char-table (make-char 'latin-iso8859-9 79) (vector #x1D5 (make-char 'latin-iso8859-1 79) nil (make-char 'latin-iso8859-3 79) nil (make-char 'latin-iso8859-9 79) nil (make-char 'latin-iso8859-14 79) (make-char 'latin-iso8859-15 79) (make-char 'latin-iso8859-16 79) nil nil #xCF) table)
    (put-char-table (make-char 'latin-iso8859-9 80) (vector #x14 nil nil (make-char 'latin-iso8859-3 43) nil (make-char 'latin-iso8859-9 80) nil nil nil nil nil nil #x11E) table)
    (put-char-table (make-char 'latin-iso8859-9 81) (vector #xD5 (make-char 'latin-iso8859-1 81) nil (make-char 'latin-iso8859-3 81) nil (make-char 'latin-iso8859-9 81) nil (make-char 'latin-iso8859-14 81) (make-char 'latin-iso8859-15 81) nil nil nil #xD1) table)
    (put-char-table (make-char 'latin-iso8859-9 82) (vector #x1D5 (make-char 'latin-iso8859-1 82) nil (make-char 'latin-iso8859-3 82) nil (make-char 'latin-iso8859-9 82) nil (make-char 'latin-iso8859-14 82) (make-char 'latin-iso8859-15 82) (make-char 'latin-iso8859-16 82) nil nil #xD2) table)
    (put-char-table (make-char 'latin-iso8859-9 83) (vector #x1F7 (make-char 'latin-iso8859-1 83) (make-char 'latin-iso8859-2 83) (make-char 'latin-iso8859-3 83) nil (make-char 'latin-iso8859-9 83) (make-char 'latin-iso8859-13 83) (make-char 'latin-iso8859-14 83) (make-char 'latin-iso8859-15 83) (make-char 'latin-iso8859-16 83) nil nil #xD3) table)
    (put-char-table (make-char 'latin-iso8859-9 84) (vector #x1DF (make-char 'latin-iso8859-1 84) (make-char 'latin-iso8859-2 84) (make-char 'latin-iso8859-3 84) (make-char 'latin-iso8859-4 84) (make-char 'latin-iso8859-9 84) nil (make-char 'latin-iso8859-14 84) (make-char 'latin-iso8859-15 84) (make-char 'latin-iso8859-16 84) nil nil #xD4) table)
    (put-char-table (make-char 'latin-iso8859-9 85) (vector #xF9 (make-char 'latin-iso8859-1 85) nil nil (make-char 'latin-iso8859-4 85) (make-char 'latin-iso8859-9 85) (make-char 'latin-iso8859-13 85) (make-char 'latin-iso8859-14 85) (make-char 'latin-iso8859-15 85) nil nil nil #xD5) table)
    (put-char-table (make-char 'latin-iso8859-9 86) (vector #x1FF (make-char 'latin-iso8859-1 86) (make-char 'latin-iso8859-2 86) (make-char 'latin-iso8859-3 86) (make-char 'latin-iso8859-4 86) (make-char 'latin-iso8859-9 86) (make-char 'latin-iso8859-13 86) (make-char 'latin-iso8859-14 86) (make-char 'latin-iso8859-15 86) (make-char 'latin-iso8859-16 86) nil nil #xD6) table)
    (put-char-table (make-char 'latin-iso8859-9 87) (vector #xBF (make-char 'latin-iso8859-1 87) (make-char 'latin-iso8859-2 87) (make-char 'latin-iso8859-3 87) (make-char 'latin-iso8859-4 87) (make-char 'latin-iso8859-9 87) (make-char 'latin-iso8859-13 87) nil (make-char 'latin-iso8859-15 87) nil nil nil #xD7) table)
    (put-char-table (make-char 'latin-iso8859-9 88) (vector #xF9 (make-char 'latin-iso8859-1 88) nil nil (make-char 'latin-iso8859-4 88) (make-char 'latin-iso8859-9 88) (make-char 'latin-iso8859-13 40) (make-char 'latin-iso8859-14 88) (make-char 'latin-iso8859-15 88) nil nil nil #xD8) table)
    (put-char-table (make-char 'latin-iso8859-9 89) (vector #x1D5 (make-char 'latin-iso8859-1 89) nil (make-char 'latin-iso8859-3 89) nil (make-char 'latin-iso8859-9 89) nil (make-char 'latin-iso8859-14 89) (make-char 'latin-iso8859-15 89) (make-char 'latin-iso8859-16 89) nil nil #xD9) table)
    (put-char-table (make-char 'latin-iso8859-9 90) (vector #x1DF (make-char 'latin-iso8859-1 90) (make-char 'latin-iso8859-2 90) (make-char 'latin-iso8859-3 90) (make-char 'latin-iso8859-4 90) (make-char 'latin-iso8859-9 90) nil (make-char 'latin-iso8859-14 90) (make-char 'latin-iso8859-15 90) (make-char 'latin-iso8859-16 90) nil nil #xDA) table)
    (put-char-table (make-char 'latin-iso8859-9 91) (vector #x1DD (make-char 'latin-iso8859-1 91) nil (make-char 'latin-iso8859-3 91) (make-char 'latin-iso8859-4 91) (make-char 'latin-iso8859-9 91) nil (make-char 'latin-iso8859-14 91) (make-char 'latin-iso8859-15 91) (make-char 'latin-iso8859-16 91) nil nil #xDB) table)
    (put-char-table (make-char 'latin-iso8859-9 92) (vector #x1FF (make-char 'latin-iso8859-1 92) (make-char 'latin-iso8859-2 92) (make-char 'latin-iso8859-3 92) (make-char 'latin-iso8859-4 92) (make-char 'latin-iso8859-9 92) (make-char 'latin-iso8859-13 92) (make-char 'latin-iso8859-14 92) (make-char 'latin-iso8859-15 92) (make-char 'latin-iso8859-16 92) nil nil #xDC) table)
    (put-char-table (make-char 'latin-iso8859-9 93) (vector #x14 nil nil (make-char 'latin-iso8859-3 41) nil (make-char 'latin-iso8859-9 93) nil nil nil nil nil nil #x130) table)
    (put-char-table (make-char 'latin-iso8859-9 94) (vector #x16 nil (make-char 'latin-iso8859-2 42) (make-char 'latin-iso8859-3 42) nil (make-char 'latin-iso8859-9 94) nil nil nil nil nil nil #x15E) table)
    (put-char-table (make-char 'latin-iso8859-9 95) (vector #x1FF (make-char 'latin-iso8859-1 95) (make-char 'latin-iso8859-2 95) (make-char 'latin-iso8859-3 95) (make-char 'latin-iso8859-4 95) (make-char 'latin-iso8859-9 95) (make-char 'latin-iso8859-13 95) (make-char 'latin-iso8859-14 95) (make-char 'latin-iso8859-15 95) (make-char 'latin-iso8859-16 95) nil nil #xDF) table)
    (put-char-table (make-char 'latin-iso8859-9 96) (vector #x1D5 (make-char 'latin-iso8859-1 96) nil (make-char 'latin-iso8859-3 96) nil (make-char 'latin-iso8859-9 96) nil (make-char 'latin-iso8859-14 96) (make-char 'latin-iso8859-15 96) (make-char 'latin-iso8859-16 96) nil nil #xE0) table)
    (put-char-table (make-char 'latin-iso8859-9 97) (vector #x1DF (make-char 'latin-iso8859-1 97) (make-char 'latin-iso8859-2 97) (make-char 'latin-iso8859-3 97) (make-char 'latin-iso8859-4 97) (make-char 'latin-iso8859-9 97) nil (make-char 'latin-iso8859-14 97) (make-char 'latin-iso8859-15 97) (make-char 'latin-iso8859-16 97) nil nil #xE1) table)
    (put-char-table (make-char 'latin-iso8859-9 98) (vector #x1DF (make-char 'latin-iso8859-1 98) (make-char 'latin-iso8859-2 98) (make-char 'latin-iso8859-3 98) (make-char 'latin-iso8859-4 98) (make-char 'latin-iso8859-9 98) nil (make-char 'latin-iso8859-14 98) (make-char 'latin-iso8859-15 98) (make-char 'latin-iso8859-16 98) nil nil #xE2) table)
    (put-char-table (make-char 'latin-iso8859-9 99) (vector #xD9 (make-char 'latin-iso8859-1 99) nil nil (make-char 'latin-iso8859-4 99) (make-char 'latin-iso8859-9 99) nil (make-char 'latin-iso8859-14 99) (make-char 'latin-iso8859-15 99) nil nil nil #xE3) table)
    (put-char-table (make-char 'latin-iso8859-9 100) (vector #x1FF (make-char 'latin-iso8859-1 100) (make-char 'latin-iso8859-2 100) (make-char 'latin-iso8859-3 100) (make-char 'latin-iso8859-4 100) (make-char 'latin-iso8859-9 100) (make-char 'latin-iso8859-13 100) (make-char 'latin-iso8859-14 100) (make-char 'latin-iso8859-15 100) (make-char 'latin-iso8859-16 100) nil nil #xE4) table)
    (put-char-table (make-char 'latin-iso8859-9 101) (vector #xF9 (make-char 'latin-iso8859-1 101) nil nil (make-char 'latin-iso8859-4 101) (make-char 'latin-iso8859-9 101) (make-char 'latin-iso8859-13 101) (make-char 'latin-iso8859-14 101) (make-char 'latin-iso8859-15 101) nil nil nil #xE5) table)
    (put-char-table (make-char 'latin-iso8859-9 102) (vector #x1F9 (make-char 'latin-iso8859-1 102) nil nil (make-char 'latin-iso8859-4 102) (make-char 'latin-iso8859-9 102) (make-char 'latin-iso8859-13 63) (make-char 'latin-iso8859-14 102) (make-char 'latin-iso8859-15 102) (make-char 'latin-iso8859-16 102) nil nil #xE6) table)
    (put-char-table (make-char 'latin-iso8859-9 103) (vector #x1D7 (make-char 'latin-iso8859-1 103) (make-char 'latin-iso8859-2 103) (make-char 'latin-iso8859-3 103) nil (make-char 'latin-iso8859-9 103) nil (make-char 'latin-iso8859-14 103) (make-char 'latin-iso8859-15 103) (make-char 'latin-iso8859-16 103) nil nil #xE7) table)
    (put-char-table (make-char 'latin-iso8859-9 104) (vector #x1D5 (make-char 'latin-iso8859-1 104) nil (make-char 'latin-iso8859-3 104) nil (make-char 'latin-iso8859-9 104) nil (make-char 'latin-iso8859-14 104) (make-char 'latin-iso8859-15 104) (make-char 'latin-iso8859-16 104) nil nil #xE8) table)
    (put-char-table (make-char 'latin-iso8859-9 105) (vector #x1FF (make-char 'latin-iso8859-1 105) (make-char 'latin-iso8859-2 105) (make-char 'latin-iso8859-3 105) (make-char 'latin-iso8859-4 105) (make-char 'latin-iso8859-9 105) (make-char 'latin-iso8859-13 105) (make-char 'latin-iso8859-14 105) (make-char 'latin-iso8859-15 105) (make-char 'latin-iso8859-16 105) nil nil #xE9) table)
    (put-char-table (make-char 'latin-iso8859-9 106) (vector #x1D5 (make-char 'latin-iso8859-1 106) nil (make-char 'latin-iso8859-3 106) nil (make-char 'latin-iso8859-9 106) nil (make-char 'latin-iso8859-14 106) (make-char 'latin-iso8859-15 106) (make-char 'latin-iso8859-16 106) nil nil #xEA) table)
    (put-char-table (make-char 'latin-iso8859-9 107) (vector #x1DF (make-char 'latin-iso8859-1 107) (make-char 'latin-iso8859-2 107) (make-char 'latin-iso8859-3 107) (make-char 'latin-iso8859-4 107) (make-char 'latin-iso8859-9 107) nil (make-char 'latin-iso8859-14 107) (make-char 'latin-iso8859-15 107) (make-char 'latin-iso8859-16 107) nil nil #xEB) table)
    (put-char-table (make-char 'latin-iso8859-9 108) (vector #x1D5 (make-char 'latin-iso8859-1 108) nil (make-char 'latin-iso8859-3 108) nil (make-char 'latin-iso8859-9 108) nil (make-char 'latin-iso8859-14 108) (make-char 'latin-iso8859-15 108) (make-char 'latin-iso8859-16 108) nil nil #xEC) table)
    (put-char-table (make-char 'latin-iso8859-9 109) (vector #x1DF (make-char 'latin-iso8859-1 109) (make-char 'latin-iso8859-2 109) (make-char 'latin-iso8859-3 109) (make-char 'latin-iso8859-4 109) (make-char 'latin-iso8859-9 109) nil (make-char 'latin-iso8859-14 109) (make-char 'latin-iso8859-15 109) (make-char 'latin-iso8859-16 109) nil nil #xED) table)
    (put-char-table (make-char 'latin-iso8859-9 110) (vector #x1DF (make-char 'latin-iso8859-1 110) (make-char 'latin-iso8859-2 110) (make-char 'latin-iso8859-3 110) (make-char 'latin-iso8859-4 110) (make-char 'latin-iso8859-9 110) nil (make-char 'latin-iso8859-14 110) (make-char 'latin-iso8859-15 110) (make-char 'latin-iso8859-16 110) nil nil #xEE) table)
    (put-char-table (make-char 'latin-iso8859-9 111) (vector #x1D5 (make-char 'latin-iso8859-1 111) nil (make-char 'latin-iso8859-3 111) nil (make-char 'latin-iso8859-9 111) nil (make-char 'latin-iso8859-14 111) (make-char 'latin-iso8859-15 111) (make-char 'latin-iso8859-16 111) nil nil #xEF) table)
    (put-char-table (make-char 'latin-iso8859-9 112) (vector #x14 nil nil (make-char 'latin-iso8859-3 59) nil (make-char 'latin-iso8859-9 112) nil nil nil nil nil nil #x11F) table)
    (put-char-table (make-char 'latin-iso8859-9 113) (vector #xD5 (make-char 'latin-iso8859-1 113) nil (make-char 'latin-iso8859-3 113) nil (make-char 'latin-iso8859-9 113) nil (make-char 'latin-iso8859-14 113) (make-char 'latin-iso8859-15 113) nil nil nil #xF1) table)
    (put-char-table (make-char 'latin-iso8859-9 114) (vector #x1D5 (make-char 'latin-iso8859-1 114) nil (make-char 'latin-iso8859-3 114) nil (make-char 'latin-iso8859-9 114) nil (make-char 'latin-iso8859-14 114) (make-char 'latin-iso8859-15 114) (make-char 'latin-iso8859-16 114) nil nil #xF2) table)
    (put-char-table (make-char 'latin-iso8859-9 115) (vector #x1F7 (make-char 'latin-iso8859-1 115) (make-char 'latin-iso8859-2 115) (make-char 'latin-iso8859-3 115) nil (make-char 'latin-iso8859-9 115) (make-char 'latin-iso8859-13 115) (make-char 'latin-iso8859-14 115) (make-char 'latin-iso8859-15 115) (make-char 'latin-iso8859-16 115) nil nil #xF3) table)
    (put-char-table (make-char 'latin-iso8859-9 116) (vector #x1DF (make-char 'latin-iso8859-1 116) (make-char 'latin-iso8859-2 116) (make-char 'latin-iso8859-3 116) (make-char 'latin-iso8859-4 116) (make-char 'latin-iso8859-9 116) nil (make-char 'latin-iso8859-14 116) (make-char 'latin-iso8859-15 116) (make-char 'latin-iso8859-16 116) nil nil #xF4) table)
    (put-char-table (make-char 'latin-iso8859-9 117) (vector #xF9 (make-char 'latin-iso8859-1 117) nil nil (make-char 'latin-iso8859-4 117) (make-char 'latin-iso8859-9 117) (make-char 'latin-iso8859-13 117) (make-char 'latin-iso8859-14 117) (make-char 'latin-iso8859-15 117) nil nil nil #xF5) table)
    (put-char-table (make-char 'latin-iso8859-9 118) (vector #x1FF (make-char 'latin-iso8859-1 118) (make-char 'latin-iso8859-2 118) (make-char 'latin-iso8859-3 118) (make-char 'latin-iso8859-4 118) (make-char 'latin-iso8859-9 118) (make-char 'latin-iso8859-13 118) (make-char 'latin-iso8859-14 118) (make-char 'latin-iso8859-15 118) (make-char 'latin-iso8859-16 118) nil nil #xF6) table)
    (put-char-table (make-char 'latin-iso8859-9 119) (vector #xBF (make-char 'latin-iso8859-1 119) (make-char 'latin-iso8859-2 119) (make-char 'latin-iso8859-3 119) (make-char 'latin-iso8859-4 119) (make-char 'latin-iso8859-9 119) (make-char 'latin-iso8859-13 119) nil (make-char 'latin-iso8859-15 119) nil nil nil #xF7) table)
    (put-char-table (make-char 'latin-iso8859-9 120) (vector #xF9 (make-char 'latin-iso8859-1 120) nil nil (make-char 'latin-iso8859-4 120) (make-char 'latin-iso8859-9 120) (make-char 'latin-iso8859-13 56) (make-char 'latin-iso8859-14 120) (make-char 'latin-iso8859-15 120) nil nil nil #xF8) table)
    (put-char-table (make-char 'latin-iso8859-9 121) (vector #x1D5 (make-char 'latin-iso8859-1 121) nil (make-char 'latin-iso8859-3 121) nil (make-char 'latin-iso8859-9 121) nil (make-char 'latin-iso8859-14 121) (make-char 'latin-iso8859-15 121) (make-char 'latin-iso8859-16 121) nil nil #xF9) table)
    (put-char-table (make-char 'latin-iso8859-9 122) (vector #x1DF (make-char 'latin-iso8859-1 122) (make-char 'latin-iso8859-2 122) (make-char 'latin-iso8859-3 122) (make-char 'latin-iso8859-4 122) (make-char 'latin-iso8859-9 122) nil (make-char 'latin-iso8859-14 122) (make-char 'latin-iso8859-15 122) (make-char 'latin-iso8859-16 122) nil nil #xFA) table)
    (put-char-table (make-char 'latin-iso8859-9 123) (vector #x1DD (make-char 'latin-iso8859-1 123) nil (make-char 'latin-iso8859-3 123) (make-char 'latin-iso8859-4 123) (make-char 'latin-iso8859-9 123) nil (make-char 'latin-iso8859-14 123) (make-char 'latin-iso8859-15 123) (make-char 'latin-iso8859-16 123) nil nil #xFB) table)
    (put-char-table (make-char 'latin-iso8859-9 124) (vector #x1FF (make-char 'latin-iso8859-1 124) (make-char 'latin-iso8859-2 124) (make-char 'latin-iso8859-3 124) (make-char 'latin-iso8859-4 124) (make-char 'latin-iso8859-9 124) (make-char 'latin-iso8859-13 124) (make-char 'latin-iso8859-14 124) (make-char 'latin-iso8859-15 124) (make-char 'latin-iso8859-16 124) nil nil #xFC) table)
    (put-char-table (make-char 'latin-iso8859-9 125) (vector #x14 nil nil (make-char 'latin-iso8859-3 57) nil (make-char 'latin-iso8859-9 125) nil nil nil nil nil nil #x131) table)
    (put-char-table (make-char 'latin-iso8859-9 126) (vector #x16 nil (make-char 'latin-iso8859-2 58) (make-char 'latin-iso8859-3 58) nil (make-char 'latin-iso8859-9 126) nil nil nil nil nil nil #x15F) table)
    (put-char-table (make-char 'latin-iso8859-9 127) (vector #x1D1 (make-char 'latin-iso8859-1 127) nil nil nil (make-char 'latin-iso8859-9 127) nil (make-char 'latin-iso8859-14 127) (make-char 'latin-iso8859-15 127) (make-char 'latin-iso8859-16 127) nil nil #xFF) table)
    (put-char-table (make-char 'latin-iso8859-13 32) (vector #x1FF (make-char 'latin-iso8859-1 32) (make-char 'latin-iso8859-2 32) (make-char 'latin-iso8859-3 32) (make-char 'latin-iso8859-4 32) (make-char 'latin-iso8859-9 32) (make-char 'latin-iso8859-13 32) (make-char 'latin-iso8859-14 32) (make-char 'latin-iso8859-15 32) (make-char 'latin-iso8859-16 32) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 33) (vector #x120 nil nil nil nil nil (make-char 'latin-iso8859-13 33) nil nil (make-char 'latin-iso8859-16 53) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 34) (vector #xB1 (make-char 'latin-iso8859-1 34) nil nil nil (make-char 'latin-iso8859-9 34) (make-char 'latin-iso8859-13 34) nil (make-char 'latin-iso8859-15 34) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 35) (vector #xF5 (make-char 'latin-iso8859-1 35) nil (make-char 'latin-iso8859-3 35) nil (make-char 'latin-iso8859-9 35) (make-char 'latin-iso8859-13 35) (make-char 'latin-iso8859-14 35) (make-char 'latin-iso8859-15 35) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 36) (vector #x3F (make-char 'latin-iso8859-1 36) (make-char 'latin-iso8859-2 36) (make-char 'latin-iso8859-3 36) (make-char 'latin-iso8859-4 36) (make-char 'latin-iso8859-9 36) (make-char 'latin-iso8859-13 36) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 37) (vector #x120 nil nil nil nil nil (make-char 'latin-iso8859-13 37) nil nil (make-char 'latin-iso8859-16 37) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 38) (vector #x31 (make-char 'latin-iso8859-1 38) nil nil nil (make-char 'latin-iso8859-9 38) (make-char 'latin-iso8859-13 38) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 39) (vector #x1FF (make-char 'latin-iso8859-1 39) (make-char 'latin-iso8859-2 39) (make-char 'latin-iso8859-3 39) (make-char 'latin-iso8859-4 39) (make-char 'latin-iso8859-9 39) (make-char 'latin-iso8859-13 39) (make-char 'latin-iso8859-14 39) (make-char 'latin-iso8859-15 39) (make-char 'latin-iso8859-16 39) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 40) (vector #xF9 (make-char 'latin-iso8859-1 88) nil nil (make-char 'latin-iso8859-4 88) (make-char 'latin-iso8859-9 88) (make-char 'latin-iso8859-13 40) (make-char 'latin-iso8859-14 88) (make-char 'latin-iso8859-15 88) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 41) (vector #x1F1 (make-char 'latin-iso8859-1 41) nil nil nil (make-char 'latin-iso8859-9 41) (make-char 'latin-iso8859-13 41) (make-char 'latin-iso8859-14 41) (make-char 'latin-iso8859-15 41) (make-char 'latin-iso8859-16 41) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 42) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 35) nil (make-char 'latin-iso8859-13 42) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 43) (vector #x1B1 (make-char 'latin-iso8859-1 43) nil nil nil (make-char 'latin-iso8859-9 43) (make-char 'latin-iso8859-13 43) nil (make-char 'latin-iso8859-15 43) (make-char 'latin-iso8859-16 43) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 44) (vector #xB1 (make-char 'latin-iso8859-1 44) nil nil nil (make-char 'latin-iso8859-9 44) (make-char 'latin-iso8859-13 44) nil (make-char 'latin-iso8859-15 44) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 45) (vector #x1FF (make-char 'latin-iso8859-1 45) (make-char 'latin-iso8859-2 45) (make-char 'latin-iso8859-3 45) (make-char 'latin-iso8859-4 45) (make-char 'latin-iso8859-9 45) (make-char 'latin-iso8859-13 45) (make-char 'latin-iso8859-14 45) (make-char 'latin-iso8859-15 45) (make-char 'latin-iso8859-16 45) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 46) (vector #xF1 (make-char 'latin-iso8859-1 46) nil nil nil (make-char 'latin-iso8859-9 46) (make-char 'latin-iso8859-13 46) (make-char 'latin-iso8859-14 46) (make-char 'latin-iso8859-15 46) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 47) (vector #x1F9 (make-char 'latin-iso8859-1 70) nil nil (make-char 'latin-iso8859-4 70) (make-char 'latin-iso8859-9 70) (make-char 'latin-iso8859-13 47) (make-char 'latin-iso8859-14 70) (make-char 'latin-iso8859-15 70) (make-char 'latin-iso8859-16 70) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 48) (vector #x1BF (make-char 'latin-iso8859-1 48) (make-char 'latin-iso8859-2 48) (make-char 'latin-iso8859-3 48) (make-char 'latin-iso8859-4 48) (make-char 'latin-iso8859-9 48) (make-char 'latin-iso8859-13 48) nil (make-char 'latin-iso8859-15 48) (make-char 'latin-iso8859-16 48) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 49) (vector #x1B1 (make-char 'latin-iso8859-1 49) nil nil nil (make-char 'latin-iso8859-9 49) (make-char 'latin-iso8859-13 49) nil (make-char 'latin-iso8859-15 49) (make-char 'latin-iso8859-16 49) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 50) (vector #xB5 (make-char 'latin-iso8859-1 50) nil (make-char 'latin-iso8859-3 50) nil (make-char 'latin-iso8859-9 50) (make-char 'latin-iso8859-13 50) nil (make-char 'latin-iso8859-15 50) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 51) (vector #xB5 (make-char 'latin-iso8859-1 51) nil (make-char 'latin-iso8859-3 51) nil (make-char 'latin-iso8859-9 51) (make-char 'latin-iso8859-13 51) nil (make-char 'latin-iso8859-15 51) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 52) (vector #x20 nil nil nil nil nil (make-char 'latin-iso8859-13 52) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 53) (vector #xB5 (make-char 'latin-iso8859-1 53) nil (make-char 'latin-iso8859-3 53) nil (make-char 'latin-iso8859-9 53) (make-char 'latin-iso8859-13 53) nil (make-char 'latin-iso8859-15 53) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 54) (vector #x1F1 (make-char 'latin-iso8859-1 54) nil nil nil (make-char 'latin-iso8859-9 54) (make-char 'latin-iso8859-13 54) (make-char 'latin-iso8859-14 54) (make-char 'latin-iso8859-15 54) (make-char 'latin-iso8859-16 54) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 55) (vector #x1B5 (make-char 'latin-iso8859-1 55) nil (make-char 'latin-iso8859-3 55) nil (make-char 'latin-iso8859-9 55) (make-char 'latin-iso8859-13 55) nil (make-char 'latin-iso8859-15 55) (make-char 'latin-iso8859-16 55) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 56) (vector #xF9 (make-char 'latin-iso8859-1 120) nil nil (make-char 'latin-iso8859-4 120) (make-char 'latin-iso8859-9 120) (make-char 'latin-iso8859-13 56) (make-char 'latin-iso8859-14 120) (make-char 'latin-iso8859-15 120) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 57) (vector #xB1 (make-char 'latin-iso8859-1 57) nil nil nil (make-char 'latin-iso8859-9 57) (make-char 'latin-iso8859-13 57) nil (make-char 'latin-iso8859-15 57) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 58) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 51) nil (make-char 'latin-iso8859-13 58) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 59) (vector #x1B1 (make-char 'latin-iso8859-1 59) nil nil nil (make-char 'latin-iso8859-9 59) (make-char 'latin-iso8859-13 59) nil (make-char 'latin-iso8859-15 59) (make-char 'latin-iso8859-16 59) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 60) (vector #x31 (make-char 'latin-iso8859-1 60) nil nil nil (make-char 'latin-iso8859-9 60) (make-char 'latin-iso8859-13 60) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 61) (vector #x35 (make-char 'latin-iso8859-1 61) nil (make-char 'latin-iso8859-3 61) nil (make-char 'latin-iso8859-9 61) (make-char 'latin-iso8859-13 61) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 62) (vector #x31 (make-char 'latin-iso8859-1 62) nil nil nil (make-char 'latin-iso8859-9 62) (make-char 'latin-iso8859-13 62) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 63) (vector #x1F9 (make-char 'latin-iso8859-1 102) nil nil (make-char 'latin-iso8859-4 102) (make-char 'latin-iso8859-9 102) (make-char 'latin-iso8859-13 63) (make-char 'latin-iso8859-14 102) (make-char 'latin-iso8859-15 102) (make-char 'latin-iso8859-16 102) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 64) (vector #x12A nil (make-char 'latin-iso8859-2 33) nil (make-char 'latin-iso8859-4 33) nil (make-char 'latin-iso8859-13 64) nil nil (make-char 'latin-iso8859-16 33) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 65) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 71) nil (make-char 'latin-iso8859-13 65) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 66) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 64) nil (make-char 'latin-iso8859-13 66) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 67) (vector #x122 nil (make-char 'latin-iso8859-2 70) nil nil nil (make-char 'latin-iso8859-13 67) nil nil (make-char 'latin-iso8859-16 69) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 68) (vector #x1FF (make-char 'latin-iso8859-1 68) (make-char 'latin-iso8859-2 68) (make-char 'latin-iso8859-3 68) (make-char 'latin-iso8859-4 68) (make-char 'latin-iso8859-9 68) (make-char 'latin-iso8859-13 68) (make-char 'latin-iso8859-14 68) (make-char 'latin-iso8859-15 68) (make-char 'latin-iso8859-16 68) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 69) (vector #xF9 (make-char 'latin-iso8859-1 69) nil nil (make-char 'latin-iso8859-4 69) (make-char 'latin-iso8859-9 69) (make-char 'latin-iso8859-13 69) (make-char 'latin-iso8859-14 69) (make-char 'latin-iso8859-15 69) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 70) (vector #x12A nil (make-char 'latin-iso8859-2 74) nil (make-char 'latin-iso8859-4 74) nil (make-char 'latin-iso8859-13 70) nil nil (make-char 'latin-iso8859-16 93) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 71) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 42) nil (make-char 'latin-iso8859-13 71) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 72) (vector #x12A nil (make-char 'latin-iso8859-2 72) nil (make-char 'latin-iso8859-4 72) nil (make-char 'latin-iso8859-13 72) nil nil (make-char 'latin-iso8859-16 50) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 73) (vector #x1FF (make-char 'latin-iso8859-1 73) (make-char 'latin-iso8859-2 73) (make-char 'latin-iso8859-3 73) (make-char 'latin-iso8859-4 73) (make-char 'latin-iso8859-9 73) (make-char 'latin-iso8859-13 73) (make-char 'latin-iso8859-14 73) (make-char 'latin-iso8859-15 73) (make-char 'latin-iso8859-16 73) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 74) (vector #x122 nil (make-char 'latin-iso8859-2 44) nil nil nil (make-char 'latin-iso8859-13 74) nil nil (make-char 'latin-iso8859-16 44) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 75) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 76) nil (make-char 'latin-iso8859-13 75) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 76) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 43) nil (make-char 'latin-iso8859-13 76) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 77) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 83) nil (make-char 'latin-iso8859-13 77) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 78) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 79) nil (make-char 'latin-iso8859-13 78) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 79) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 38) nil (make-char 'latin-iso8859-13 79) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 80) (vector #x1AA nil (make-char 'latin-iso8859-2 41) nil (make-char 'latin-iso8859-4 41) nil (make-char 'latin-iso8859-13 80) nil (make-char 'latin-iso8859-15 38) (make-char 'latin-iso8859-16 38) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 81) (vector #x122 nil (make-char 'latin-iso8859-2 81) nil nil nil (make-char 'latin-iso8859-13 81) nil nil (make-char 'latin-iso8859-16 81) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 82) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 81) nil (make-char 'latin-iso8859-13 82) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 83) (vector #x1F7 (make-char 'latin-iso8859-1 83) (make-char 'latin-iso8859-2 83) (make-char 'latin-iso8859-3 83) nil (make-char 'latin-iso8859-9 83) (make-char 'latin-iso8859-13 83) (make-char 'latin-iso8859-14 83) (make-char 'latin-iso8859-15 83) (make-char 'latin-iso8859-16 83) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 84) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 82) nil (make-char 'latin-iso8859-13 84) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 85) (vector #xF9 (make-char 'latin-iso8859-1 85) nil nil (make-char 'latin-iso8859-4 85) (make-char 'latin-iso8859-9 85) (make-char 'latin-iso8859-13 85) (make-char 'latin-iso8859-14 85) (make-char 'latin-iso8859-15 85) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 86) (vector #x1FF (make-char 'latin-iso8859-1 86) (make-char 'latin-iso8859-2 86) (make-char 'latin-iso8859-3 86) (make-char 'latin-iso8859-4 86) (make-char 'latin-iso8859-9 86) (make-char 'latin-iso8859-13 86) (make-char 'latin-iso8859-14 86) (make-char 'latin-iso8859-15 86) (make-char 'latin-iso8859-16 86) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 87) (vector #xBF (make-char 'latin-iso8859-1 87) (make-char 'latin-iso8859-2 87) (make-char 'latin-iso8859-3 87) (make-char 'latin-iso8859-4 87) (make-char 'latin-iso8859-9 87) (make-char 'latin-iso8859-13 87) nil (make-char 'latin-iso8859-15 87) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 88) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 89) nil (make-char 'latin-iso8859-13 88) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 89) (vector #x122 nil (make-char 'latin-iso8859-2 35) nil nil nil (make-char 'latin-iso8859-13 89) nil nil (make-char 'latin-iso8859-16 35) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 90) (vector #x122 nil (make-char 'latin-iso8859-2 38) nil nil nil (make-char 'latin-iso8859-13 90) nil nil (make-char 'latin-iso8859-16 87) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 91) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 94) nil (make-char 'latin-iso8859-13 91) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 92) (vector #x1FF (make-char 'latin-iso8859-1 92) (make-char 'latin-iso8859-2 92) (make-char 'latin-iso8859-3 92) (make-char 'latin-iso8859-4 92) (make-char 'latin-iso8859-9 92) (make-char 'latin-iso8859-13 92) (make-char 'latin-iso8859-14 92) (make-char 'latin-iso8859-15 92) (make-char 'latin-iso8859-16 92) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 93) (vector #x126 nil (make-char 'latin-iso8859-2 47) (make-char 'latin-iso8859-3 47) nil nil (make-char 'latin-iso8859-13 93) nil nil (make-char 'latin-iso8859-16 47) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 94) (vector #x1AA nil (make-char 'latin-iso8859-2 46) nil (make-char 'latin-iso8859-4 46) nil (make-char 'latin-iso8859-13 94) nil (make-char 'latin-iso8859-15 52) (make-char 'latin-iso8859-16 52) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 95) (vector #x1FF (make-char 'latin-iso8859-1 95) (make-char 'latin-iso8859-2 95) (make-char 'latin-iso8859-3 95) (make-char 'latin-iso8859-4 95) (make-char 'latin-iso8859-9 95) (make-char 'latin-iso8859-13 95) (make-char 'latin-iso8859-14 95) (make-char 'latin-iso8859-15 95) (make-char 'latin-iso8859-16 95) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 96) (vector #x12A nil (make-char 'latin-iso8859-2 49) nil (make-char 'latin-iso8859-4 49) nil (make-char 'latin-iso8859-13 96) nil nil (make-char 'latin-iso8859-16 34) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 97) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 103) nil (make-char 'latin-iso8859-13 97) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 98) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 96) nil (make-char 'latin-iso8859-13 98) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 99) (vector #x122 nil (make-char 'latin-iso8859-2 102) nil nil nil (make-char 'latin-iso8859-13 99) nil nil (make-char 'latin-iso8859-16 101) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 100) (vector #x1FF (make-char 'latin-iso8859-1 100) (make-char 'latin-iso8859-2 100) (make-char 'latin-iso8859-3 100) (make-char 'latin-iso8859-4 100) (make-char 'latin-iso8859-9 100) (make-char 'latin-iso8859-13 100) (make-char 'latin-iso8859-14 100) (make-char 'latin-iso8859-15 100) (make-char 'latin-iso8859-16 100) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 101) (vector #xF9 (make-char 'latin-iso8859-1 101) nil nil (make-char 'latin-iso8859-4 101) (make-char 'latin-iso8859-9 101) (make-char 'latin-iso8859-13 101) (make-char 'latin-iso8859-14 101) (make-char 'latin-iso8859-15 101) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 102) (vector #x12A nil (make-char 'latin-iso8859-2 106) nil (make-char 'latin-iso8859-4 106) nil (make-char 'latin-iso8859-13 102) nil nil (make-char 'latin-iso8859-16 125) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 103) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 58) nil (make-char 'latin-iso8859-13 103) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 104) (vector #x12A nil (make-char 'latin-iso8859-2 104) nil (make-char 'latin-iso8859-4 104) nil (make-char 'latin-iso8859-13 104) nil nil (make-char 'latin-iso8859-16 57) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 105) (vector #x1FF (make-char 'latin-iso8859-1 105) (make-char 'latin-iso8859-2 105) (make-char 'latin-iso8859-3 105) (make-char 'latin-iso8859-4 105) (make-char 'latin-iso8859-9 105) (make-char 'latin-iso8859-13 105) (make-char 'latin-iso8859-14 105) (make-char 'latin-iso8859-15 105) (make-char 'latin-iso8859-16 105) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 106) (vector #x122 nil (make-char 'latin-iso8859-2 60) nil nil nil (make-char 'latin-iso8859-13 106) nil nil (make-char 'latin-iso8859-16 46) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 107) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 108) nil (make-char 'latin-iso8859-13 107) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 108) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 59) nil (make-char 'latin-iso8859-13 108) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 109) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 115) nil (make-char 'latin-iso8859-13 109) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 110) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 111) nil (make-char 'latin-iso8859-13 110) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 111) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 54) nil (make-char 'latin-iso8859-13 111) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 112) (vector #x1AA nil (make-char 'latin-iso8859-2 57) nil (make-char 'latin-iso8859-4 57) nil (make-char 'latin-iso8859-13 112) nil (make-char 'latin-iso8859-15 40) (make-char 'latin-iso8859-16 40) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 113) (vector #x122 nil (make-char 'latin-iso8859-2 113) nil nil nil (make-char 'latin-iso8859-13 113) nil nil (make-char 'latin-iso8859-16 113) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 114) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 113) nil (make-char 'latin-iso8859-13 114) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 115) (vector #x1F7 (make-char 'latin-iso8859-1 115) (make-char 'latin-iso8859-2 115) (make-char 'latin-iso8859-3 115) nil (make-char 'latin-iso8859-9 115) (make-char 'latin-iso8859-13 115) (make-char 'latin-iso8859-14 115) (make-char 'latin-iso8859-15 115) (make-char 'latin-iso8859-16 115) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 116) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 114) nil (make-char 'latin-iso8859-13 116) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 117) (vector #xF9 (make-char 'latin-iso8859-1 117) nil nil (make-char 'latin-iso8859-4 117) (make-char 'latin-iso8859-9 117) (make-char 'latin-iso8859-13 117) (make-char 'latin-iso8859-14 117) (make-char 'latin-iso8859-15 117) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 118) (vector #x1FF (make-char 'latin-iso8859-1 118) (make-char 'latin-iso8859-2 118) (make-char 'latin-iso8859-3 118) (make-char 'latin-iso8859-4 118) (make-char 'latin-iso8859-9 118) (make-char 'latin-iso8859-13 118) (make-char 'latin-iso8859-14 118) (make-char 'latin-iso8859-15 118) (make-char 'latin-iso8859-16 118) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 119) (vector #xBF (make-char 'latin-iso8859-1 119) (make-char 'latin-iso8859-2 119) (make-char 'latin-iso8859-3 119) (make-char 'latin-iso8859-4 119) (make-char 'latin-iso8859-9 119) (make-char 'latin-iso8859-13 119) nil (make-char 'latin-iso8859-15 119) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 120) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 121) nil (make-char 'latin-iso8859-13 120) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 121) (vector #x122 nil (make-char 'latin-iso8859-2 51) nil nil nil (make-char 'latin-iso8859-13 121) nil nil (make-char 'latin-iso8859-16 51) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 122) (vector #x122 nil (make-char 'latin-iso8859-2 54) nil nil nil (make-char 'latin-iso8859-13 122) nil nil (make-char 'latin-iso8859-16 119) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 123) (vector #x28 nil nil nil (make-char 'latin-iso8859-4 126) nil (make-char 'latin-iso8859-13 123) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 124) (vector #x1FF (make-char 'latin-iso8859-1 124) (make-char 'latin-iso8859-2 124) (make-char 'latin-iso8859-3 124) (make-char 'latin-iso8859-4 124) (make-char 'latin-iso8859-9 124) (make-char 'latin-iso8859-13 124) (make-char 'latin-iso8859-14 124) (make-char 'latin-iso8859-15 124) (make-char 'latin-iso8859-16 124) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 125) (vector #x126 nil (make-char 'latin-iso8859-2 63) (make-char 'latin-iso8859-3 63) nil nil (make-char 'latin-iso8859-13 125) nil nil (make-char 'latin-iso8859-16 63) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 126) (vector #x1AA nil (make-char 'latin-iso8859-2 62) nil (make-char 'latin-iso8859-4 62) nil (make-char 'latin-iso8859-13 126) nil (make-char 'latin-iso8859-15 56) (make-char 'latin-iso8859-16 56) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-13 127) (vector #x20 nil nil nil nil nil (make-char 'latin-iso8859-13 127) nil nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 32) (vector #x1FF (make-char 'latin-iso8859-1 32) (make-char 'latin-iso8859-2 32) (make-char 'latin-iso8859-3 32) (make-char 'latin-iso8859-4 32) (make-char 'latin-iso8859-9 32) (make-char 'latin-iso8859-13 32) (make-char 'latin-iso8859-14 32) (make-char 'latin-iso8859-15 32) (make-char 'latin-iso8859-16 32) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 33) (vector #x91 (make-char 'latin-iso8859-1 33) nil nil nil (make-char 'latin-iso8859-9 33) nil nil (make-char 'latin-iso8859-15 33) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 34) (vector #xB1 (make-char 'latin-iso8859-1 34) nil nil nil (make-char 'latin-iso8859-9 34) (make-char 'latin-iso8859-13 34) nil (make-char 'latin-iso8859-15 34) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 35) (vector #xF5 (make-char 'latin-iso8859-1 35) nil (make-char 'latin-iso8859-3 35) nil (make-char 'latin-iso8859-9 35) (make-char 'latin-iso8859-13 35) (make-char 'latin-iso8859-14 35) (make-char 'latin-iso8859-15 35) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 36) (vector #x180 nil nil nil nil nil nil nil (make-char 'latin-iso8859-15 36) (make-char 'latin-iso8859-16 36) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 37) (vector #x491 (make-char 'latin-iso8859-1 37) nil nil nil (make-char 'latin-iso8859-9 37) nil nil (make-char 'latin-iso8859-15 37) nil nil (make-char 'latin-jisx0201 92) nil) table)
    (put-char-table (make-char 'latin-iso8859-15 38) (vector #x1AA nil (make-char 'latin-iso8859-2 41) nil (make-char 'latin-iso8859-4 41) nil (make-char 'latin-iso8859-13 80) nil (make-char 'latin-iso8859-15 38) (make-char 'latin-iso8859-16 38) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 39) (vector #x1FF (make-char 'latin-iso8859-1 39) (make-char 'latin-iso8859-2 39) (make-char 'latin-iso8859-3 39) (make-char 'latin-iso8859-4 39) (make-char 'latin-iso8859-9 39) (make-char 'latin-iso8859-13 39) (make-char 'latin-iso8859-14 39) (make-char 'latin-iso8859-15 39) (make-char 'latin-iso8859-16 39) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 40) (vector #x1AA nil (make-char 'latin-iso8859-2 57) nil (make-char 'latin-iso8859-4 57) nil (make-char 'latin-iso8859-13 112) nil (make-char 'latin-iso8859-15 40) (make-char 'latin-iso8859-16 40) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 41) (vector #x1F1 (make-char 'latin-iso8859-1 41) nil nil nil (make-char 'latin-iso8859-9 41) (make-char 'latin-iso8859-13 41) (make-char 'latin-iso8859-14 41) (make-char 'latin-iso8859-15 41) (make-char 'latin-iso8859-16 41) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 42) (vector #x91 (make-char 'latin-iso8859-1 42) nil nil nil (make-char 'latin-iso8859-9 42) nil nil (make-char 'latin-iso8859-15 42) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 43) (vector #x1B1 (make-char 'latin-iso8859-1 43) nil nil nil (make-char 'latin-iso8859-9 43) (make-char 'latin-iso8859-13 43) nil (make-char 'latin-iso8859-15 43) (make-char 'latin-iso8859-16 43) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 44) (vector #xB1 (make-char 'latin-iso8859-1 44) nil nil nil (make-char 'latin-iso8859-9 44) (make-char 'latin-iso8859-13 44) nil (make-char 'latin-iso8859-15 44) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 45) (vector #x1FF (make-char 'latin-iso8859-1 45) (make-char 'latin-iso8859-2 45) (make-char 'latin-iso8859-3 45) (make-char 'latin-iso8859-4 45) (make-char 'latin-iso8859-9 45) (make-char 'latin-iso8859-13 45) (make-char 'latin-iso8859-14 45) (make-char 'latin-iso8859-15 45) (make-char 'latin-iso8859-16 45) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 46) (vector #xF1 (make-char 'latin-iso8859-1 46) nil nil nil (make-char 'latin-iso8859-9 46) (make-char 'latin-iso8859-13 46) (make-char 'latin-iso8859-14 46) (make-char 'latin-iso8859-15 46) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 47) (vector #x99 (make-char 'latin-iso8859-1 47) nil nil (make-char 'latin-iso8859-4 47) (make-char 'latin-iso8859-9 47) nil nil (make-char 'latin-iso8859-15 47) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 48) (vector #x1BF (make-char 'latin-iso8859-1 48) (make-char 'latin-iso8859-2 48) (make-char 'latin-iso8859-3 48) (make-char 'latin-iso8859-4 48) (make-char 'latin-iso8859-9 48) (make-char 'latin-iso8859-13 48) nil (make-char 'latin-iso8859-15 48) (make-char 'latin-iso8859-16 48) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 49) (vector #x1B1 (make-char 'latin-iso8859-1 49) nil nil nil (make-char 'latin-iso8859-9 49) (make-char 'latin-iso8859-13 49) nil (make-char 'latin-iso8859-15 49) (make-char 'latin-iso8859-16 49) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 50) (vector #xB5 (make-char 'latin-iso8859-1 50) nil (make-char 'latin-iso8859-3 50) nil (make-char 'latin-iso8859-9 50) (make-char 'latin-iso8859-13 50) nil (make-char 'latin-iso8859-15 50) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 51) (vector #xB5 (make-char 'latin-iso8859-1 51) nil (make-char 'latin-iso8859-3 51) nil (make-char 'latin-iso8859-9 51) (make-char 'latin-iso8859-13 51) nil (make-char 'latin-iso8859-15 51) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 52) (vector #x1AA nil (make-char 'latin-iso8859-2 46) nil (make-char 'latin-iso8859-4 46) nil (make-char 'latin-iso8859-13 94) nil (make-char 'latin-iso8859-15 52) (make-char 'latin-iso8859-16 52) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 53) (vector #xB5 (make-char 'latin-iso8859-1 53) nil (make-char 'latin-iso8859-3 53) nil (make-char 'latin-iso8859-9 53) (make-char 'latin-iso8859-13 53) nil (make-char 'latin-iso8859-15 53) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 54) (vector #x1F1 (make-char 'latin-iso8859-1 54) nil nil nil (make-char 'latin-iso8859-9 54) (make-char 'latin-iso8859-13 54) (make-char 'latin-iso8859-14 54) (make-char 'latin-iso8859-15 54) (make-char 'latin-iso8859-16 54) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 55) (vector #x1B5 (make-char 'latin-iso8859-1 55) nil (make-char 'latin-iso8859-3 55) nil (make-char 'latin-iso8859-9 55) (make-char 'latin-iso8859-13 55) nil (make-char 'latin-iso8859-15 55) (make-char 'latin-iso8859-16 55) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 56) (vector #x1AA nil (make-char 'latin-iso8859-2 62) nil (make-char 'latin-iso8859-4 62) nil (make-char 'latin-iso8859-13 126) nil (make-char 'latin-iso8859-15 56) (make-char 'latin-iso8859-16 56) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 57) (vector #xB1 (make-char 'latin-iso8859-1 57) nil nil nil (make-char 'latin-iso8859-9 57) (make-char 'latin-iso8859-13 57) nil (make-char 'latin-iso8859-15 57) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 58) (vector #x91 (make-char 'latin-iso8859-1 58) nil nil nil (make-char 'latin-iso8859-9 58) nil nil (make-char 'latin-iso8859-15 58) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 59) (vector #x1B1 (make-char 'latin-iso8859-1 59) nil nil nil (make-char 'latin-iso8859-9 59) (make-char 'latin-iso8859-13 59) nil (make-char 'latin-iso8859-15 59) (make-char 'latin-iso8859-16 59) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 60) (vector #x180 nil nil nil nil nil nil nil (make-char 'latin-iso8859-15 60) (make-char 'latin-iso8859-16 60) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 61) (vector #x180 nil nil nil nil nil nil nil (make-char 'latin-iso8859-15 61) (make-char 'latin-iso8859-16 61) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 62) (vector #x1C0 nil nil nil nil nil nil (make-char 'latin-iso8859-14 47) (make-char 'latin-iso8859-15 62) (make-char 'latin-iso8859-16 62) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 63) (vector #x91 (make-char 'latin-iso8859-1 63) nil nil nil (make-char 'latin-iso8859-9 63) nil nil (make-char 'latin-iso8859-15 63) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 64) (vector #x1D5 (make-char 'latin-iso8859-1 64) nil (make-char 'latin-iso8859-3 64) nil (make-char 'latin-iso8859-9 64) nil (make-char 'latin-iso8859-14 64) (make-char 'latin-iso8859-15 64) (make-char 'latin-iso8859-16 64) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 65) (vector #x1DF (make-char 'latin-iso8859-1 65) (make-char 'latin-iso8859-2 65) (make-char 'latin-iso8859-3 65) (make-char 'latin-iso8859-4 65) (make-char 'latin-iso8859-9 65) nil (make-char 'latin-iso8859-14 65) (make-char 'latin-iso8859-15 65) (make-char 'latin-iso8859-16 65) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 66) (vector #x1DF (make-char 'latin-iso8859-1 66) (make-char 'latin-iso8859-2 66) (make-char 'latin-iso8859-3 66) (make-char 'latin-iso8859-4 66) (make-char 'latin-iso8859-9 66) nil (make-char 'latin-iso8859-14 66) (make-char 'latin-iso8859-15 66) (make-char 'latin-iso8859-16 66) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 67) (vector #xD9 (make-char 'latin-iso8859-1 67) nil nil (make-char 'latin-iso8859-4 67) (make-char 'latin-iso8859-9 67) nil (make-char 'latin-iso8859-14 67) (make-char 'latin-iso8859-15 67) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 68) (vector #x1FF (make-char 'latin-iso8859-1 68) (make-char 'latin-iso8859-2 68) (make-char 'latin-iso8859-3 68) (make-char 'latin-iso8859-4 68) (make-char 'latin-iso8859-9 68) (make-char 'latin-iso8859-13 68) (make-char 'latin-iso8859-14 68) (make-char 'latin-iso8859-15 68) (make-char 'latin-iso8859-16 68) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 69) (vector #xF9 (make-char 'latin-iso8859-1 69) nil nil (make-char 'latin-iso8859-4 69) (make-char 'latin-iso8859-9 69) (make-char 'latin-iso8859-13 69) (make-char 'latin-iso8859-14 69) (make-char 'latin-iso8859-15 69) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 70) (vector #x1F9 (make-char 'latin-iso8859-1 70) nil nil (make-char 'latin-iso8859-4 70) (make-char 'latin-iso8859-9 70) (make-char 'latin-iso8859-13 47) (make-char 'latin-iso8859-14 70) (make-char 'latin-iso8859-15 70) (make-char 'latin-iso8859-16 70) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 71) (vector #x1D7 (make-char 'latin-iso8859-1 71) (make-char 'latin-iso8859-2 71) (make-char 'latin-iso8859-3 71) nil (make-char 'latin-iso8859-9 71) nil (make-char 'latin-iso8859-14 71) (make-char 'latin-iso8859-15 71) (make-char 'latin-iso8859-16 71) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 72) (vector #x1D5 (make-char 'latin-iso8859-1 72) nil (make-char 'latin-iso8859-3 72) nil (make-char 'latin-iso8859-9 72) nil (make-char 'latin-iso8859-14 72) (make-char 'latin-iso8859-15 72) (make-char 'latin-iso8859-16 72) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 73) (vector #x1FF (make-char 'latin-iso8859-1 73) (make-char 'latin-iso8859-2 73) (make-char 'latin-iso8859-3 73) (make-char 'latin-iso8859-4 73) (make-char 'latin-iso8859-9 73) (make-char 'latin-iso8859-13 73) (make-char 'latin-iso8859-14 73) (make-char 'latin-iso8859-15 73) (make-char 'latin-iso8859-16 73) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 74) (vector #x1D5 (make-char 'latin-iso8859-1 74) nil (make-char 'latin-iso8859-3 74) nil (make-char 'latin-iso8859-9 74) nil (make-char 'latin-iso8859-14 74) (make-char 'latin-iso8859-15 74) (make-char 'latin-iso8859-16 74) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 75) (vector #x1DF (make-char 'latin-iso8859-1 75) (make-char 'latin-iso8859-2 75) (make-char 'latin-iso8859-3 75) (make-char 'latin-iso8859-4 75) (make-char 'latin-iso8859-9 75) nil (make-char 'latin-iso8859-14 75) (make-char 'latin-iso8859-15 75) (make-char 'latin-iso8859-16 75) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 76) (vector #x1D5 (make-char 'latin-iso8859-1 76) nil (make-char 'latin-iso8859-3 76) nil (make-char 'latin-iso8859-9 76) nil (make-char 'latin-iso8859-14 76) (make-char 'latin-iso8859-15 76) (make-char 'latin-iso8859-16 76) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 77) (vector #x1DF (make-char 'latin-iso8859-1 77) (make-char 'latin-iso8859-2 77) (make-char 'latin-iso8859-3 77) (make-char 'latin-iso8859-4 77) (make-char 'latin-iso8859-9 77) nil (make-char 'latin-iso8859-14 77) (make-char 'latin-iso8859-15 77) (make-char 'latin-iso8859-16 77) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 78) (vector #x1DF (make-char 'latin-iso8859-1 78) (make-char 'latin-iso8859-2 78) (make-char 'latin-iso8859-3 78) (make-char 'latin-iso8859-4 78) (make-char 'latin-iso8859-9 78) nil (make-char 'latin-iso8859-14 78) (make-char 'latin-iso8859-15 78) (make-char 'latin-iso8859-16 78) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 79) (vector #x1D5 (make-char 'latin-iso8859-1 79) nil (make-char 'latin-iso8859-3 79) nil (make-char 'latin-iso8859-9 79) nil (make-char 'latin-iso8859-14 79) (make-char 'latin-iso8859-15 79) (make-char 'latin-iso8859-16 79) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 80) (vector #x81 (make-char 'latin-iso8859-1 80) nil nil nil nil nil nil (make-char 'latin-iso8859-15 80) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 81) (vector #xD5 (make-char 'latin-iso8859-1 81) nil (make-char 'latin-iso8859-3 81) nil (make-char 'latin-iso8859-9 81) nil (make-char 'latin-iso8859-14 81) (make-char 'latin-iso8859-15 81) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 82) (vector #x1D5 (make-char 'latin-iso8859-1 82) nil (make-char 'latin-iso8859-3 82) nil (make-char 'latin-iso8859-9 82) nil (make-char 'latin-iso8859-14 82) (make-char 'latin-iso8859-15 82) (make-char 'latin-iso8859-16 82) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 83) (vector #x1F7 (make-char 'latin-iso8859-1 83) (make-char 'latin-iso8859-2 83) (make-char 'latin-iso8859-3 83) nil (make-char 'latin-iso8859-9 83) (make-char 'latin-iso8859-13 83) (make-char 'latin-iso8859-14 83) (make-char 'latin-iso8859-15 83) (make-char 'latin-iso8859-16 83) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 84) (vector #x1DF (make-char 'latin-iso8859-1 84) (make-char 'latin-iso8859-2 84) (make-char 'latin-iso8859-3 84) (make-char 'latin-iso8859-4 84) (make-char 'latin-iso8859-9 84) nil (make-char 'latin-iso8859-14 84) (make-char 'latin-iso8859-15 84) (make-char 'latin-iso8859-16 84) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 85) (vector #xF9 (make-char 'latin-iso8859-1 85) nil nil (make-char 'latin-iso8859-4 85) (make-char 'latin-iso8859-9 85) (make-char 'latin-iso8859-13 85) (make-char 'latin-iso8859-14 85) (make-char 'latin-iso8859-15 85) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 86) (vector #x1FF (make-char 'latin-iso8859-1 86) (make-char 'latin-iso8859-2 86) (make-char 'latin-iso8859-3 86) (make-char 'latin-iso8859-4 86) (make-char 'latin-iso8859-9 86) (make-char 'latin-iso8859-13 86) (make-char 'latin-iso8859-14 86) (make-char 'latin-iso8859-15 86) (make-char 'latin-iso8859-16 86) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 87) (vector #xBF (make-char 'latin-iso8859-1 87) (make-char 'latin-iso8859-2 87) (make-char 'latin-iso8859-3 87) (make-char 'latin-iso8859-4 87) (make-char 'latin-iso8859-9 87) (make-char 'latin-iso8859-13 87) nil (make-char 'latin-iso8859-15 87) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 88) (vector #xF9 (make-char 'latin-iso8859-1 88) nil nil (make-char 'latin-iso8859-4 88) (make-char 'latin-iso8859-9 88) (make-char 'latin-iso8859-13 40) (make-char 'latin-iso8859-14 88) (make-char 'latin-iso8859-15 88) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 89) (vector #x1D5 (make-char 'latin-iso8859-1 89) nil (make-char 'latin-iso8859-3 89) nil (make-char 'latin-iso8859-9 89) nil (make-char 'latin-iso8859-14 89) (make-char 'latin-iso8859-15 89) (make-char 'latin-iso8859-16 89) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 90) (vector #x1DF (make-char 'latin-iso8859-1 90) (make-char 'latin-iso8859-2 90) (make-char 'latin-iso8859-3 90) (make-char 'latin-iso8859-4 90) (make-char 'latin-iso8859-9 90) nil (make-char 'latin-iso8859-14 90) (make-char 'latin-iso8859-15 90) (make-char 'latin-iso8859-16 90) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 91) (vector #x1DD (make-char 'latin-iso8859-1 91) nil (make-char 'latin-iso8859-3 91) (make-char 'latin-iso8859-4 91) (make-char 'latin-iso8859-9 91) nil (make-char 'latin-iso8859-14 91) (make-char 'latin-iso8859-15 91) (make-char 'latin-iso8859-16 91) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 92) (vector #x1FF (make-char 'latin-iso8859-1 92) (make-char 'latin-iso8859-2 92) (make-char 'latin-iso8859-3 92) (make-char 'latin-iso8859-4 92) (make-char 'latin-iso8859-9 92) (make-char 'latin-iso8859-13 92) (make-char 'latin-iso8859-14 92) (make-char 'latin-iso8859-15 92) (make-char 'latin-iso8859-16 92) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 93) (vector #xC3 (make-char 'latin-iso8859-1 93) (make-char 'latin-iso8859-2 93) nil nil nil nil (make-char 'latin-iso8859-14 93) (make-char 'latin-iso8859-15 93) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 94) (vector #x81 (make-char 'latin-iso8859-1 94) nil nil nil nil nil nil (make-char 'latin-iso8859-15 94) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 95) (vector #x1FF (make-char 'latin-iso8859-1 95) (make-char 'latin-iso8859-2 95) (make-char 'latin-iso8859-3 95) (make-char 'latin-iso8859-4 95) (make-char 'latin-iso8859-9 95) (make-char 'latin-iso8859-13 95) (make-char 'latin-iso8859-14 95) (make-char 'latin-iso8859-15 95) (make-char 'latin-iso8859-16 95) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 96) (vector #x1D5 (make-char 'latin-iso8859-1 96) nil (make-char 'latin-iso8859-3 96) nil (make-char 'latin-iso8859-9 96) nil (make-char 'latin-iso8859-14 96) (make-char 'latin-iso8859-15 96) (make-char 'latin-iso8859-16 96) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 97) (vector #x1DF (make-char 'latin-iso8859-1 97) (make-char 'latin-iso8859-2 97) (make-char 'latin-iso8859-3 97) (make-char 'latin-iso8859-4 97) (make-char 'latin-iso8859-9 97) nil (make-char 'latin-iso8859-14 97) (make-char 'latin-iso8859-15 97) (make-char 'latin-iso8859-16 97) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 98) (vector #x1DF (make-char 'latin-iso8859-1 98) (make-char 'latin-iso8859-2 98) (make-char 'latin-iso8859-3 98) (make-char 'latin-iso8859-4 98) (make-char 'latin-iso8859-9 98) nil (make-char 'latin-iso8859-14 98) (make-char 'latin-iso8859-15 98) (make-char 'latin-iso8859-16 98) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 99) (vector #xD9 (make-char 'latin-iso8859-1 99) nil nil (make-char 'latin-iso8859-4 99) (make-char 'latin-iso8859-9 99) nil (make-char 'latin-iso8859-14 99) (make-char 'latin-iso8859-15 99) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 100) (vector #x1FF (make-char 'latin-iso8859-1 100) (make-char 'latin-iso8859-2 100) (make-char 'latin-iso8859-3 100) (make-char 'latin-iso8859-4 100) (make-char 'latin-iso8859-9 100) (make-char 'latin-iso8859-13 100) (make-char 'latin-iso8859-14 100) (make-char 'latin-iso8859-15 100) (make-char 'latin-iso8859-16 100) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 101) (vector #xF9 (make-char 'latin-iso8859-1 101) nil nil (make-char 'latin-iso8859-4 101) (make-char 'latin-iso8859-9 101) (make-char 'latin-iso8859-13 101) (make-char 'latin-iso8859-14 101) (make-char 'latin-iso8859-15 101) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 102) (vector #x1F9 (make-char 'latin-iso8859-1 102) nil nil (make-char 'latin-iso8859-4 102) (make-char 'latin-iso8859-9 102) (make-char 'latin-iso8859-13 63) (make-char 'latin-iso8859-14 102) (make-char 'latin-iso8859-15 102) (make-char 'latin-iso8859-16 102) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 103) (vector #x1D7 (make-char 'latin-iso8859-1 103) (make-char 'latin-iso8859-2 103) (make-char 'latin-iso8859-3 103) nil (make-char 'latin-iso8859-9 103) nil (make-char 'latin-iso8859-14 103) (make-char 'latin-iso8859-15 103) (make-char 'latin-iso8859-16 103) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 104) (vector #x1D5 (make-char 'latin-iso8859-1 104) nil (make-char 'latin-iso8859-3 104) nil (make-char 'latin-iso8859-9 104) nil (make-char 'latin-iso8859-14 104) (make-char 'latin-iso8859-15 104) (make-char 'latin-iso8859-16 104) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 105) (vector #x1FF (make-char 'latin-iso8859-1 105) (make-char 'latin-iso8859-2 105) (make-char 'latin-iso8859-3 105) (make-char 'latin-iso8859-4 105) (make-char 'latin-iso8859-9 105) (make-char 'latin-iso8859-13 105) (make-char 'latin-iso8859-14 105) (make-char 'latin-iso8859-15 105) (make-char 'latin-iso8859-16 105) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 106) (vector #x1D5 (make-char 'latin-iso8859-1 106) nil (make-char 'latin-iso8859-3 106) nil (make-char 'latin-iso8859-9 106) nil (make-char 'latin-iso8859-14 106) (make-char 'latin-iso8859-15 106) (make-char 'latin-iso8859-16 106) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 107) (vector #x1DF (make-char 'latin-iso8859-1 107) (make-char 'latin-iso8859-2 107) (make-char 'latin-iso8859-3 107) (make-char 'latin-iso8859-4 107) (make-char 'latin-iso8859-9 107) nil (make-char 'latin-iso8859-14 107) (make-char 'latin-iso8859-15 107) (make-char 'latin-iso8859-16 107) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 108) (vector #x1D5 (make-char 'latin-iso8859-1 108) nil (make-char 'latin-iso8859-3 108) nil (make-char 'latin-iso8859-9 108) nil (make-char 'latin-iso8859-14 108) (make-char 'latin-iso8859-15 108) (make-char 'latin-iso8859-16 108) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 109) (vector #x1DF (make-char 'latin-iso8859-1 109) (make-char 'latin-iso8859-2 109) (make-char 'latin-iso8859-3 109) (make-char 'latin-iso8859-4 109) (make-char 'latin-iso8859-9 109) nil (make-char 'latin-iso8859-14 109) (make-char 'latin-iso8859-15 109) (make-char 'latin-iso8859-16 109) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 110) (vector #x1DF (make-char 'latin-iso8859-1 110) (make-char 'latin-iso8859-2 110) (make-char 'latin-iso8859-3 110) (make-char 'latin-iso8859-4 110) (make-char 'latin-iso8859-9 110) nil (make-char 'latin-iso8859-14 110) (make-char 'latin-iso8859-15 110) (make-char 'latin-iso8859-16 110) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 111) (vector #x1D5 (make-char 'latin-iso8859-1 111) nil (make-char 'latin-iso8859-3 111) nil (make-char 'latin-iso8859-9 111) nil (make-char 'latin-iso8859-14 111) (make-char 'latin-iso8859-15 111) (make-char 'latin-iso8859-16 111) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 112) (vector #x81 (make-char 'latin-iso8859-1 112) nil nil nil nil nil nil (make-char 'latin-iso8859-15 112) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 113) (vector #xD5 (make-char 'latin-iso8859-1 113) nil (make-char 'latin-iso8859-3 113) nil (make-char 'latin-iso8859-9 113) nil (make-char 'latin-iso8859-14 113) (make-char 'latin-iso8859-15 113) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 114) (vector #x1D5 (make-char 'latin-iso8859-1 114) nil (make-char 'latin-iso8859-3 114) nil (make-char 'latin-iso8859-9 114) nil (make-char 'latin-iso8859-14 114) (make-char 'latin-iso8859-15 114) (make-char 'latin-iso8859-16 114) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 115) (vector #x1F7 (make-char 'latin-iso8859-1 115) (make-char 'latin-iso8859-2 115) (make-char 'latin-iso8859-3 115) nil (make-char 'latin-iso8859-9 115) (make-char 'latin-iso8859-13 115) (make-char 'latin-iso8859-14 115) (make-char 'latin-iso8859-15 115) (make-char 'latin-iso8859-16 115) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 116) (vector #x1DF (make-char 'latin-iso8859-1 116) (make-char 'latin-iso8859-2 116) (make-char 'latin-iso8859-3 116) (make-char 'latin-iso8859-4 116) (make-char 'latin-iso8859-9 116) nil (make-char 'latin-iso8859-14 116) (make-char 'latin-iso8859-15 116) (make-char 'latin-iso8859-16 116) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 117) (vector #xF9 (make-char 'latin-iso8859-1 117) nil nil (make-char 'latin-iso8859-4 117) (make-char 'latin-iso8859-9 117) (make-char 'latin-iso8859-13 117) (make-char 'latin-iso8859-14 117) (make-char 'latin-iso8859-15 117) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 118) (vector #x1FF (make-char 'latin-iso8859-1 118) (make-char 'latin-iso8859-2 118) (make-char 'latin-iso8859-3 118) (make-char 'latin-iso8859-4 118) (make-char 'latin-iso8859-9 118) (make-char 'latin-iso8859-13 118) (make-char 'latin-iso8859-14 118) (make-char 'latin-iso8859-15 118) (make-char 'latin-iso8859-16 118) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 119) (vector #xBF (make-char 'latin-iso8859-1 119) (make-char 'latin-iso8859-2 119) (make-char 'latin-iso8859-3 119) (make-char 'latin-iso8859-4 119) (make-char 'latin-iso8859-9 119) (make-char 'latin-iso8859-13 119) nil (make-char 'latin-iso8859-15 119) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 120) (vector #xF9 (make-char 'latin-iso8859-1 120) nil nil (make-char 'latin-iso8859-4 120) (make-char 'latin-iso8859-9 120) (make-char 'latin-iso8859-13 56) (make-char 'latin-iso8859-14 120) (make-char 'latin-iso8859-15 120) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 121) (vector #x1D5 (make-char 'latin-iso8859-1 121) nil (make-char 'latin-iso8859-3 121) nil (make-char 'latin-iso8859-9 121) nil (make-char 'latin-iso8859-14 121) (make-char 'latin-iso8859-15 121) (make-char 'latin-iso8859-16 121) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 122) (vector #x1DF (make-char 'latin-iso8859-1 122) (make-char 'latin-iso8859-2 122) (make-char 'latin-iso8859-3 122) (make-char 'latin-iso8859-4 122) (make-char 'latin-iso8859-9 122) nil (make-char 'latin-iso8859-14 122) (make-char 'latin-iso8859-15 122) (make-char 'latin-iso8859-16 122) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 123) (vector #x1DD (make-char 'latin-iso8859-1 123) nil (make-char 'latin-iso8859-3 123) (make-char 'latin-iso8859-4 123) (make-char 'latin-iso8859-9 123) nil (make-char 'latin-iso8859-14 123) (make-char 'latin-iso8859-15 123) (make-char 'latin-iso8859-16 123) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 124) (vector #x1FF (make-char 'latin-iso8859-1 124) (make-char 'latin-iso8859-2 124) (make-char 'latin-iso8859-3 124) (make-char 'latin-iso8859-4 124) (make-char 'latin-iso8859-9 124) (make-char 'latin-iso8859-13 124) (make-char 'latin-iso8859-14 124) (make-char 'latin-iso8859-15 124) (make-char 'latin-iso8859-16 124) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 125) (vector #xC3 (make-char 'latin-iso8859-1 125) (make-char 'latin-iso8859-2 125) nil nil nil nil (make-char 'latin-iso8859-14 125) (make-char 'latin-iso8859-15 125) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 126) (vector #x81 (make-char 'latin-iso8859-1 126) nil nil nil nil nil nil (make-char 'latin-iso8859-15 126) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-15 127) (vector #x1D1 (make-char 'latin-iso8859-1 127) nil nil nil (make-char 'latin-iso8859-9 127) nil (make-char 'latin-iso8859-14 127) (make-char 'latin-iso8859-15 127) (make-char 'latin-iso8859-16 127) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 32) (vector #x1FF (make-char 'latin-iso8859-1 32) (make-char 'latin-iso8859-2 32) (make-char 'latin-iso8859-3 32) (make-char 'latin-iso8859-4 32) (make-char 'latin-iso8859-9 32) (make-char 'latin-iso8859-13 32) (make-char 'latin-iso8859-14 32) (make-char 'latin-iso8859-15 32) (make-char 'latin-iso8859-16 32) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 33) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 33) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 34) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 34) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 35) (vector #xF5 (make-char 'latin-iso8859-1 35) nil (make-char 'latin-iso8859-3 35) nil (make-char 'latin-iso8859-9 35) (make-char 'latin-iso8859-13 35) (make-char 'latin-iso8859-14 35) (make-char 'latin-iso8859-15 35) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 36) (vector #x44 nil nil (make-char 'latin-iso8859-3 69) nil nil nil (make-char 'latin-iso8859-14 36) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 37) (vector #x44 nil nil (make-char 'latin-iso8859-3 101) nil nil nil (make-char 'latin-iso8859-14 37) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 38) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 38) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 39) (vector #x1FF (make-char 'latin-iso8859-1 39) (make-char 'latin-iso8859-2 39) (make-char 'latin-iso8859-3 39) (make-char 'latin-iso8859-4 39) (make-char 'latin-iso8859-9 39) (make-char 'latin-iso8859-13 39) (make-char 'latin-iso8859-14 39) (make-char 'latin-iso8859-15 39) (make-char 'latin-iso8859-16 39) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 40) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 40) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 41) (vector #x1F1 (make-char 'latin-iso8859-1 41) nil nil nil (make-char 'latin-iso8859-9 41) (make-char 'latin-iso8859-13 41) (make-char 'latin-iso8859-14 41) (make-char 'latin-iso8859-15 41) (make-char 'latin-iso8859-16 41) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 42) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 42) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 43) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 43) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 44) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 44) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 45) (vector #x1FF (make-char 'latin-iso8859-1 45) (make-char 'latin-iso8859-2 45) (make-char 'latin-iso8859-3 45) (make-char 'latin-iso8859-4 45) (make-char 'latin-iso8859-9 45) (make-char 'latin-iso8859-13 45) (make-char 'latin-iso8859-14 45) (make-char 'latin-iso8859-15 45) (make-char 'latin-iso8859-16 45) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 46) (vector #xF1 (make-char 'latin-iso8859-1 46) nil nil nil (make-char 'latin-iso8859-9 46) (make-char 'latin-iso8859-13 46) (make-char 'latin-iso8859-14 46) (make-char 'latin-iso8859-15 46) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 47) (vector #x1C0 nil nil nil nil nil nil (make-char 'latin-iso8859-14 47) (make-char 'latin-iso8859-15 62) (make-char 'latin-iso8859-16 62) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 48) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 48) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 49) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 49) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 50) (vector #x44 nil nil (make-char 'latin-iso8859-3 85) nil nil nil (make-char 'latin-iso8859-14 50) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 51) (vector #x44 nil nil (make-char 'latin-iso8859-3 117) nil nil nil (make-char 'latin-iso8859-14 51) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 52) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 52) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 53) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 53) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 54) (vector #x1F1 (make-char 'latin-iso8859-1 54) nil nil nil (make-char 'latin-iso8859-9 54) (make-char 'latin-iso8859-13 54) (make-char 'latin-iso8859-14 54) (make-char 'latin-iso8859-15 54) (make-char 'latin-iso8859-16 54) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 55) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 55) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 56) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 56) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 57) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 57) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 58) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 58) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 59) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 59) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 60) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 60) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 61) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 61) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 62) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 62) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 63) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 63) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 64) (vector #x1D5 (make-char 'latin-iso8859-1 64) nil (make-char 'latin-iso8859-3 64) nil (make-char 'latin-iso8859-9 64) nil (make-char 'latin-iso8859-14 64) (make-char 'latin-iso8859-15 64) (make-char 'latin-iso8859-16 64) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 65) (vector #x1DF (make-char 'latin-iso8859-1 65) (make-char 'latin-iso8859-2 65) (make-char 'latin-iso8859-3 65) (make-char 'latin-iso8859-4 65) (make-char 'latin-iso8859-9 65) nil (make-char 'latin-iso8859-14 65) (make-char 'latin-iso8859-15 65) (make-char 'latin-iso8859-16 65) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 66) (vector #x1DF (make-char 'latin-iso8859-1 66) (make-char 'latin-iso8859-2 66) (make-char 'latin-iso8859-3 66) (make-char 'latin-iso8859-4 66) (make-char 'latin-iso8859-9 66) nil (make-char 'latin-iso8859-14 66) (make-char 'latin-iso8859-15 66) (make-char 'latin-iso8859-16 66) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 67) (vector #xD9 (make-char 'latin-iso8859-1 67) nil nil (make-char 'latin-iso8859-4 67) (make-char 'latin-iso8859-9 67) nil (make-char 'latin-iso8859-14 67) (make-char 'latin-iso8859-15 67) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 68) (vector #x1FF (make-char 'latin-iso8859-1 68) (make-char 'latin-iso8859-2 68) (make-char 'latin-iso8859-3 68) (make-char 'latin-iso8859-4 68) (make-char 'latin-iso8859-9 68) (make-char 'latin-iso8859-13 68) (make-char 'latin-iso8859-14 68) (make-char 'latin-iso8859-15 68) (make-char 'latin-iso8859-16 68) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 69) (vector #xF9 (make-char 'latin-iso8859-1 69) nil nil (make-char 'latin-iso8859-4 69) (make-char 'latin-iso8859-9 69) (make-char 'latin-iso8859-13 69) (make-char 'latin-iso8859-14 69) (make-char 'latin-iso8859-15 69) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 70) (vector #x1F9 (make-char 'latin-iso8859-1 70) nil nil (make-char 'latin-iso8859-4 70) (make-char 'latin-iso8859-9 70) (make-char 'latin-iso8859-13 47) (make-char 'latin-iso8859-14 70) (make-char 'latin-iso8859-15 70) (make-char 'latin-iso8859-16 70) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 71) (vector #x1D7 (make-char 'latin-iso8859-1 71) (make-char 'latin-iso8859-2 71) (make-char 'latin-iso8859-3 71) nil (make-char 'latin-iso8859-9 71) nil (make-char 'latin-iso8859-14 71) (make-char 'latin-iso8859-15 71) (make-char 'latin-iso8859-16 71) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 72) (vector #x1D5 (make-char 'latin-iso8859-1 72) nil (make-char 'latin-iso8859-3 72) nil (make-char 'latin-iso8859-9 72) nil (make-char 'latin-iso8859-14 72) (make-char 'latin-iso8859-15 72) (make-char 'latin-iso8859-16 72) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 73) (vector #x1FF (make-char 'latin-iso8859-1 73) (make-char 'latin-iso8859-2 73) (make-char 'latin-iso8859-3 73) (make-char 'latin-iso8859-4 73) (make-char 'latin-iso8859-9 73) (make-char 'latin-iso8859-13 73) (make-char 'latin-iso8859-14 73) (make-char 'latin-iso8859-15 73) (make-char 'latin-iso8859-16 73) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 74) (vector #x1D5 (make-char 'latin-iso8859-1 74) nil (make-char 'latin-iso8859-3 74) nil (make-char 'latin-iso8859-9 74) nil (make-char 'latin-iso8859-14 74) (make-char 'latin-iso8859-15 74) (make-char 'latin-iso8859-16 74) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 75) (vector #x1DF (make-char 'latin-iso8859-1 75) (make-char 'latin-iso8859-2 75) (make-char 'latin-iso8859-3 75) (make-char 'latin-iso8859-4 75) (make-char 'latin-iso8859-9 75) nil (make-char 'latin-iso8859-14 75) (make-char 'latin-iso8859-15 75) (make-char 'latin-iso8859-16 75) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 76) (vector #x1D5 (make-char 'latin-iso8859-1 76) nil (make-char 'latin-iso8859-3 76) nil (make-char 'latin-iso8859-9 76) nil (make-char 'latin-iso8859-14 76) (make-char 'latin-iso8859-15 76) (make-char 'latin-iso8859-16 76) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 77) (vector #x1DF (make-char 'latin-iso8859-1 77) (make-char 'latin-iso8859-2 77) (make-char 'latin-iso8859-3 77) (make-char 'latin-iso8859-4 77) (make-char 'latin-iso8859-9 77) nil (make-char 'latin-iso8859-14 77) (make-char 'latin-iso8859-15 77) (make-char 'latin-iso8859-16 77) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 78) (vector #x1DF (make-char 'latin-iso8859-1 78) (make-char 'latin-iso8859-2 78) (make-char 'latin-iso8859-3 78) (make-char 'latin-iso8859-4 78) (make-char 'latin-iso8859-9 78) nil (make-char 'latin-iso8859-14 78) (make-char 'latin-iso8859-15 78) (make-char 'latin-iso8859-16 78) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 79) (vector #x1D5 (make-char 'latin-iso8859-1 79) nil (make-char 'latin-iso8859-3 79) nil (make-char 'latin-iso8859-9 79) nil (make-char 'latin-iso8859-14 79) (make-char 'latin-iso8859-15 79) (make-char 'latin-iso8859-16 79) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 80) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 80) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 81) (vector #xD5 (make-char 'latin-iso8859-1 81) nil (make-char 'latin-iso8859-3 81) nil (make-char 'latin-iso8859-9 81) nil (make-char 'latin-iso8859-14 81) (make-char 'latin-iso8859-15 81) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 82) (vector #x1D5 (make-char 'latin-iso8859-1 82) nil (make-char 'latin-iso8859-3 82) nil (make-char 'latin-iso8859-9 82) nil (make-char 'latin-iso8859-14 82) (make-char 'latin-iso8859-15 82) (make-char 'latin-iso8859-16 82) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 83) (vector #x1F7 (make-char 'latin-iso8859-1 83) (make-char 'latin-iso8859-2 83) (make-char 'latin-iso8859-3 83) nil (make-char 'latin-iso8859-9 83) (make-char 'latin-iso8859-13 83) (make-char 'latin-iso8859-14 83) (make-char 'latin-iso8859-15 83) (make-char 'latin-iso8859-16 83) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 84) (vector #x1DF (make-char 'latin-iso8859-1 84) (make-char 'latin-iso8859-2 84) (make-char 'latin-iso8859-3 84) (make-char 'latin-iso8859-4 84) (make-char 'latin-iso8859-9 84) nil (make-char 'latin-iso8859-14 84) (make-char 'latin-iso8859-15 84) (make-char 'latin-iso8859-16 84) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 85) (vector #xF9 (make-char 'latin-iso8859-1 85) nil nil (make-char 'latin-iso8859-4 85) (make-char 'latin-iso8859-9 85) (make-char 'latin-iso8859-13 85) (make-char 'latin-iso8859-14 85) (make-char 'latin-iso8859-15 85) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 86) (vector #x1FF (make-char 'latin-iso8859-1 86) (make-char 'latin-iso8859-2 86) (make-char 'latin-iso8859-3 86) (make-char 'latin-iso8859-4 86) (make-char 'latin-iso8859-9 86) (make-char 'latin-iso8859-13 86) (make-char 'latin-iso8859-14 86) (make-char 'latin-iso8859-15 86) (make-char 'latin-iso8859-16 86) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 87) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 87) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 88) (vector #xF9 (make-char 'latin-iso8859-1 88) nil nil (make-char 'latin-iso8859-4 88) (make-char 'latin-iso8859-9 88) (make-char 'latin-iso8859-13 40) (make-char 'latin-iso8859-14 88) (make-char 'latin-iso8859-15 88) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 89) (vector #x1D5 (make-char 'latin-iso8859-1 89) nil (make-char 'latin-iso8859-3 89) nil (make-char 'latin-iso8859-9 89) nil (make-char 'latin-iso8859-14 89) (make-char 'latin-iso8859-15 89) (make-char 'latin-iso8859-16 89) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 90) (vector #x1DF (make-char 'latin-iso8859-1 90) (make-char 'latin-iso8859-2 90) (make-char 'latin-iso8859-3 90) (make-char 'latin-iso8859-4 90) (make-char 'latin-iso8859-9 90) nil (make-char 'latin-iso8859-14 90) (make-char 'latin-iso8859-15 90) (make-char 'latin-iso8859-16 90) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 91) (vector #x1DD (make-char 'latin-iso8859-1 91) nil (make-char 'latin-iso8859-3 91) (make-char 'latin-iso8859-4 91) (make-char 'latin-iso8859-9 91) nil (make-char 'latin-iso8859-14 91) (make-char 'latin-iso8859-15 91) (make-char 'latin-iso8859-16 91) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 92) (vector #x1FF (make-char 'latin-iso8859-1 92) (make-char 'latin-iso8859-2 92) (make-char 'latin-iso8859-3 92) (make-char 'latin-iso8859-4 92) (make-char 'latin-iso8859-9 92) (make-char 'latin-iso8859-13 92) (make-char 'latin-iso8859-14 92) (make-char 'latin-iso8859-15 92) (make-char 'latin-iso8859-16 92) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 93) (vector #xC3 (make-char 'latin-iso8859-1 93) (make-char 'latin-iso8859-2 93) nil nil nil nil (make-char 'latin-iso8859-14 93) (make-char 'latin-iso8859-15 93) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 94) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 94) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 95) (vector #x1FF (make-char 'latin-iso8859-1 95) (make-char 'latin-iso8859-2 95) (make-char 'latin-iso8859-3 95) (make-char 'latin-iso8859-4 95) (make-char 'latin-iso8859-9 95) (make-char 'latin-iso8859-13 95) (make-char 'latin-iso8859-14 95) (make-char 'latin-iso8859-15 95) (make-char 'latin-iso8859-16 95) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 96) (vector #x1D5 (make-char 'latin-iso8859-1 96) nil (make-char 'latin-iso8859-3 96) nil (make-char 'latin-iso8859-9 96) nil (make-char 'latin-iso8859-14 96) (make-char 'latin-iso8859-15 96) (make-char 'latin-iso8859-16 96) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 97) (vector #x1DF (make-char 'latin-iso8859-1 97) (make-char 'latin-iso8859-2 97) (make-char 'latin-iso8859-3 97) (make-char 'latin-iso8859-4 97) (make-char 'latin-iso8859-9 97) nil (make-char 'latin-iso8859-14 97) (make-char 'latin-iso8859-15 97) (make-char 'latin-iso8859-16 97) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 98) (vector #x1DF (make-char 'latin-iso8859-1 98) (make-char 'latin-iso8859-2 98) (make-char 'latin-iso8859-3 98) (make-char 'latin-iso8859-4 98) (make-char 'latin-iso8859-9 98) nil (make-char 'latin-iso8859-14 98) (make-char 'latin-iso8859-15 98) (make-char 'latin-iso8859-16 98) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 99) (vector #xD9 (make-char 'latin-iso8859-1 99) nil nil (make-char 'latin-iso8859-4 99) (make-char 'latin-iso8859-9 99) nil (make-char 'latin-iso8859-14 99) (make-char 'latin-iso8859-15 99) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 100) (vector #x1FF (make-char 'latin-iso8859-1 100) (make-char 'latin-iso8859-2 100) (make-char 'latin-iso8859-3 100) (make-char 'latin-iso8859-4 100) (make-char 'latin-iso8859-9 100) (make-char 'latin-iso8859-13 100) (make-char 'latin-iso8859-14 100) (make-char 'latin-iso8859-15 100) (make-char 'latin-iso8859-16 100) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 101) (vector #xF9 (make-char 'latin-iso8859-1 101) nil nil (make-char 'latin-iso8859-4 101) (make-char 'latin-iso8859-9 101) (make-char 'latin-iso8859-13 101) (make-char 'latin-iso8859-14 101) (make-char 'latin-iso8859-15 101) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 102) (vector #x1F9 (make-char 'latin-iso8859-1 102) nil nil (make-char 'latin-iso8859-4 102) (make-char 'latin-iso8859-9 102) (make-char 'latin-iso8859-13 63) (make-char 'latin-iso8859-14 102) (make-char 'latin-iso8859-15 102) (make-char 'latin-iso8859-16 102) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 103) (vector #x1D7 (make-char 'latin-iso8859-1 103) (make-char 'latin-iso8859-2 103) (make-char 'latin-iso8859-3 103) nil (make-char 'latin-iso8859-9 103) nil (make-char 'latin-iso8859-14 103) (make-char 'latin-iso8859-15 103) (make-char 'latin-iso8859-16 103) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 104) (vector #x1D5 (make-char 'latin-iso8859-1 104) nil (make-char 'latin-iso8859-3 104) nil (make-char 'latin-iso8859-9 104) nil (make-char 'latin-iso8859-14 104) (make-char 'latin-iso8859-15 104) (make-char 'latin-iso8859-16 104) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 105) (vector #x1FF (make-char 'latin-iso8859-1 105) (make-char 'latin-iso8859-2 105) (make-char 'latin-iso8859-3 105) (make-char 'latin-iso8859-4 105) (make-char 'latin-iso8859-9 105) (make-char 'latin-iso8859-13 105) (make-char 'latin-iso8859-14 105) (make-char 'latin-iso8859-15 105) (make-char 'latin-iso8859-16 105) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 106) (vector #x1D5 (make-char 'latin-iso8859-1 106) nil (make-char 'latin-iso8859-3 106) nil (make-char 'latin-iso8859-9 106) nil (make-char 'latin-iso8859-14 106) (make-char 'latin-iso8859-15 106) (make-char 'latin-iso8859-16 106) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 107) (vector #x1DF (make-char 'latin-iso8859-1 107) (make-char 'latin-iso8859-2 107) (make-char 'latin-iso8859-3 107) (make-char 'latin-iso8859-4 107) (make-char 'latin-iso8859-9 107) nil (make-char 'latin-iso8859-14 107) (make-char 'latin-iso8859-15 107) (make-char 'latin-iso8859-16 107) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 108) (vector #x1D5 (make-char 'latin-iso8859-1 108) nil (make-char 'latin-iso8859-3 108) nil (make-char 'latin-iso8859-9 108) nil (make-char 'latin-iso8859-14 108) (make-char 'latin-iso8859-15 108) (make-char 'latin-iso8859-16 108) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 109) (vector #x1DF (make-char 'latin-iso8859-1 109) (make-char 'latin-iso8859-2 109) (make-char 'latin-iso8859-3 109) (make-char 'latin-iso8859-4 109) (make-char 'latin-iso8859-9 109) nil (make-char 'latin-iso8859-14 109) (make-char 'latin-iso8859-15 109) (make-char 'latin-iso8859-16 109) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 110) (vector #x1DF (make-char 'latin-iso8859-1 110) (make-char 'latin-iso8859-2 110) (make-char 'latin-iso8859-3 110) (make-char 'latin-iso8859-4 110) (make-char 'latin-iso8859-9 110) nil (make-char 'latin-iso8859-14 110) (make-char 'latin-iso8859-15 110) (make-char 'latin-iso8859-16 110) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 111) (vector #x1D5 (make-char 'latin-iso8859-1 111) nil (make-char 'latin-iso8859-3 111) nil (make-char 'latin-iso8859-9 111) nil (make-char 'latin-iso8859-14 111) (make-char 'latin-iso8859-15 111) (make-char 'latin-iso8859-16 111) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 112) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 112) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 113) (vector #xD5 (make-char 'latin-iso8859-1 113) nil (make-char 'latin-iso8859-3 113) nil (make-char 'latin-iso8859-9 113) nil (make-char 'latin-iso8859-14 113) (make-char 'latin-iso8859-15 113) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 114) (vector #x1D5 (make-char 'latin-iso8859-1 114) nil (make-char 'latin-iso8859-3 114) nil (make-char 'latin-iso8859-9 114) nil (make-char 'latin-iso8859-14 114) (make-char 'latin-iso8859-15 114) (make-char 'latin-iso8859-16 114) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 115) (vector #x1F7 (make-char 'latin-iso8859-1 115) (make-char 'latin-iso8859-2 115) (make-char 'latin-iso8859-3 115) nil (make-char 'latin-iso8859-9 115) (make-char 'latin-iso8859-13 115) (make-char 'latin-iso8859-14 115) (make-char 'latin-iso8859-15 115) (make-char 'latin-iso8859-16 115) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 116) (vector #x1DF (make-char 'latin-iso8859-1 116) (make-char 'latin-iso8859-2 116) (make-char 'latin-iso8859-3 116) (make-char 'latin-iso8859-4 116) (make-char 'latin-iso8859-9 116) nil (make-char 'latin-iso8859-14 116) (make-char 'latin-iso8859-15 116) (make-char 'latin-iso8859-16 116) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 117) (vector #xF9 (make-char 'latin-iso8859-1 117) nil nil (make-char 'latin-iso8859-4 117) (make-char 'latin-iso8859-9 117) (make-char 'latin-iso8859-13 117) (make-char 'latin-iso8859-14 117) (make-char 'latin-iso8859-15 117) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 118) (vector #x1FF (make-char 'latin-iso8859-1 118) (make-char 'latin-iso8859-2 118) (make-char 'latin-iso8859-3 118) (make-char 'latin-iso8859-4 118) (make-char 'latin-iso8859-9 118) (make-char 'latin-iso8859-13 118) (make-char 'latin-iso8859-14 118) (make-char 'latin-iso8859-15 118) (make-char 'latin-iso8859-16 118) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 119) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 119) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 120) (vector #xF9 (make-char 'latin-iso8859-1 120) nil nil (make-char 'latin-iso8859-4 120) (make-char 'latin-iso8859-9 120) (make-char 'latin-iso8859-13 56) (make-char 'latin-iso8859-14 120) (make-char 'latin-iso8859-15 120) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 121) (vector #x1D5 (make-char 'latin-iso8859-1 121) nil (make-char 'latin-iso8859-3 121) nil (make-char 'latin-iso8859-9 121) nil (make-char 'latin-iso8859-14 121) (make-char 'latin-iso8859-15 121) (make-char 'latin-iso8859-16 121) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 122) (vector #x1DF (make-char 'latin-iso8859-1 122) (make-char 'latin-iso8859-2 122) (make-char 'latin-iso8859-3 122) (make-char 'latin-iso8859-4 122) (make-char 'latin-iso8859-9 122) nil (make-char 'latin-iso8859-14 122) (make-char 'latin-iso8859-15 122) (make-char 'latin-iso8859-16 122) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 123) (vector #x1DD (make-char 'latin-iso8859-1 123) nil (make-char 'latin-iso8859-3 123) (make-char 'latin-iso8859-4 123) (make-char 'latin-iso8859-9 123) nil (make-char 'latin-iso8859-14 123) (make-char 'latin-iso8859-15 123) (make-char 'latin-iso8859-16 123) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 124) (vector #x1FF (make-char 'latin-iso8859-1 124) (make-char 'latin-iso8859-2 124) (make-char 'latin-iso8859-3 124) (make-char 'latin-iso8859-4 124) (make-char 'latin-iso8859-9 124) (make-char 'latin-iso8859-13 124) (make-char 'latin-iso8859-14 124) (make-char 'latin-iso8859-15 124) (make-char 'latin-iso8859-16 124) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 125) (vector #xC3 (make-char 'latin-iso8859-1 125) (make-char 'latin-iso8859-2 125) nil nil nil nil (make-char 'latin-iso8859-14 125) (make-char 'latin-iso8859-15 125) nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 126) (vector #x40 nil nil nil nil nil nil (make-char 'latin-iso8859-14 126) nil nil nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-14 127) (vector #x1D1 (make-char 'latin-iso8859-1 127) nil nil nil (make-char 'latin-iso8859-9 127) nil (make-char 'latin-iso8859-14 127) (make-char 'latin-iso8859-15 127) (make-char 'latin-iso8859-16 127) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 32) (vector #x1FF (make-char 'latin-iso8859-1 32) (make-char 'latin-iso8859-2 32) (make-char 'latin-iso8859-3 32) (make-char 'latin-iso8859-4 32) (make-char 'latin-iso8859-9 32) (make-char 'latin-iso8859-13 32) (make-char 'latin-iso8859-14 32) (make-char 'latin-iso8859-15 32) (make-char 'latin-iso8859-16 32) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 33) (vector #x12A nil (make-char 'latin-iso8859-2 33) nil (make-char 'latin-iso8859-4 33) nil (make-char 'latin-iso8859-13 64) nil nil (make-char 'latin-iso8859-16 33) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 34) (vector #x12A nil (make-char 'latin-iso8859-2 49) nil (make-char 'latin-iso8859-4 49) nil (make-char 'latin-iso8859-13 96) nil nil (make-char 'latin-iso8859-16 34) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 35) (vector #x122 nil (make-char 'latin-iso8859-2 35) nil nil nil (make-char 'latin-iso8859-13 89) nil nil (make-char 'latin-iso8859-16 35) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 36) (vector #x180 nil nil nil nil nil nil nil (make-char 'latin-iso8859-15 36) (make-char 'latin-iso8859-16 36) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 37) (vector #x120 nil nil nil nil nil (make-char 'latin-iso8859-13 37) nil nil (make-char 'latin-iso8859-16 37) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 38) (vector #x1AA nil (make-char 'latin-iso8859-2 41) nil (make-char 'latin-iso8859-4 41) nil (make-char 'latin-iso8859-13 80) nil (make-char 'latin-iso8859-15 38) (make-char 'latin-iso8859-16 38) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 39) (vector #x1FF (make-char 'latin-iso8859-1 39) (make-char 'latin-iso8859-2 39) (make-char 'latin-iso8859-3 39) (make-char 'latin-iso8859-4 39) (make-char 'latin-iso8859-9 39) (make-char 'latin-iso8859-13 39) (make-char 'latin-iso8859-14 39) (make-char 'latin-iso8859-15 39) (make-char 'latin-iso8859-16 39) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 40) (vector #x1AA nil (make-char 'latin-iso8859-2 57) nil (make-char 'latin-iso8859-4 57) nil (make-char 'latin-iso8859-13 112) nil (make-char 'latin-iso8859-15 40) (make-char 'latin-iso8859-16 40) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 41) (vector #x1F1 (make-char 'latin-iso8859-1 41) nil nil nil (make-char 'latin-iso8859-9 41) (make-char 'latin-iso8859-13 41) (make-char 'latin-iso8859-14 41) (make-char 'latin-iso8859-15 41) (make-char 'latin-iso8859-16 41) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 42) (vector #x100 nil nil nil nil nil nil nil nil (make-char 'latin-iso8859-16 42) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 43) (vector #x1B1 (make-char 'latin-iso8859-1 43) nil nil nil (make-char 'latin-iso8859-9 43) (make-char 'latin-iso8859-13 43) nil (make-char 'latin-iso8859-15 43) (make-char 'latin-iso8859-16 43) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 44) (vector #x122 nil (make-char 'latin-iso8859-2 44) nil nil nil (make-char 'latin-iso8859-13 74) nil nil (make-char 'latin-iso8859-16 44) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 45) (vector #x1FF (make-char 'latin-iso8859-1 45) (make-char 'latin-iso8859-2 45) (make-char 'latin-iso8859-3 45) (make-char 'latin-iso8859-4 45) (make-char 'latin-iso8859-9 45) (make-char 'latin-iso8859-13 45) (make-char 'latin-iso8859-14 45) (make-char 'latin-iso8859-15 45) (make-char 'latin-iso8859-16 45) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 46) (vector #x122 nil (make-char 'latin-iso8859-2 60) nil nil nil (make-char 'latin-iso8859-13 106) nil nil (make-char 'latin-iso8859-16 46) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 47) (vector #x126 nil (make-char 'latin-iso8859-2 47) (make-char 'latin-iso8859-3 47) nil nil (make-char 'latin-iso8859-13 93) nil nil (make-char 'latin-iso8859-16 47) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 48) (vector #x1BF (make-char 'latin-iso8859-1 48) (make-char 'latin-iso8859-2 48) (make-char 'latin-iso8859-3 48) (make-char 'latin-iso8859-4 48) (make-char 'latin-iso8859-9 48) (make-char 'latin-iso8859-13 48) nil (make-char 'latin-iso8859-15 48) (make-char 'latin-iso8859-16 48) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 49) (vector #x1B1 (make-char 'latin-iso8859-1 49) nil nil nil (make-char 'latin-iso8859-9 49) (make-char 'latin-iso8859-13 49) nil (make-char 'latin-iso8859-15 49) (make-char 'latin-iso8859-16 49) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 50) (vector #x12A nil (make-char 'latin-iso8859-2 72) nil (make-char 'latin-iso8859-4 72) nil (make-char 'latin-iso8859-13 72) nil nil (make-char 'latin-iso8859-16 50) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 51) (vector #x122 nil (make-char 'latin-iso8859-2 51) nil nil nil (make-char 'latin-iso8859-13 121) nil nil (make-char 'latin-iso8859-16 51) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 52) (vector #x1AA nil (make-char 'latin-iso8859-2 46) nil (make-char 'latin-iso8859-4 46) nil (make-char 'latin-iso8859-13 94) nil (make-char 'latin-iso8859-15 52) (make-char 'latin-iso8859-16 52) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 53) (vector #x120 nil nil nil nil nil (make-char 'latin-iso8859-13 33) nil nil (make-char 'latin-iso8859-16 53) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 54) (vector #x1F1 (make-char 'latin-iso8859-1 54) nil nil nil (make-char 'latin-iso8859-9 54) (make-char 'latin-iso8859-13 54) (make-char 'latin-iso8859-14 54) (make-char 'latin-iso8859-15 54) (make-char 'latin-iso8859-16 54) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 55) (vector #x1B5 (make-char 'latin-iso8859-1 55) nil (make-char 'latin-iso8859-3 55) nil (make-char 'latin-iso8859-9 55) (make-char 'latin-iso8859-13 55) nil (make-char 'latin-iso8859-15 55) (make-char 'latin-iso8859-16 55) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 56) (vector #x1AA nil (make-char 'latin-iso8859-2 62) nil (make-char 'latin-iso8859-4 62) nil (make-char 'latin-iso8859-13 126) nil (make-char 'latin-iso8859-15 56) (make-char 'latin-iso8859-16 56) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 57) (vector #x12A nil (make-char 'latin-iso8859-2 104) nil (make-char 'latin-iso8859-4 104) nil (make-char 'latin-iso8859-13 104) nil nil (make-char 'latin-iso8859-16 57) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 58) (vector #x100 nil nil nil nil nil nil nil nil (make-char 'latin-iso8859-16 58) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 59) (vector #x1B1 (make-char 'latin-iso8859-1 59) nil nil nil (make-char 'latin-iso8859-9 59) (make-char 'latin-iso8859-13 59) nil (make-char 'latin-iso8859-15 59) (make-char 'latin-iso8859-16 59) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 60) (vector #x180 nil nil nil nil nil nil nil (make-char 'latin-iso8859-15 60) (make-char 'latin-iso8859-16 60) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 61) (vector #x180 nil nil nil nil nil nil nil (make-char 'latin-iso8859-15 61) (make-char 'latin-iso8859-16 61) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 62) (vector #x1C0 nil nil nil nil nil nil (make-char 'latin-iso8859-14 47) (make-char 'latin-iso8859-15 62) (make-char 'latin-iso8859-16 62) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 63) (vector #x126 nil (make-char 'latin-iso8859-2 63) (make-char 'latin-iso8859-3 63) nil nil (make-char 'latin-iso8859-13 125) nil nil (make-char 'latin-iso8859-16 63) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 64) (vector #x1D5 (make-char 'latin-iso8859-1 64) nil (make-char 'latin-iso8859-3 64) nil (make-char 'latin-iso8859-9 64) nil (make-char 'latin-iso8859-14 64) (make-char 'latin-iso8859-15 64) (make-char 'latin-iso8859-16 64) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 65) (vector #x1DF (make-char 'latin-iso8859-1 65) (make-char 'latin-iso8859-2 65) (make-char 'latin-iso8859-3 65) (make-char 'latin-iso8859-4 65) (make-char 'latin-iso8859-9 65) nil (make-char 'latin-iso8859-14 65) (make-char 'latin-iso8859-15 65) (make-char 'latin-iso8859-16 65) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 66) (vector #x1DF (make-char 'latin-iso8859-1 66) (make-char 'latin-iso8859-2 66) (make-char 'latin-iso8859-3 66) (make-char 'latin-iso8859-4 66) (make-char 'latin-iso8859-9 66) nil (make-char 'latin-iso8859-14 66) (make-char 'latin-iso8859-15 66) (make-char 'latin-iso8859-16 66) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 67) (vector #x102 nil (make-char 'latin-iso8859-2 67) nil nil nil nil nil nil (make-char 'latin-iso8859-16 67) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 68) (vector #x1FF (make-char 'latin-iso8859-1 68) (make-char 'latin-iso8859-2 68) (make-char 'latin-iso8859-3 68) (make-char 'latin-iso8859-4 68) (make-char 'latin-iso8859-9 68) (make-char 'latin-iso8859-13 68) (make-char 'latin-iso8859-14 68) (make-char 'latin-iso8859-15 68) (make-char 'latin-iso8859-16 68) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 69) (vector #x122 nil (make-char 'latin-iso8859-2 70) nil nil nil (make-char 'latin-iso8859-13 67) nil nil (make-char 'latin-iso8859-16 69) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 70) (vector #x1F9 (make-char 'latin-iso8859-1 70) nil nil (make-char 'latin-iso8859-4 70) (make-char 'latin-iso8859-9 70) (make-char 'latin-iso8859-13 47) (make-char 'latin-iso8859-14 70) (make-char 'latin-iso8859-15 70) (make-char 'latin-iso8859-16 70) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 71) (vector #x1D7 (make-char 'latin-iso8859-1 71) (make-char 'latin-iso8859-2 71) (make-char 'latin-iso8859-3 71) nil (make-char 'latin-iso8859-9 71) nil (make-char 'latin-iso8859-14 71) (make-char 'latin-iso8859-15 71) (make-char 'latin-iso8859-16 71) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 72) (vector #x1D5 (make-char 'latin-iso8859-1 72) nil (make-char 'latin-iso8859-3 72) nil (make-char 'latin-iso8859-9 72) nil (make-char 'latin-iso8859-14 72) (make-char 'latin-iso8859-15 72) (make-char 'latin-iso8859-16 72) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 73) (vector #x1FF (make-char 'latin-iso8859-1 73) (make-char 'latin-iso8859-2 73) (make-char 'latin-iso8859-3 73) (make-char 'latin-iso8859-4 73) (make-char 'latin-iso8859-9 73) (make-char 'latin-iso8859-13 73) (make-char 'latin-iso8859-14 73) (make-char 'latin-iso8859-15 73) (make-char 'latin-iso8859-16 73) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 74) (vector #x1D5 (make-char 'latin-iso8859-1 74) nil (make-char 'latin-iso8859-3 74) nil (make-char 'latin-iso8859-9 74) nil (make-char 'latin-iso8859-14 74) (make-char 'latin-iso8859-15 74) (make-char 'latin-iso8859-16 74) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 75) (vector #x1DF (make-char 'latin-iso8859-1 75) (make-char 'latin-iso8859-2 75) (make-char 'latin-iso8859-3 75) (make-char 'latin-iso8859-4 75) (make-char 'latin-iso8859-9 75) nil (make-char 'latin-iso8859-14 75) (make-char 'latin-iso8859-15 75) (make-char 'latin-iso8859-16 75) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 76) (vector #x1D5 (make-char 'latin-iso8859-1 76) nil (make-char 'latin-iso8859-3 76) nil (make-char 'latin-iso8859-9 76) nil (make-char 'latin-iso8859-14 76) (make-char 'latin-iso8859-15 76) (make-char 'latin-iso8859-16 76) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 77) (vector #x1DF (make-char 'latin-iso8859-1 77) (make-char 'latin-iso8859-2 77) (make-char 'latin-iso8859-3 77) (make-char 'latin-iso8859-4 77) (make-char 'latin-iso8859-9 77) nil (make-char 'latin-iso8859-14 77) (make-char 'latin-iso8859-15 77) (make-char 'latin-iso8859-16 77) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 78) (vector #x1DF (make-char 'latin-iso8859-1 78) (make-char 'latin-iso8859-2 78) (make-char 'latin-iso8859-3 78) (make-char 'latin-iso8859-4 78) (make-char 'latin-iso8859-9 78) nil (make-char 'latin-iso8859-14 78) (make-char 'latin-iso8859-15 78) (make-char 'latin-iso8859-16 78) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 79) (vector #x1D5 (make-char 'latin-iso8859-1 79) nil (make-char 'latin-iso8859-3 79) nil (make-char 'latin-iso8859-9 79) nil (make-char 'latin-iso8859-14 79) (make-char 'latin-iso8859-15 79) (make-char 'latin-iso8859-16 79) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 80) (vector #x10A nil (make-char 'latin-iso8859-2 80) nil (make-char 'latin-iso8859-4 80) nil nil nil nil (make-char 'latin-iso8859-16 80) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 81) (vector #x122 nil (make-char 'latin-iso8859-2 81) nil nil nil (make-char 'latin-iso8859-13 81) nil nil (make-char 'latin-iso8859-16 81) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 82) (vector #x1D5 (make-char 'latin-iso8859-1 82) nil (make-char 'latin-iso8859-3 82) nil (make-char 'latin-iso8859-9 82) nil (make-char 'latin-iso8859-14 82) (make-char 'latin-iso8859-15 82) (make-char 'latin-iso8859-16 82) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 83) (vector #x1F7 (make-char 'latin-iso8859-1 83) (make-char 'latin-iso8859-2 83) (make-char 'latin-iso8859-3 83) nil (make-char 'latin-iso8859-9 83) (make-char 'latin-iso8859-13 83) (make-char 'latin-iso8859-14 83) (make-char 'latin-iso8859-15 83) (make-char 'latin-iso8859-16 83) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 84) (vector #x1DF (make-char 'latin-iso8859-1 84) (make-char 'latin-iso8859-2 84) (make-char 'latin-iso8859-3 84) (make-char 'latin-iso8859-4 84) (make-char 'latin-iso8859-9 84) nil (make-char 'latin-iso8859-14 84) (make-char 'latin-iso8859-15 84) (make-char 'latin-iso8859-16 84) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 85) (vector #x102 nil (make-char 'latin-iso8859-2 85) nil nil nil nil nil nil (make-char 'latin-iso8859-16 85) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 86) (vector #x1FF (make-char 'latin-iso8859-1 86) (make-char 'latin-iso8859-2 86) (make-char 'latin-iso8859-3 86) (make-char 'latin-iso8859-4 86) (make-char 'latin-iso8859-9 86) (make-char 'latin-iso8859-13 86) (make-char 'latin-iso8859-14 86) (make-char 'latin-iso8859-15 86) (make-char 'latin-iso8859-16 86) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 87) (vector #x122 nil (make-char 'latin-iso8859-2 38) nil nil nil (make-char 'latin-iso8859-13 90) nil nil (make-char 'latin-iso8859-16 87) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 88) (vector #x102 nil (make-char 'latin-iso8859-2 91) nil nil nil nil nil nil (make-char 'latin-iso8859-16 88) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 89) (vector #x1D5 (make-char 'latin-iso8859-1 89) nil (make-char 'latin-iso8859-3 89) nil (make-char 'latin-iso8859-9 89) nil (make-char 'latin-iso8859-14 89) (make-char 'latin-iso8859-15 89) (make-char 'latin-iso8859-16 89) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 90) (vector #x1DF (make-char 'latin-iso8859-1 90) (make-char 'latin-iso8859-2 90) (make-char 'latin-iso8859-3 90) (make-char 'latin-iso8859-4 90) (make-char 'latin-iso8859-9 90) nil (make-char 'latin-iso8859-14 90) (make-char 'latin-iso8859-15 90) (make-char 'latin-iso8859-16 90) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 91) (vector #x1DD (make-char 'latin-iso8859-1 91) nil (make-char 'latin-iso8859-3 91) (make-char 'latin-iso8859-4 91) (make-char 'latin-iso8859-9 91) nil (make-char 'latin-iso8859-14 91) (make-char 'latin-iso8859-15 91) (make-char 'latin-iso8859-16 91) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 92) (vector #x1FF (make-char 'latin-iso8859-1 92) (make-char 'latin-iso8859-2 92) (make-char 'latin-iso8859-3 92) (make-char 'latin-iso8859-4 92) (make-char 'latin-iso8859-9 92) (make-char 'latin-iso8859-13 92) (make-char 'latin-iso8859-14 92) (make-char 'latin-iso8859-15 92) (make-char 'latin-iso8859-16 92) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 93) (vector #x12A nil (make-char 'latin-iso8859-2 74) nil (make-char 'latin-iso8859-4 74) nil (make-char 'latin-iso8859-13 70) nil nil (make-char 'latin-iso8859-16 93) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 94) (vector #x100 nil nil nil nil nil nil nil nil (make-char 'latin-iso8859-16 94) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 95) (vector #x1FF (make-char 'latin-iso8859-1 95) (make-char 'latin-iso8859-2 95) (make-char 'latin-iso8859-3 95) (make-char 'latin-iso8859-4 95) (make-char 'latin-iso8859-9 95) (make-char 'latin-iso8859-13 95) (make-char 'latin-iso8859-14 95) (make-char 'latin-iso8859-15 95) (make-char 'latin-iso8859-16 95) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 96) (vector #x1D5 (make-char 'latin-iso8859-1 96) nil (make-char 'latin-iso8859-3 96) nil (make-char 'latin-iso8859-9 96) nil (make-char 'latin-iso8859-14 96) (make-char 'latin-iso8859-15 96) (make-char 'latin-iso8859-16 96) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 97) (vector #x1DF (make-char 'latin-iso8859-1 97) (make-char 'latin-iso8859-2 97) (make-char 'latin-iso8859-3 97) (make-char 'latin-iso8859-4 97) (make-char 'latin-iso8859-9 97) nil (make-char 'latin-iso8859-14 97) (make-char 'latin-iso8859-15 97) (make-char 'latin-iso8859-16 97) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 98) (vector #x1DF (make-char 'latin-iso8859-1 98) (make-char 'latin-iso8859-2 98) (make-char 'latin-iso8859-3 98) (make-char 'latin-iso8859-4 98) (make-char 'latin-iso8859-9 98) nil (make-char 'latin-iso8859-14 98) (make-char 'latin-iso8859-15 98) (make-char 'latin-iso8859-16 98) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 99) (vector #x102 nil (make-char 'latin-iso8859-2 99) nil nil nil nil nil nil (make-char 'latin-iso8859-16 99) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 100) (vector #x1FF (make-char 'latin-iso8859-1 100) (make-char 'latin-iso8859-2 100) (make-char 'latin-iso8859-3 100) (make-char 'latin-iso8859-4 100) (make-char 'latin-iso8859-9 100) (make-char 'latin-iso8859-13 100) (make-char 'latin-iso8859-14 100) (make-char 'latin-iso8859-15 100) (make-char 'latin-iso8859-16 100) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 101) (vector #x122 nil (make-char 'latin-iso8859-2 102) nil nil nil (make-char 'latin-iso8859-13 99) nil nil (make-char 'latin-iso8859-16 101) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 102) (vector #x1F9 (make-char 'latin-iso8859-1 102) nil nil (make-char 'latin-iso8859-4 102) (make-char 'latin-iso8859-9 102) (make-char 'latin-iso8859-13 63) (make-char 'latin-iso8859-14 102) (make-char 'latin-iso8859-15 102) (make-char 'latin-iso8859-16 102) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 103) (vector #x1D7 (make-char 'latin-iso8859-1 103) (make-char 'latin-iso8859-2 103) (make-char 'latin-iso8859-3 103) nil (make-char 'latin-iso8859-9 103) nil (make-char 'latin-iso8859-14 103) (make-char 'latin-iso8859-15 103) (make-char 'latin-iso8859-16 103) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 104) (vector #x1D5 (make-char 'latin-iso8859-1 104) nil (make-char 'latin-iso8859-3 104) nil (make-char 'latin-iso8859-9 104) nil (make-char 'latin-iso8859-14 104) (make-char 'latin-iso8859-15 104) (make-char 'latin-iso8859-16 104) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 105) (vector #x1FF (make-char 'latin-iso8859-1 105) (make-char 'latin-iso8859-2 105) (make-char 'latin-iso8859-3 105) (make-char 'latin-iso8859-4 105) (make-char 'latin-iso8859-9 105) (make-char 'latin-iso8859-13 105) (make-char 'latin-iso8859-14 105) (make-char 'latin-iso8859-15 105) (make-char 'latin-iso8859-16 105) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 106) (vector #x1D5 (make-char 'latin-iso8859-1 106) nil (make-char 'latin-iso8859-3 106) nil (make-char 'latin-iso8859-9 106) nil (make-char 'latin-iso8859-14 106) (make-char 'latin-iso8859-15 106) (make-char 'latin-iso8859-16 106) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 107) (vector #x1DF (make-char 'latin-iso8859-1 107) (make-char 'latin-iso8859-2 107) (make-char 'latin-iso8859-3 107) (make-char 'latin-iso8859-4 107) (make-char 'latin-iso8859-9 107) nil (make-char 'latin-iso8859-14 107) (make-char 'latin-iso8859-15 107) (make-char 'latin-iso8859-16 107) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 108) (vector #x1D5 (make-char 'latin-iso8859-1 108) nil (make-char 'latin-iso8859-3 108) nil (make-char 'latin-iso8859-9 108) nil (make-char 'latin-iso8859-14 108) (make-char 'latin-iso8859-15 108) (make-char 'latin-iso8859-16 108) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 109) (vector #x1DF (make-char 'latin-iso8859-1 109) (make-char 'latin-iso8859-2 109) (make-char 'latin-iso8859-3 109) (make-char 'latin-iso8859-4 109) (make-char 'latin-iso8859-9 109) nil (make-char 'latin-iso8859-14 109) (make-char 'latin-iso8859-15 109) (make-char 'latin-iso8859-16 109) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 110) (vector #x1DF (make-char 'latin-iso8859-1 110) (make-char 'latin-iso8859-2 110) (make-char 'latin-iso8859-3 110) (make-char 'latin-iso8859-4 110) (make-char 'latin-iso8859-9 110) nil (make-char 'latin-iso8859-14 110) (make-char 'latin-iso8859-15 110) (make-char 'latin-iso8859-16 110) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 111) (vector #x1D5 (make-char 'latin-iso8859-1 111) nil (make-char 'latin-iso8859-3 111) nil (make-char 'latin-iso8859-9 111) nil (make-char 'latin-iso8859-14 111) (make-char 'latin-iso8859-15 111) (make-char 'latin-iso8859-16 111) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 112) (vector #x10A nil (make-char 'latin-iso8859-2 112) nil (make-char 'latin-iso8859-4 112) nil nil nil nil (make-char 'latin-iso8859-16 112) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 113) (vector #x122 nil (make-char 'latin-iso8859-2 113) nil nil nil (make-char 'latin-iso8859-13 113) nil nil (make-char 'latin-iso8859-16 113) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 114) (vector #x1D5 (make-char 'latin-iso8859-1 114) nil (make-char 'latin-iso8859-3 114) nil (make-char 'latin-iso8859-9 114) nil (make-char 'latin-iso8859-14 114) (make-char 'latin-iso8859-15 114) (make-char 'latin-iso8859-16 114) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 115) (vector #x1F7 (make-char 'latin-iso8859-1 115) (make-char 'latin-iso8859-2 115) (make-char 'latin-iso8859-3 115) nil (make-char 'latin-iso8859-9 115) (make-char 'latin-iso8859-13 115) (make-char 'latin-iso8859-14 115) (make-char 'latin-iso8859-15 115) (make-char 'latin-iso8859-16 115) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 116) (vector #x1DF (make-char 'latin-iso8859-1 116) (make-char 'latin-iso8859-2 116) (make-char 'latin-iso8859-3 116) (make-char 'latin-iso8859-4 116) (make-char 'latin-iso8859-9 116) nil (make-char 'latin-iso8859-14 116) (make-char 'latin-iso8859-15 116) (make-char 'latin-iso8859-16 116) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 117) (vector #x102 nil (make-char 'latin-iso8859-2 117) nil nil nil nil nil nil (make-char 'latin-iso8859-16 117) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 118) (vector #x1FF (make-char 'latin-iso8859-1 118) (make-char 'latin-iso8859-2 118) (make-char 'latin-iso8859-3 118) (make-char 'latin-iso8859-4 118) (make-char 'latin-iso8859-9 118) (make-char 'latin-iso8859-13 118) (make-char 'latin-iso8859-14 118) (make-char 'latin-iso8859-15 118) (make-char 'latin-iso8859-16 118) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 119) (vector #x122 nil (make-char 'latin-iso8859-2 54) nil nil nil (make-char 'latin-iso8859-13 122) nil nil (make-char 'latin-iso8859-16 119) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 120) (vector #x102 nil (make-char 'latin-iso8859-2 123) nil nil nil nil nil nil (make-char 'latin-iso8859-16 120) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 121) (vector #x1D5 (make-char 'latin-iso8859-1 121) nil (make-char 'latin-iso8859-3 121) nil (make-char 'latin-iso8859-9 121) nil (make-char 'latin-iso8859-14 121) (make-char 'latin-iso8859-15 121) (make-char 'latin-iso8859-16 121) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 122) (vector #x1DF (make-char 'latin-iso8859-1 122) (make-char 'latin-iso8859-2 122) (make-char 'latin-iso8859-3 122) (make-char 'latin-iso8859-4 122) (make-char 'latin-iso8859-9 122) nil (make-char 'latin-iso8859-14 122) (make-char 'latin-iso8859-15 122) (make-char 'latin-iso8859-16 122) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 123) (vector #x1DD (make-char 'latin-iso8859-1 123) nil (make-char 'latin-iso8859-3 123) (make-char 'latin-iso8859-4 123) (make-char 'latin-iso8859-9 123) nil (make-char 'latin-iso8859-14 123) (make-char 'latin-iso8859-15 123) (make-char 'latin-iso8859-16 123) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 124) (vector #x1FF (make-char 'latin-iso8859-1 124) (make-char 'latin-iso8859-2 124) (make-char 'latin-iso8859-3 124) (make-char 'latin-iso8859-4 124) (make-char 'latin-iso8859-9 124) (make-char 'latin-iso8859-13 124) (make-char 'latin-iso8859-14 124) (make-char 'latin-iso8859-15 124) (make-char 'latin-iso8859-16 124) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 125) (vector #x12A nil (make-char 'latin-iso8859-2 106) nil (make-char 'latin-iso8859-4 106) nil (make-char 'latin-iso8859-13 102) nil nil (make-char 'latin-iso8859-16 125) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 126) (vector #x100 nil nil nil nil nil nil nil nil (make-char 'latin-iso8859-16 126) nil nil nil) table)
    (put-char-table (make-char 'latin-iso8859-16 127) (vector #x1D1 (make-char 'latin-iso8859-1 127) nil nil nil (make-char 'latin-iso8859-9 127) nil (make-char 'latin-iso8859-14 127) (make-char 'latin-iso8859-15 127) (make-char 'latin-iso8859-16 127) nil nil nil) table)
    table)
  "Map a (Latin) Mule character to the set of character sets containing it.
Created: 2002 November 01")
(put 'latin-unity-equivalences 'creation-date-string "2002 November 01")
;;; end of latin-unity-tables.el
